/*
 * #%L
 * LA-iMageS Core
 * %%
 * Copyright (C) 2016 Marco Aurélio Zezzi Arruda, Gustavo de Souza
 * 			Pessôa, José Luis Capelo Martínez, Florentino Fdez-Riverola, Miguel
 * 			Reboiro-Jato, Hugo López-Fdez, and Daniel Glez-Peña
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */
package es.uvigo.ei.sing.laimages.core.io;

import java.io.File;
import java.io.IOException;
import java.util.Arrays;
import java.util.List;

import es.uvigo.ei.sing.laimages.core.entities.datasets.ElementData;
import es.uvigo.ei.sing.laimages.core.entities.datasets.ElementDataset;
import es.uvigo.ei.sing.laimages.core.entities.datasets.ElementDatasetConfiguration;
import es.uvigo.ei.sing.laimages.core.entities.datasets.LineData;
import es.uvigo.ei.sing.laimages.core.entities.datasets.coordinates.LineCoordinates;
import es.uvigo.ei.sing.laimages.core.entities.datasets.coordinates.VerticalLineCoordinates;
import es.uvigo.ei.sing.laimages.core.io.LineDatasetLoader;
import es.uvigo.ei.sing.laimages.core.io.exception.NoSuchStandardElementException;

public class TestVerticalDatasetUtils {

	private static final File TEST_DATASET_DIRECTORY = ResourceLoader.loadResource("/dataset-vertical");

	private static final ElementDatasetConfiguration TEST_DATASET_CONFIGURATION = new ElementDatasetConfiguration(
			0.070d, 0.378d, 0.2d, "C12");

	public static ElementDataset loadTestDataset() throws IOException,
			NoSuchStandardElementException {
		return loadTestDataset(TEST_DATASET_CONFIGURATION);
	}

	private static ElementDataset loadTestDataset(
			ElementDatasetConfiguration configuration) throws IOException,
			NoSuchStandardElementException {
		LineDatasetLoader datasetLoader = new LineDatasetLoader(configuration);
		ElementDataset dataset = datasetLoader
				.loadAndNormalizeDataset(TEST_DATASET_DIRECTORY.toPath());
		return dataset;
	}

	public static final List<String> TEST_DATASET_ELEMENT_NAMES = Arrays
			.asList(new String[] { "Na23", "Ca44", "Zn64", "P31", "C13", "Si28"});

	private static final LineCoordinates[] TEST_DATASET_COORDINATES = new LineCoordinates[] {
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,0.0),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,0.2),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,0.4),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,0.6000000000000001),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,0.8),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,1.0),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,1.2000000000000002),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,1.4000000000000001),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,1.6),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,1.8),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,2.0),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,2.2),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,2.4000000000000004),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,2.6),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,2.8000000000000003),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,3.0),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,3.2),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,3.4000000000000004),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,3.6),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,3.8000000000000003),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,4.0),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,4.2),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,4.4),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,4.6000000000000005),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,4.800000000000001),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,5.0),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,5.2),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,5.4),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,5.6000000000000005),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,5.800000000000001),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,6.0),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,6.2),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,6.4),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,6.6000000000000005),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,6.800000000000001),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,7.0),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,7.2),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,7.4),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,7.6000000000000005),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,7.800000000000001),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,8.0),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,8.200000000000001),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,8.4),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,8.6),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,8.8),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,9.0),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,9.200000000000001),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,9.4),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,9.600000000000001),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,9.8),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,10.0),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,10.200000000000001),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,10.4),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,10.600000000000001),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,10.8),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,11.0),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,11.200000000000001),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,11.4),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,11.600000000000001),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,11.8),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,12.0),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,12.200000000000001),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,12.4),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,12.600000000000001),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,12.8),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,13.0),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,13.200000000000001),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,13.4),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,13.600000000000001),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,13.8),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,14.0),
		new VerticalLineCoordinates(0.026460000000000004,0.0,
				18.098640000000003,14.200000000000001)
	};

	public static final double[][] NA23_DATA = new double[][] {
			new double[] { 2.9402591004478563E-4, 3.410377359661311E-4,
					0.0630951132365083, 0.08604457151769712,
					0.10187378464748623, 0.21743198253713655,
					0.18397490209186176, 0.22158057508833826,
					0.16374056907319184, 0.3787777396610422,
					0.3840245757945462, 0.34803761695840174,
					0.4754927582518846, 0.45782560487162666,
					0.5244587591863867, 0.626114796404448, 0.5564712240037447,
					0.5595116612299825, 0.7336632744330206, 0.8602386831156189,
					0.7583126414493654, 0.8019479862025455, 0.9244285511231237,
					0.8080426176464363, 0.7587706630130292, 0.6608693834968798,
					0.7053798388741382, 0.7387636010018931, 0.6461235583527626,
					0.7399290767917022, 0.6467137314298119, 0.7041689586101876,
					0.8604387663293482, 0.7001479053629891, 0.7110343360336352,
					0.7550939205503701, 0.6409437861622082, 0.6929675567620656,
					0.5855296423842221, 0.5829682291835757, 0.5190577007367805,
					0.4403790546639132, 0.561812312584549, 0.48101445045323216,
					0.4282247351260536, 0.45564183339830244,
					0.42706195517559514, 0.5116586659850004,
					0.41999644205576664, 0.5184026680565286,
					0.48543957783286557, 0.7232842121839947,
					0.6300998153284433, 0.4445439485620247, 0.5944656143582491,
					0.5923458480958395, 0.6316893928253231, 0.4969847565420966,
					0.45533265683257523, 0.5879485510016746, 0.700393201088062,
					0.6749047474229233, 0.6329090227557258, 0.622918424058546,
					0.5526241224620256, 0.519491679508394, 0.6809297314820872,
					0.6550734124415492, 0.7507156192391796, 0.6485478817139285,
					0.7854292482638103, 0.6597968817533707, 0.6627801733557791,
					0.9060337041634142, 0.6391561119747254, 0.7912142411809832,
					0.8472109842999884, 0.6580345258996397, 0.6223697646432906,
					0.5634292840420172, 0.6956363927897908, 0.7496121527577192,
					0.7693304639677208, 0.7202193900057476, 0.7203855271432021,
					0.8161314085942574, 0.9444602152952547, 0.8854254016511169,
					0.8721683721110405, 0.9279135971239025, 0.9303758880450652,
					0.87374768597178, 0.8867065571744567, 0.8789728478615499,
					0.7768482112761077, 0.830779939881886, 0.7128783668170704,
					0.7248136964665107, 0.6422200719511869, 0.6881026367300239,
					0.6752753523187603, 0.6705214126293733, 0.6195738966236498,
					0.7173577287757708, 0.7855758811754819, 0.6539870933740757,
					0.6381150721397741, 0.7882807469563284, 0.717666822700509,
					0.6401400297644395, 0.6233712600929066, 0.660471002671979,
					0.5858609609694041, 0.5934340263072759, 0.5755028401174075,
					0.703318394211557, 0.6753953721765097, 0.636168925193637,
					0.6300843057824063, 0.6678938555957529, 0.6094871162369602,
					0.6602947378573629, 0.6585675796661092, 0.6627619997774725,
					0.7658912314515992, 0.5623638092832406, 0.5964285987149562,
					0.7347331476923714, 0.7382443164403721, 0.7113106095349034,
					0.8018369224236055, 0.7540119126739966, 0.9576108697370825,
					0.9167158929705783, 0.727718086770046, 0.9341505413471741,
					0.8844750328480437, 0.7512807075280131, 0.6490344891686028,
					0.6986618435001941, 0.9112102724794763, 0.7536805623515564,
					0.7432631234303061, 0.7936305582273459, 0.7159679370679439,
					0.9328527389750633, 0.9092382149805558, 0.7649067511255695,
					0.6640569445904619, 0.8866018157562551, 0.8167320388388151,
					0.9157062974615822, 0.7525016621108189, 0.7374908874189889,
					0.6750335220398576, 0.7641022866931453, 0.6295680242758643,
					0.6947345696732189, 0.5972825786809803, 0.6030195476373214,
					0.6908817086252728, 0.7227799590757467, 0.6557228754395682,
					0.657248947218508, 0.7027725320375893, 0.7933654937202461,
					0.8275104547612002, 0.7994419655714871, 0.9029554397623513,
					0.6654601043054359, 0.7451311816288971, 0.7544574760189516,
					0.7344688089783006, 0.794931793962523, 0.8673634668150249,
					0.7737546016353433, 0.9466714047019279, 0.6880190757921931,
					0.6970219130820635, 0.6823698934132432, 0.6380717252296704,
					0.5794898150706098, 0.6551017885152386, 0.6440414687194085,
					0.7849885110224312, 0.6472549588988759, 0.60358194587168,
					0.5635264825248242, 0.5963117598503554, 0.606513322912893,
					0.7017290038739492, 0.5671735710295317, 0.6015689874719002,
					0.713994437705811, 0.8602353165080792, 0.8350076550281524,
					0.7423111393039317, 0.7861060871213044, 0.6921244037156199,
					0.6625786088429836, 0.7883482745189182, 0.8587592376312306,
					0.7573548075532528, 0.8479344591293526, 1.0655735164916764,
					0.9279925555602401, 0.7915856835947265, 0.7679510578571292,
					0.8487322651664728, 0.9207411965738762, 0.9223599487395879,
					0.7409233837759625, 0.9102054525156088, 0.8873304010170218,
					0.9729938178408141, 0.8872288326563609, 0.8879138885937653,
					0.6915525709682744, 0.8095578358669226, 0.7719779884592204,
					0.8312556779088313, 0.6993296502962583, 0.654979167309709,
					0.8678652709138941, 0.7237326331123783, 0.6291077965631512,
					0.6868245892254634, 0.6958877842774868, 0.5297578517945614,
					0.5885697635528893, 0.6351861475554709, 0.6538480854684597,
					0.664947811049423, 0.6691071877787802, 0.6363323911950554,
					0.5244742171413003, 0.6839410916717341, 0.7121528570975583,
					0.6033026802142696, 0.5618595694826773, 0.616984712226139,
					0.6441389599198742, 0.5995279162871896, 0.6438571366264664,
					0.7222933944902298, 0.7316784817146884, 0.7437968660092054,
					0.6905964760905103, 0.7467069282861855, 0.7500978456024865,
					0.9198579559033231, 1.0292514239853348, 1.4909144910358068,
					2.6865104474407913, 2.219368466943632, 2.100286465598562,
					1.8578611081987757, 1.616312646304535, 1.4043985058353674,
					1.3622265825234796, 1.2931543773708012, 1.0884170650038785,
					0.9658193903530892, 0.8638831824876829, 0.9518389345212692,
					0.7536701597572857, 0.788984947854608, 0.7198811760385662,
					0.6669821981313232, 0.7485544771899902, 0.8207585904553868,
					0.7340982312919472, 0.5233383056871574, 0.6497352911661254,
					0.6191582568787186, 0.6299985783103217, 0.5926477986501517,
					0.7132987480380023, 0.7622300276339888, 0.6621824641998144,
					0.6288284103394908, 0.8349870284786193, 0.7832178421818036,
					0.7638736786851195, 0.9388959759114839, 0.6974636049847914,
					0.6640263009213205, 0.9256449580724078, 1.0125456686108274,
					0.926437511868313, 0.9068512195458699, 0.8973620813288117,
					0.8817970453510956, 0.933915006174384, 0.8070498760739718,
					0.8626245101460863, 0.9017451196230539, 0.8901168477409281,
					0.8232690089662753, 0.8604250919126545, 0.6799127286355234,
					0.7512309931888569, 0.6117569854362003, 0.6641033375563719,
					0.7351461682628754, 0.8805741131779096, 0.783245380120922,
					0.8256155338173016, 0.8219840061109862, 0.8585299976741563,
					0.8718276175236713, 0.9876087782695674, 0.9271487848866364,
					0.8341899754473254, 0.9307279259691142, 1.0921070779301447,
					1.0343678798439107, 1.02696908145197, 1.039058833408786,
					0.9421676236936489, 1.1180876030513074, 1.0532392115215303,
					1.171984447838271, 1.024479494534887, 1.0192663183867683,
					0.8609049540594953, 1.0029485324543528, 0.8409425738895618,
					0.9340095571818436, 0.7480751442598711, 0.8291670679034446,
					0.7951652931664963, 0.9243542057642057, 1.0536778911888909,
					0.9989066545638985, 0.9345358164046239, 1.02932048126786,
					0.9051280570640332, 0.9694547564573733, 0.796341262714485,
					1.0557330182417959, 0.8827762697135623, 0.9455504156001114,
					0.9088344283913551, 1.0238378781977504, 1.12785105666794,
					0.9397161052662627, 1.078827790657323, 0.8874929145438144,
					0.9319036611235194, 1.1374788530382078, 0.9565250993406291,
					0.9646782137012789, 0.9097293830446128, 0.8486566686643056,
					0.7910272967643834, 1.024519328472235, 0.8086965352313938,
					0.939166827851892, 0.963911129552534, 0.9232816828765957,
					0.8739006108432594, 0.9390488390743136, 0.7613662833566194,
					1.0726979970856487, 0.8828461132121416, 0.8335832819312065,
					1.0264028843684445, 0.8756647238911569, 0.9682134614207772,
					1.1575669263000175, 0.9302669000218693, 0.7327158708162735,
					0.958335024934035, 0.9658071882674816, 0.9303597957509934,
					0.8922942784245342, 0.8743024449985575, 0.8565542480286183,
					0.8955507766908177, 0.8300199555215863, 0.7726776968246075,
					0.9099766812537045, 0.9552436624539594, 0.9103839941732385,
					0.7610769416275985, 0.8340858864024617, 1.0351886713222338,
					0.8842488085509322, 0.8823687963067975, 0.9064564837352133,
					0.8031974095352272, 0.8809626531487212, 0.7471398567071356,
					0.8968278530819855, 0.8401361970224422, 0.8524329064476776,
					0.9286239207579132, 0.8731639172781862, 0.9053123409364017,
					0.9773575702865538, 1.0977687977563333, 1.1498332586065758,
					1.6631806697080993, 1.5298856449110165, 1.456695736578561,
					1.514260368974208, 1.0763367397527435, 1.1556092177481507,
					1.1036054495430563, 1.1395382663394484, 1.1707340443818732,
					1.0008064533659213, 1.2582392209344444, 1.0844024253558084,
					1.0634237309721783, 0.9318052865323754, 1.1342670337999508,
					1.4036310633549136, 1.0824544392261635, 0.9493128988799429,
					1.1615572054355736, 1.0687134291186897, 0.8899380617454653,
					1.1307198148892144, 1.2485188086174712, 1.1875124862941866,
					1.1790613525150841, 1.2475846772507782, 1.1497766215418916,
					1.2212716910371169, 1.1536090576269222, 1.1506298554753212,
					1.064567977817024, 1.0149910481987974, 1.1674102521190206,
					1.2893059227189774, 1.3064893719300088, 1.2522941684988544,
					1.1718160853422726, 1.1665557396640913, 1.0476345390278259,
					0.9771852733067137, 1.1484207959739499, 0.895700152858524,
					1.0942726275233805, 1.11102932439194, 1.3515378406733012,
					1.2708006720898009, 1.1320781883551414, 1.2615062306666702,
					1.1280328958863248, 1.0756752452836207, 1.2997993344251906,
					1.449493056092417, 1.5580390535254085, 1.4679330813142608,
					1.1728053632743163, 1.3009256323135863, 1.512514387840938,
					1.741977434839802, 1.4314186592328453, 1.511516375562002,
					1.3651149436791, 1.153109481230239, 1.3903843950823718,
					1.491037047591911, 1.3346230243830497, 1.5321821669312612,
					1.314826612588168, 1.6088063096120453, 1.2715019851358935,
					1.1147846254025833, 1.6239743304514265, 1.444489409536933,
					1.544972445597293, 1.5018681344113065, 1.742721692091005,
					1.5867656106939187, 1.6169062756787607, 1.7889828074275453,
					1.489905496269946, 1.241994615122833, 1.4473796539637616,
					1.442734426703126, 1.2726493069327163, 1.5679393269697897,
					1.5350751778577323, 1.3952250507706359, 1.3474745801698433,
					1.4811091537381686, 1.5501612212992075, 1.81079272091933,
					1.448344956750412, 1.7884986247026802, 1.4498059913528276,
					1.462688435390371, 1.6837176579075714, 1.5102259063092647,
					1.4632553666454757, 1.3952958982897743, 1.5739324843546367,
					1.152842983367159, 1.584749220322171, 1.4218189577056264,
					1.912301403652452, 1.7309554845826898, 1.7260876732595327,
					1.5438047465603264, 1.7846963410066927, 1.6091122845220225,
					1.6261746791321374, 1.6720594879770028, 1.6175392458790174,
					1.7538417224869711, 1.6640534913030218, 1.7500615418592496,
					1.787057223649965, 1.9090550348931346, 1.8878335206525343,
					1.5862284998468812, 1.8519929217602622, 1.7241230930510212,
					1.885138763546495, 1.8176913521811855, 1.596128568413232,
					1.6410890039840131, 1.5390354538164657, 1.6972749570050645,
					1.8665532649362866, 2.247068970317917, 2.4260733817071345,
					2.190985047962339, 1.9817482183394501, 2.1149401577354565,
					2.1617844825269636, 2.030416286106511, 1.8969157603346396,
					1.8279530344768722, 2.0033403301692103, 1.9564569933259752,
					1.8433999398227219, 1.8629289628889933, 1.6855460720107067,
					1.7637287252432805, 1.4914080677525559, 1.6813526738304152,
					2.0413134884030124, 1.215161805415452, 1.7009027271690458,
					1.9544934401912768, 1.6824110864756565, 2.1548019087401507,
					1.967671074347579, 1.8237465144533977, 1.488177865679698,
					1.70693044170802, 2.137133633763737, 1.709787718082726,
					1.567016846986299, 1.5804136005432565, 1.7253366734506335,
					1.8976254657678928, 1.764061320237918, 1.8190788330390575,
					1.6813658925162358, 1.6548920384301602, 1.840661553787461,
					1.689972821974582, 1.9179020892968215, 2.0246549802937173,
					2.057448675247683, 2.4343642479544445, 2.0398655269965165,
					1.9918041126095678, 2.2957114483586363, 2.501733231397207,
					2.305582226145, 2.003675418314074, 2.449479846180245,
					1.537573501394158, 2.146447910079424, 1.8870930135049866,
					2.3495189713406854, 2.252266781296336, 1.8633585529768697,
					1.7648918502259083, 1.9380486542692408, 2.416169211300652,
					2.5798929112340465, 2.768127411452447, 1.96197270710421,
					1.8777493095061775, 2.0920652311315204, 2.326179410265892,
					2.0756919815721737, 2.613866128328804, 2.197846863061006,
					2.905788790907957, 2.6312471716880808, 1.8970355856800039,
					2.5583242351278597, 2.628313926534108, 2.320383130643414,
					2.1657752211761117, 2.594574687046235, 2.337632189628244,
					2.3729501663485273, 2.647965675872242, 2.1348445816426156,
					2.0670601298320017, 2.482288595481739, 2.540146757324354,
					2.1032659712828368, 2.24390356931488, 2.6430699396185964,
					3.175220701678632, 2.6026048102058486, 2.353728970490501,
					2.1260254734047113, 2.5131993278303577, 2.250601826472904,
					2.568862857670528, 2.4043945785730876, 2.256111289545214,
					2.50363597340234, 2.4905476741438313, 2.2057705854386924,
					2.5934572612240747, 2.5088946008460646, 2.6312134820575186,
					2.875151595279988, 2.307605435285144, 2.2132987811258453,
					2.6097552570454483, 2.487292478101179, 2.5965256590467756,
					2.2895076365889215, 2.559910644158505, 2.3640470839757244,
					2.344944246047288, 2.0384021975562447, 1.8833178785498808,
					1.7337398727767852, 2.029929183438489, 2.5436065951590168,
					2.2577922835368733, 2.699617596779899, 2.5646456921979968,
					1.8806149018152667, 2.3458784848990795, 3.0598519709337313,
					2.425600955839293, 2.3442281531810267, 2.5590021595441454,
					2.281818528137894, 2.4657248781969727, 2.7897209531599128,
					2.3131979067967703, 2.3191666188000624, 2.169867028243185,
					2.004481837366861, 1.865834600111293, 2.2016074080174746,
					2.549925145800995, 1.868875850859259, 2.2355310777815953,
					2.2072594187681287, 1.9284831723364042, 1.6731739522131357,
					1.8883677730407968, 1.719637933328975, 2.0980663041665224,
					1.6594514097764048, 1.4571911555687158, 1.7035297019548687,
					1.4568294657817016, 1.6449854437384452, 1.9287488080081139,
					1.3203112508732207, 1.7507524465738085, 1.3956428201357167,
					2.0739812771064985, 1.6468847155403772, 1.623730660745045 },
			new double[] { 0.011807451258323503, 1.1322986512189877,
					3.459017884444574, 3.4200783462055733, 4.183197575521359,
					5.117807499475531, 4.372319469050903, 4.797672244062835,
					4.945734563748036, 5.021619269379444, 5.354977570631535,
					5.224347539933164, 5.228002920786645, 5.0162614880326455,
					5.072661418205821, 5.740971824026811, 5.883116085363537,
					6.561249463339864, 5.270465523060586, 5.613440126486153,
					5.394667749639746, 5.182410306738043, 5.893717351113029,
					5.641811085440746, 5.206698295054373, 5.667572663125491,
					5.7674291966814755, 5.165457028288879, 5.0841496384768385,
					5.390381392816367, 6.7850076340193315, 4.7427005541233935,
					4.71917628218225, 5.946213775583381, 4.801024616091112,
					5.582731613844414, 5.292767954248992, 5.236358671997874,
					6.388338683911866, 5.221776493371416, 5.410506751709236,
					5.428666773096869, 5.977889971394378, 5.222434923618842,
					5.058088345614653, 5.469698901263276, 4.894101069708512,
					4.673230180917466, 5.490695348632611, 5.475576136017954,
					5.491612307419676, 5.167092194851217, 4.785508640668974,
					5.873308061865248, 5.752227418057369, 5.113875597788583,
					5.75974565711547, 5.115219039100593, 5.7255882074368625,
					4.868358028182621, 4.5732750284490065, 5.460995054011828,
					5.579473650171064, 5.977491104139145, 4.884350705570693,
					6.172342590675035, 5.7640623157260045, 4.461215311513343,
					4.661105544682592, 5.858524151754547, 6.610640327688866,
					5.813707092080161, 5.725221843110072, 5.455969356405854,
					4.649889522158102, 5.176878429912425, 5.23825172677553,
					5.738426008173734, 5.338271392302863, 4.965145680521997,
					5.52294571325739, 5.157771591398552, 5.034934553371578,
					4.75351417701318, 5.573570086966989, 5.2462289295671845,
					4.411683913854856, 4.548323456355253, 4.589601929907335,
					5.025679732330548, 5.83816180864658, 4.774311536173645,
					5.023766154524215, 5.530114047453147, 5.653211264747483,
					5.437011071499777, 5.467167737410718, 5.173604924535508,
					5.344276841747201, 5.102830063133153, 6.637378894051537,
					5.713316106756034, 5.396786844462345, 4.800041878621914,
					5.856162428579694, 4.362442423533806, 5.25811464917534,
					5.349939924481631, 5.386587667506016, 5.7485506039025305,
					5.838164130972961, 5.076987687578418, 5.257149576198,
					4.576709307148307, 5.587446910238426, 4.907984131102798,
					4.982751455254122, 5.4421413578829165, 5.428525282154591,
					4.881216944314242, 4.978375426628458, 5.447074351035817,
					5.047687908810469, 5.497338897636038, 5.835802769496214,
					4.7978327558652225, 5.1079797762987305, 5.282402866060988,
					5.026679688985048, 5.029175228543973, 4.7430014238272005,
					4.8313250385819915, 5.616240898369135, 5.2478026359129055,
					5.165031437961064, 5.1820330237042285, 4.8548772830630735,
					5.617312627031966, 5.939278768488748, 4.938418606963983,
					4.9879500259956195, 5.388904242060284, 5.978994407636814,
					5.5587471569362705, 5.416563935716983, 5.519099075876149,
					6.299639894593303, 4.926541865788636, 5.347021756649337,
					5.523889981616132, 5.590055882667583, 5.541537259632852,
					6.040476608176188, 5.592712870820772, 5.18697395649967,
					5.504501687435366, 5.607274572135822, 5.8897214104320295,
					5.776544612086971, 5.2554934692491235, 5.78243036686702,
					4.74278545554316, 4.990448629282304, 4.421740596709397,
					4.725251085843527, 5.009555603023066, 5.409500058295562,
					5.151910986469821, 6.152780621277569, 5.95478800240244,
					5.145939601241332, 5.249144638133163, 5.300552661347556,
					6.132110468514201, 5.753343153064011, 4.2679548422265015,
					4.8805931747894435, 5.5440810810178665, 5.258149769017194,
					4.622616335391406, 5.585530940696267, 5.722919206488412,
					5.9852250549127515, 5.359914192756084, 5.223068850673474,
					4.6398489125158155, 4.919738789607103, 5.657126456723719,
					6.089745661012655, 5.312740210741739, 5.559494361805209,
					5.1219783360602715, 5.400383011074126, 5.6475865795246705,
					5.800624556578331, 5.3162110913208425, 4.7275620601621995,
					6.654691233524917, 5.726984595743923, 6.179821672288699,
					5.218937430166119, 4.901279731112463, 4.963947010669148,
					5.57187964811354, 5.158012303195849, 5.301078365951515,
					5.30111760155748, 6.204121193791094, 5.455265325053966,
					5.480746287172776, 5.353252080682056, 5.736678788549108,
					5.584170863678105, 5.700740897655443, 4.5048054958332,
					5.3447010010236236, 5.557898915151039, 6.262971240343665,
					6.104840464433095, 6.678001934164067, 5.885489245866459,
					5.62026808991933, 6.376195876181797, 6.78890551779996,
					6.948234526229036, 6.369558930592822, 6.482355065406344,
					7.3791728549610385, 7.4783783362009295, 7.952699606755513,
					5.792025237896394, 7.367955762747311, 7.654816057240297,
					6.544124786360094, 6.420398696310425, 6.047992768899356,
					5.355596138511718, 5.8529520892846065, 6.293228673643032,
					5.267779888243007, 7.037903566999839, 6.1458210974013,
					5.039530845268698, 5.206900452669727, 5.050690912533539,
					4.9204807030564774, 5.012616161925202, 5.559393102278167,
					5.544911546282898, 5.751877542420032, 4.889728940912211,
					5.622600113273577, 6.018845724232414, 6.141565325872348,
					5.922040349280688, 5.05743114821318, 5.493650344510228,
					5.704983879523062, 5.466700534520875, 6.784013520770307,
					6.652469654634339, 5.512703635725949, 4.987113803915839,
					5.148906540022458, 5.591099706070942, 6.293435468908037,
					5.629474834921381, 5.951940983733155, 5.376365725478187,
					6.109727522712617, 6.354735660696856, 5.870700958095073,
					5.417762399157299, 4.495390391996699, 6.175956336007392,
					5.561256712703691, 5.1300047348999245, 6.365014998808389,
					5.5693252406849965, 6.140009433033647, 4.972584805253963,
					5.348604072849338, 5.784313328873056, 5.241955138662154,
					5.556424059155621, 5.134919744702817, 5.155354685013326,
					4.901400055862137, 4.982368345737111, 6.269601953225825,
					5.444928003708252, 5.4781208893576805, 5.8546986626638375,
					5.777956466319045, 4.958493257303078, 5.831952623617134,
					5.060060875152687, 6.907520862017128, 6.519086092585921,
					5.1933822209819835, 4.888039495758314, 6.488324761001314,
					6.2941239436363015, 5.829592031933428, 6.400565391861329,
					5.288086274810103, 6.086379510498867, 6.2007026324337575,
					6.2739934474102395, 6.36438154612378, 6.719112359762782,
					6.496359375642782, 5.522467263729765, 4.573144623974287,
					5.873401290651964, 6.21508713661895, 6.67933457592053,
					6.222077831388134, 5.1391952636930744, 4.505283980655886,
					5.875135018517286, 6.154278070550571, 5.214852612634363,
					5.37193634156126, 4.872484971849059, 5.889104913580157,
					6.604821840315644, 5.681501500549452, 5.741790973286959,
					5.262506202457142, 6.162017457367641, 6.142171089888071,
					5.598092492983293, 5.235984929450964, 5.7776384254055895,
					4.7462919265355366, 5.028297436380463, 5.122943690642278,
					6.000068151625467, 5.984597509580226, 6.02131737284488,
					5.832121534907873, 4.9077650570682305, 5.180208258448009,
					5.884799683607909, 6.0839593652803705, 5.849584945961958,
					5.5987608012701, 6.190980659094177, 6.089708061759351,
					6.189613901903287, 6.280095089588736, 5.59042534138326,
					6.861463388953049, 5.521460597748936, 5.603246611817282,
					4.825066396129252, 6.201641120324529, 6.0446287105499845,
					6.691688322095131, 6.354929041415269, 6.644400392121931,
					5.45660477278598, 6.045249249375054, 5.072924650179674,
					6.339673451917453, 6.062377363362878, 6.78104969265712,
					6.557017915291255, 6.318239095663989, 5.947568827775586,
					6.40371565246324, 5.80228595420714, 7.511503303620169,
					5.032220422767548, 5.243023066819708, 5.161166382283139,
					5.5571176384146295, 5.571239834584024, 5.218109584200243,
					5.739131751936166, 6.191064457796768, 6.27940930832534,
					5.4383866827277325, 5.154480301137731, 6.170337989989822,
					5.759710017542697, 5.408586013778269, 6.150048813052187,
					5.576200830022205, 6.0722665964221045, 7.370954249037454,
					5.826057995004471, 5.976779580622689, 6.69663830077117,
					7.349779092626088, 5.751074511798036, 6.564730149103078,
					5.9164326147641875, 6.343618946966768, 6.57413529646764,
					5.783046396016466, 6.212889242159543, 7.752797886182489,
					6.3100209150182875, 6.066182787514824, 5.968201569512662,
					6.523682819225104, 6.379746477931252, 6.350218891132416,
					5.735794554225904, 5.994542377789116, 5.680437244276745,
					6.337680356200639, 5.702293918400826, 7.145212552952942,
					6.290999681581608, 5.678104702432229, 6.478738822020797,
					5.761701185401792, 6.142113606311729, 5.17393361048449,
					5.024939685469803, 5.299702496626951, 5.509414045406195,
					6.200987747380558, 8.57418401048601, 6.544203582719346,
					5.594999402649284, 5.425733044664792, 6.706498296396476,
					5.58537682021141, 6.148784038890016, 6.703487439640133,
					5.768205550580388, 6.72421393536266, 6.0349910951240995,
					5.596886748100069, 6.309787268350469, 6.5677654652764845,
					6.659342283596776, 7.710598286674448, 5.976514742134793,
					5.192613050881067, 5.825557561267674, 6.011845952210257,
					5.7320865874814215, 5.701124382209397, 6.2417556514682895,
					5.904752536800298, 5.733114253970817, 6.163680884638859,
					6.825448013154832, 6.366106636077036, 5.2870227391852636,
					6.804543033125204, 6.285338376483069, 6.6618493603441955,
					5.40731689019031, 5.97021599429032, 7.31084813446638,
					6.191829678999062, 6.146600647075015, 6.0053185233832425,
					6.169084094458304, 6.601989508658688, 5.933924245931099,
					6.333053064996055, 5.607800888860303, 6.568514868411493,
					6.324473425493737, 5.050162146171538, 5.706838060962039,
					5.67331235923411, 6.422239900348321, 6.525575286885783,
					5.97769471464922, 6.735695587782586, 6.149079101405192,
					5.50138947843238, 6.34158955411339, 5.823531316427564,
					6.141600794998536, 6.051531078340071, 5.737841791069853,
					4.87598282922945, 5.171144224598104, 5.239709019686855,
					5.5854469154802615, 5.837656882227589, 5.961595934317872,
					5.938506221546134, 5.683455758344755, 7.187073172360463,
					6.043671398926046, 6.094733407714271, 6.622902372304771,
					6.250341068535316, 6.106459311351938, 6.976635711037861,
					6.136667672294889, 5.853806534832354, 5.6647022648883025,
					6.954196052333569, 7.172778155675763, 6.009098478490862,
					5.592463860550943, 7.003022110961722, 5.609851580716791,
					5.588393692439253, 6.12979584625358, 5.8484816100816195,
					6.058406122336369, 7.042704059680902, 6.637921749624434,
					5.530008439311692, 6.357684371706823, 6.16054769108451,
					6.318846715131519, 5.691755501337083, 6.083049556431749,
					6.650356884057783, 6.529235460863041, 6.059920588043439,
					6.25850788786451, 6.213092338682166, 5.9542947550029774,
					6.414328723529661, 6.272803138517918, 6.40892314277155,
					6.215817782005466, 5.966600018636377, 6.985909529298519,
					6.607346702205518, 6.646959964327302, 5.956944424383944,
					6.124695384599111, 6.264741163415173, 5.130638640627369,
					6.000663982045239, 6.404783377378837, 6.484071174357348,
					5.947291720216209, 5.831755122865141, 6.081041305814412,
					6.189728319027599, 5.437499110660277, 6.001805262528732,
					6.230420818543822, 6.0975885573394955, 6.170680314748863,
					6.268597007425842, 6.657086650897395, 5.167148375350486,
					5.588252916942209, 6.197935213955501, 5.863751026738629,
					5.47717708879144, 5.976094606106308, 6.646482858452358,
					5.093625558200648, 6.074657643969778, 5.540469168933241,
					5.019207519972352, 6.1323378849606245, 5.60040749467305,
					5.131239710004451, 5.32843961096932, 5.667793551504928,
					5.472977951853915, 5.815170460740432, 6.4450761993665076,
					5.608357087301639, 5.820133399681805, 5.12183130277732,
					5.764930303071815, 5.3020440031853315, 5.558224238048325,
					6.1618394944317565, 6.22551163366434, 4.649944557871028,
					5.624967533772663, 5.960989643730221, 5.370303897091971,
					6.030664025451504, 5.066438317291929, 5.221142026249267,
					5.789946000111192, 6.321394991212715, 6.785588444928638,
					6.552664726657704, 5.8084492025540815, 5.04916025192447,
					6.450338001027721, 5.705898555228341, 7.3601133057711925,
					6.858567547011316, 6.406281496975368, 5.674399970987399,
					5.930333158962676, 6.705386204730189, 6.977040542370054,
					6.454305175429846, 5.959221040616326, 5.724690255416193,
					7.2222120013848015, 6.071167041042365, 5.155040765922116,
					5.577411447393553, 5.656540910739107, 5.844436931151622,
					5.87018178914173, 6.061143573344186, 5.804848981297696,
					7.069389633615439, 7.003172964255427, 5.992215477231189,
					6.502491563015543, 6.20878386573375, 5.865699606121636,
					5.740554744779677, 6.133647811331463, 5.949491641758015,
					6.371425399143114, 7.176911464908708, 7.134547313620657,
					6.31738520350767, 5.758950628039176, 5.665784652776178,
					6.345487309342064, 5.994094129344041, 6.298775315596891,
					6.169751170096736, 6.522023137760003, 4.82548649031273,
					6.597107348223415, 5.255631832035792, 5.693943790806174,
					5.750165456519644, 6.036918380248099, 5.63212147844074,
					5.172058135495219, 5.256044219006368, 5.637787375155802,
					5.705541020977896, 5.658149753953956, 7.325873688955274,
					5.865213357844792, 6.32117123386861, 5.556866625993735,
					4.805381719699934, 5.7019434364910255, 6.003314845963909,
					5.512015732382684, 6.169872804303276, 6.624064924380954,
					5.124179704893979, 6.108927137953501, 6.209074346766476,
					6.291106409085877, 5.807839148384711, 6.320677885743473,
					6.368289149827117, 6.126064326755612, 6.443348493083094,
					5.430963791331345, 7.120019394117341, 5.39204715164037,
					5.827422688512181, 6.048484873408138, 5.905513638955473,
					5.973481477092997, 5.901966017384174, 6.3865462495457,
					5.8164206431123375, 6.775956660715921, 6.845961008225405,
					5.8632786758021185, 6.420788757885247, 7.126610743589143,
					6.228342203889914, 6.0735889592746535, 6.142220304027703,
					6.1418285704508175, 6.78202769476062 },
			new double[] { 0.0011383217500897638, 0.0010286862729803792,
					0.22459768372897523, 1.3020258000501763,
					1.9574506045809201, 2.5379230956926673, 2.6954114354920065,
					3.5434099683860296, 2.66288620563887, 3.580637330505463,
					4.199097695373886, 3.1343454359545153, 3.847657286204266,
					3.488464773207999, 4.102006498413083, 3.8084171075790354,
					4.547113954367315, 3.9333506610645093, 3.88061897406914,
					3.6423833593265416, 3.1084955810142016, 3.819252319543358,
					4.313277226461028, 3.697071507069862, 3.834835299599594,
					4.514926240617054, 3.262432264425856, 3.532397888217341,
					3.466383502211989, 3.7277672483611632, 3.5340993090338286,
					3.113771785171734, 3.299016930622924, 3.110613491895834,
					4.290784956978701, 3.298884690649394, 3.714734756457939,
					3.684032654318724, 4.926880300038647, 4.037886437383557,
					3.3768744832714637, 4.371335947474401, 3.9727660596415615,
					4.596804298197391, 4.190133196974983, 4.236968233212109,
					4.595352347368821, 4.606498061261928, 5.151481042777711,
					4.763088172147715, 4.924712456296507, 4.9950328010118525,
					4.194205575775436, 3.9268196398179223, 3.958677886429915,
					4.225438620088142, 3.882907719093809, 4.5116272787373015,
					4.402487560665017, 4.949872514662715, 4.450631364137917,
					4.48798618654144, 4.920545816706832, 4.465400696421462,
					5.108129201904756, 3.756335495290756, 4.060141859403158,
					4.187805299026821, 4.892948033974682, 3.672124379134396,
					3.9995988667460987, 4.721360458818361, 4.382864080608276,
					5.090153469018225, 3.813930430073585, 3.8009851009728086,
					3.986524100957901, 3.979210228398426, 4.270964325116096,
					4.423016144882905, 4.673764473851528, 4.518643047861256,
					4.570270610085624, 4.026256010890649, 4.857247626653151,
					4.645520097273095, 4.647756491843642, 3.9213823313286635,
					4.434309053455093, 4.956107617383828, 4.432252539937479,
					4.27021925282276, 3.8649629785237876, 4.154733394681138,
					4.095409518313123, 4.7154042842274615, 4.354637213194506,
					3.6989719705594273, 4.20749907844506, 4.45263867287068,
					4.308353894786123, 4.619261760949555, 4.96089177843585,
					4.201496642993693, 4.377568304289586, 4.641197234714699,
					5.230943814098687, 4.917568979492621, 4.8669799728254075,
					4.672502484039681, 5.0735926857241385, 4.69663217974804,
					4.501405045596671, 3.8054863495937044, 4.720894231468262,
					4.7456003864228915, 3.923452148394315, 4.360796471851343,
					4.38722915759991, 4.09056986967755, 4.776003576824472,
					4.756393784424287, 3.895728042295232, 4.0480209380580225,
					4.439019476344544, 3.900061206465875, 4.428429306053578,
					4.433510175577613, 5.078749466126389, 4.2499604355252485,
					4.546253282394096, 4.776094524548838, 4.953436268056487,
					4.419776397381321, 3.975871445255121, 4.061464766425518,
					5.079996458626613, 5.130159622537473, 4.736931458842419,
					4.603371898589678, 4.743750233079142, 5.111309643574971,
					4.112087681611783, 5.123035465356464, 3.9771097347489954,
					5.040530161927067, 5.1327343290891605, 5.025063428206437,
					4.0842762335363085, 4.21351139473348, 4.699609982772599,
					5.417294332439898, 4.698050037884323, 3.794351419827271,
					5.032907199185159, 4.787960695757429, 4.4247853497711285,
					5.209159237831525, 4.042357872155196, 5.448948317952446,
					5.36722090362596, 5.068144850059993, 5.110880362994194,
					4.533480837103453, 4.262819310163065, 4.928987394216161,
					4.442475593222101, 5.464890654594585, 4.663307687025161,
					3.617973334156134, 4.576971907397939, 4.0652371197174775,
					4.034043732182082, 5.201615266785153, 5.194785381941515,
					4.575056345293914, 4.798096937742302, 4.214002329287549,
					4.940490443929015, 5.5010541270894215, 4.819534088075821,
					5.042260958379909, 5.229828015073428, 5.059288775503154,
					4.8852701176129365, 4.911942584736334, 5.697902629676835,
					5.048812615172111, 5.064278994282853, 4.400210264253916,
					4.987221971352621, 5.417677583553216, 5.567834351261639,
					5.070508349661923, 5.866313029355792, 6.148692211164954,
					3.9176860700691374, 4.553037883509521, 4.437278815306041,
					5.059376822881555, 4.672152555063646, 4.819510764014818,
					4.300687503788018, 4.361757629240487, 4.9320125635794065,
					4.929733752096965, 5.3465209129333475, 4.469837283598441,
					5.718931181044506, 5.390834872930438, 4.985833167022112,
					5.547934868066268, 6.21863777594458, 5.260455547366182,
					6.707382942586672, 6.671516614267003, 5.579295854073624,
					5.566967037474699, 5.757527524628938, 6.562502013277262,
					5.609063072983183, 5.079181311560377, 6.374192230244494,
					5.919351040648377, 5.945152673100668, 6.095984937716482,
					5.959196552563299, 5.545449534727353, 6.255178544401335,
					6.860173604256099, 6.280021854035075, 6.433489043171913,
					4.9062696667984556, 6.170152138336277, 5.964242367100262,
					5.754490676788696, 5.659438394075292, 5.550173179462278,
					6.002983467487814, 5.877192466582172, 6.353305764098066,
					6.4058616886862945, 5.87909952708664, 6.293404257570674,
					5.941328358028317, 6.407848627073628, 6.53670592234051,
					6.914495600859785, 5.753085320975238, 6.292415012181063,
					6.307549131837773, 6.4464358634214864, 6.757135282260658,
					6.407624017030305, 6.415651078111096, 5.720279806731547,
					5.781050198167341, 6.033975215181316, 5.798256623731467,
					5.3829049620103655, 6.31373206880175, 5.167932027143318,
					5.510849704932467, 4.98701200263176, 5.594928095181212,
					4.62880278660942, 3.963153428474194, 4.6284855991792995,
					4.471616266127671, 4.847592602478408, 4.998366561215562,
					5.156222484234812, 5.696280539263992, 5.501771365421785,
					5.838515655171198, 4.639456642166756, 4.112044594899897,
					4.523090653254155, 4.6780068811775335, 4.858807862407148,
					4.348831015474431, 4.769709947114569, 4.925397624855946,
					4.131418491743442, 4.63214091982474, 4.353389196750239,
					5.35995779957173, 5.028956019530049, 4.998192806878098,
					4.064134755012648, 4.733541444796458, 5.4695597788448325,
					4.898035801569534, 4.964092733641496, 5.257510369654352,
					5.118479467001337, 4.529970823344376, 5.586645698513533,
					4.704635072927485, 4.4695716356830975, 5.185139144126789,
					4.4835598133512296, 5.525277390825463, 5.6357536307695355,
					4.518483867460105, 5.169797929600951, 5.1251816472340606,
					5.398873525095122, 4.810457135553872, 5.61300467833924,
					4.953062316948314, 6.284156437265787, 6.151355506130558,
					4.875108275581131, 4.758547588050984, 5.007966886745585,
					5.523604312469645, 5.836160293325328, 5.415707895303052,
					4.839709061096967, 5.4214314311642315, 4.922453619314239,
					5.306415510844967, 5.677673005414678, 4.533673137461553,
					5.322098881618464, 5.085283829844713, 4.899705440975658,
					4.89846119563203, 5.956206100477709, 5.387678705922198,
					4.804358911987508, 4.339858984742194, 5.503238361887806,
					4.986872061599198, 5.104856975382375, 4.733924341575431,
					5.229689736747507, 4.568209724813631, 4.160625599672937,
					4.187279159928502, 4.652567860520502, 4.877248519318847,
					5.3020408935382415, 5.549250721922314, 4.38388797214865,
					5.040567272874946, 5.42738670632638, 4.829271331723585,
					4.593858470342301, 5.507418340995086, 5.671611738007663,
					5.655655620594496, 4.364766474559057, 5.288264966827091,
					5.002706040474401, 5.196239666822538, 5.256916323460703,
					4.527872460043757, 4.850305097343188, 4.707905271809579,
					5.284566659826468, 5.81168647464845, 5.051186246531605,
					5.02491442505092, 5.314085326234699, 5.036352786364711,
					4.7940209219863, 5.5671859090048965, 5.227729207052722,
					5.158937947364855, 4.165659921991256, 4.219862005802979,
					4.1108627890108, 4.840742533273617, 4.550859140738826,
					4.596688273309285, 4.6567017262612955, 4.416187393293818,
					4.673734957093166, 4.863674887304017, 5.222281377460965,
					5.094469641495265, 5.305343287168556, 5.025592018473798,
					4.532756306528466, 4.981300802544257, 4.3834532967154285,
					5.5969542437422755, 5.994613025990557, 5.258273823462008,
					5.6134382474500795, 4.638918615694837, 5.052366127985388,
					5.4987292289529535, 5.040912660279835, 5.751739607187378,
					5.615245292006476, 4.687260841032757, 4.952236322856306,
					4.8182439446314405, 4.962285364839681, 4.977438633855094,
					4.92433150171933, 4.598043935015297, 6.02751075180936,
					5.380616102385971, 4.834514194711437, 4.561345297823987,
					4.984736308761669, 4.898595651590732, 5.3698451284678335,
					4.627595920884987, 5.870820944355448, 4.9408805931744135,
					4.597057047082655, 5.2559945472907454, 4.365718844650592,
					5.524723229606935, 4.892215419095635, 5.0399444779178735,
					5.198432231596129, 5.01086293161187, 5.380876952007363,
					4.898585767314523, 5.418798944754029, 5.449274811001889,
					4.868444515595294, 5.393811654720866, 4.885231974190347,
					5.572308663417583, 5.525352775685849, 5.948934166337724,
					5.178463700550739, 5.434067804126054, 4.572744828280303,
					4.6793593628563155, 4.596248853722262, 4.983603720624278,
					5.5633773030233105, 5.3859023786651266, 5.149865888695005,
					6.06134521663544, 6.781549705765499, 5.1037455882558564,
					6.054676858996187, 5.60574224583988, 5.569856789130275,
					5.63826545804288, 4.813933209506581, 5.972110449773464,
					5.343995718392442, 5.259609404697477, 5.85068745847895,
					5.278908797170418, 5.065553197607898, 5.4676723730864385,
					4.697592359719557, 6.2189068351047085, 4.651413379847224,
					5.7393873196565055, 4.619190191946583, 4.57339322170168,
					4.76902810604719, 4.804309356518426, 4.679244129050559,
					5.226255648611816, 4.752059550009283, 5.095103163054339,
					5.420437993397107, 5.482101318407662, 5.03067697366351,
					5.3889362925694995, 4.495384681274574, 5.830661408822409,
					5.614832374450306, 5.665038471678501, 5.1607404107819494,
					5.528559660110457, 4.869614314989716, 5.5106524888525215,
					5.138610386592472, 5.42444588760059, 4.598400771833761,
					5.331921805357102, 5.72209880695768, 5.647983593921029,
					4.365408688982896, 4.382831774182538, 5.444220973158208,
					5.579016108009984, 5.534358419179728, 6.103810902152485,
					5.772326528332395, 5.360251596192065, 5.046806353232672,
					5.35717271437685, 5.853355181049014, 5.488339705122657,
					4.9695442961106675, 5.548175599038467, 5.285319565119881,
					5.359397224943272, 4.615287904728482, 5.302107740693497,
					5.7951168999885265, 4.133729133290575, 5.799754510985309,
					4.614886112147639, 6.430592623402033, 4.939623600356981,
					4.898651590711854, 4.6944035843135525, 5.203129518050422,
					4.791749416923097, 4.237971023554599, 4.708202324217912,
					5.386388667883831, 5.062634125362722, 4.81742101572035,
					4.558409848492527, 4.82141351604935, 5.841724672298276,
					5.066426439216543, 4.888695118733923, 4.46740169187733,
					5.060527580907202, 5.365851910255239, 4.1605940577833405,
					5.184639213444167, 4.853569715541108, 5.207729219184253,
					4.8740540838494555, 4.594741438141444, 4.791359348274483,
					5.226423978987669, 5.335583549008724, 4.530704462257215,
					4.826085842081258, 4.6818414750201995, 5.358532724393906,
					5.284976563809202, 5.107729175518053, 5.400758605944556,
					5.52473128479583, 4.770218874086617, 5.416188418846435,
					4.391778506662325, 4.557674802541331, 4.411662343122817,
					4.278520954208387, 4.134323899401146, 3.926872485065538,
					4.374868369785386, 4.303531100416093, 4.150201528649034,
					4.183028121553262, 5.089857069681255, 4.612279128116127,
					4.893948124542355, 5.302602104765759, 3.9593156001012826,
					4.340067589999793, 3.8866882398427207, 4.74644973018738,
					4.125684957090185, 4.5135122671430175, 3.7662158272772626,
					4.261294538100746, 4.493314904469123, 4.43468359225684,
					4.1194565398846725, 4.887788826902049, 4.655087343757073,
					4.007727546179254, 4.040085800355263, 4.159370965109982,
					4.22259423516368, 4.603865500964252, 4.9101703199319795,
					4.7117954688996475, 4.695824288277387, 4.614919931751933,
					4.513785653838626, 4.038190905876007, 4.112354558253888,
					4.023801956544125, 4.548734852126778, 4.9177482050138455,
					4.169874633449376, 3.7296664638643917, 4.908147719164638,
					4.2829500125921856, 3.7102057228926015, 4.58043125159664,
					4.094027123300924, 4.160496875028953, 3.761911212980077,
					4.19580983757984, 4.054950693813177, 3.744047522016349,
					4.304216189354849, 4.160593776794142, 3.6846710653647157,
					4.5805993320156775, 4.331453869656883, 4.001904885508807,
					4.343749272930759, 4.47034607029814, 4.822199538392147,
					4.814099822977522, 4.912935595042166, 3.761002353080309,
					4.249565304233679, 4.7536794317048345, 4.90735136718631,
					4.5109427440839465, 4.478701416656484, 4.617733940646923,
					4.401970014316196, 5.0275442368760235, 4.406928566493026,
					4.808207877222458, 5.3818501866692365, 4.863836206533624,
					3.9238006457892265, 5.436060957019111, 4.779500456178429,
					4.781101452065003, 4.170105899447311, 4.536766074464285,
					4.509889440380532, 4.940069420958102, 4.75029788161856,
					4.776388558490149, 4.650708087963821, 4.550780423735877,
					4.776511933284503, 4.18067834660051, 5.042947919732834,
					4.583790158843187, 4.952350104371921, 4.87047595408034,
					4.299732297153241, 4.9104802456523515, 4.766837441918368,
					4.304075066460517, 4.1493436461191475, 4.857878736027152,
					4.843973498013927, 4.946099825697511, 4.584338514834927,
					4.738391652150519, 4.190968328511952, 4.537467167164237,
					4.538086348337331, 5.017317293503223, 4.514854853801213,
					5.072539754401572, 4.6035639362690635, 5.007021244159121,
					4.477765137717856, 4.7550285707918105, 4.885705030596841,
					4.793535839033019, 4.755641318409831, 5.462884807239876,
					5.108567625380088, 4.90957693109809, 4.953721093318577,
					5.351353327049509, 5.4586680117156465, 5.4623364041471785,
					5.856333969598877, 5.364637683549111, 5.694146056969264,
					6.215969115406105, 5.478799049836458, 5.797281492261562,
					5.456520225547522, 5.352364523373867, 5.715948692914714,
					4.811373729094619, 5.35445758331865, 4.8645913510949494 } };
	
	public static final String NA23_NAME = "Na23";
	private static final LineData[] NA23_LINES;

	static {
		NA23_LINES = new LineData[TEST_DATASET_COORDINATES.length];
		for (int i = 0; i < 3; i++) {
			NA23_LINES[i] = new LineData(lineName(i), NA23_DATA[i],
					TEST_DATASET_COORDINATES[i]);
		}
	}

	public static final ElementData NA23_REDUCED = 
		ElementData.createElementData(NA23_NAME, Arrays.copyOfRange(NA23_LINES, 0, 3));

	private static String lineName(int i) {
		StringBuilder sB = new StringBuilder("Line ");
		sB.append((i+1));
		sB.append(".xl");
		return sB.toString();
	}
}
