/*
 * #%L
 * LA-iMageS Core
 * %%
 * Copyright (C) 2016 Marco Aurélio Zezzi Arruda, Gustavo de Souza
 * 			Pessôa, José Luis Capelo Martínez, Florentino Fdez-Riverola, Miguel
 * 			Reboiro-Jato, Hugo López-Fdez, and Daniel Glez-Peña
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */
package es.uvigo.ei.sing.laimages.core.io;

import static es.uvigo.ei.sing.laimages.core.io.ResourceLoader.loadResource;

import java.io.File;
import java.io.IOException;
import java.util.Arrays;
import java.util.List;

import es.uvigo.ei.sing.laimages.core.entities.datasets.ElementData;
import es.uvigo.ei.sing.laimages.core.entities.datasets.ElementDataset;
import es.uvigo.ei.sing.laimages.core.entities.datasets.ElementDatasetConfiguration;
import es.uvigo.ei.sing.laimages.core.entities.datasets.LineData;
import es.uvigo.ei.sing.laimages.core.entities.datasets.coordinates.HorizontalLineCoordinates;
import es.uvigo.ei.sing.laimages.core.entities.datasets.coordinates.LineCoordinates;
import es.uvigo.ei.sing.laimages.core.io.LineDatasetLoader;
import es.uvigo.ei.sing.laimages.core.io.exception.NoSuchStandardElementException;

public class TestDatasetUtils {
	public static final String NA23_NAME = "Na23";
	
	private static final File TEST_DATASET_DIRECTORY = loadResource("/dataset");

	public static final File TEST_DATASET_MISSING_POSITIONS_DIRECTORY = loadResource(
		"/dataset-without-positions");

	public static final File TEST_DATASET_MISSING_POSITIONS_DIFFERENT_LINE_LENGTHS_DIRECTORY = loadResource(
		"/dataset-without-positions-different-line-lengths");

	public static final File TEST_DATASET_INVALID_LINE_LENGTHS_DIRECTORY = loadResource(
		"/dataset-invalid-length-line");
	
	public static final File TEST_DATASET_LINE_POSITIONS_REPEATED_DIRECTORY = loadResource(
		"/dataset-repeated-positions");

	public static final File TEST_DATASET_COORDINATES_FILE = loadResource("/dataset/positions.txt");

	private static final ElementDatasetConfiguration TEST_DATASET_CONFIGURATION = new ElementDatasetConfiguration(
			0.060d, 0.527d, 0.080d, "C12");

	public static ElementDataset loadTestDataset() throws IOException,
			NoSuchStandardElementException {
		return loadTestDataset(TEST_DATASET_CONFIGURATION);
	}

	public static ElementDataset loadTestDataset(
			ElementDatasetConfiguration configuration) throws IOException,
			NoSuchStandardElementException {
		LineDatasetLoader datasetLoader = new LineDatasetLoader(configuration);
		ElementDataset dataset = datasetLoader
				.loadAndNormalizeDataset(TEST_DATASET_DIRECTORY.toPath());
		return dataset;
	}

	public static final List<String> TEST_DATASET_ELEMENT_NAMES = Arrays
			.asList(new String[] { "Na23", "K39", "Ca44", "Ca43", "C13",
					"Mg24", "Si28", "P31" });

	public static final LineCoordinates[] TEST_DATASET_COORDINATES = new LineCoordinates[] {
		new HorizontalLineCoordinates(0.03162d, 0.0, 5.1856800000000005, 0.0),
		new HorizontalLineCoordinates(0.03162d, 0.0, 5.1856800000000005, 0.08),
		new HorizontalLineCoordinates(0.03162d, 0.0, 5.1856800000000005, 0.16),
		new HorizontalLineCoordinates(0.03162d, 0.0, 5.1856800000000005, 0.24),
		new HorizontalLineCoordinates(0.03162d, 0.0, 5.1856800000000005, 0.32),
		new HorizontalLineCoordinates(0.03162d, 0.0, 5.1856800000000005, 0.4),
		new HorizontalLineCoordinates(0.03162d, 0.0, 5.1856800000000005, 0.48),
		new HorizontalLineCoordinates(0.03162d, 0.0, 5.1856800000000005, 0.56),
		new HorizontalLineCoordinates(0.03162d, 0.0, 5.1856800000000005, 0.64),
		new HorizontalLineCoordinates(0.03162d, 0.0, 5.1856800000000005, 0.72),
		new HorizontalLineCoordinates(0.03162d, 0.0, 5.1856800000000005, 0.8),
		new HorizontalLineCoordinates(0.03162d, 0.0, 5.1856800000000005, 0.88),
		new HorizontalLineCoordinates(0.03162d, 0.0, 5.1856800000000005, 0.96),
		new HorizontalLineCoordinates(0.03162d, 0.0, 5.1856800000000005, 1.04),
		new HorizontalLineCoordinates(0.03162d, 0.0, 5.1856800000000005, 1.12),
		new HorizontalLineCoordinates(0.03162d, 0.0, 5.1856800000000005, 1.2),
		new HorizontalLineCoordinates(0.03162d, 0.0, 5.1856800000000005, 1.28),
		new HorizontalLineCoordinates(0.03162d, 0.0, 5.1856800000000005, 1.36),
		new HorizontalLineCoordinates(0.03162d, 0.0, 5.1856800000000005, 1.44),
		new HorizontalLineCoordinates(0.03162d, 0.0, 5.1856800000000005, 1.52),
		new HorizontalLineCoordinates(0.03162d, 0.0, 5.1856800000000005, 1.6),
		new HorizontalLineCoordinates(0.03162d, 0.0, 5.1856800000000005, 1.68),
		new HorizontalLineCoordinates(0.03162d, 0.0, 5.1856800000000005, 1.76),
		new HorizontalLineCoordinates(0.03162d, 0.0, 5.1856800000000005, 1.84),
		new HorizontalLineCoordinates(0.03162d, 0.0, 5.1856800000000005, 1.92),
		new HorizontalLineCoordinates(0.03162d, 0.0, 5.1856800000000005, 2.0),
		new HorizontalLineCoordinates(0.03162d, 0.0, 5.1856800000000005, 2.08),
		new HorizontalLineCoordinates(0.03162d, 0.0, 5.1856800000000005, 2.16),
		new HorizontalLineCoordinates(0.03162d, 0.0, 5.1856800000000005, 2.24),
		new HorizontalLineCoordinates(0.03162d, 0.0, 5.1856800000000005, 2.32),
		new HorizontalLineCoordinates(0.03162d, 0.0, 5.1856800000000005, 2.4),
		new HorizontalLineCoordinates(0.03162d, 0.0, 5.1856800000000005, 2.48),
		new HorizontalLineCoordinates(0.03162d, 0.0, 5.1856800000000005, 2.56) };

	public static final double[][] NA23_DATA = new double[][] {
			new double[] { 0.0d, 0.0d, 6.188195997815331E-5d,
					0.0633347543009192d, 0.09657261460738102d,
					0.13541857364458976d, 0.15083551339946838d,
					0.21794082483601615d, 0.22832145103368107d,
					0.2443915926615489d, 0.25960479651217455d,
					0.2853925435818115d, 0.2511146619367602d,
					0.2479675332516314d, 0.29076238331001797d,
					0.30359816010963736d, 0.40249037068845467d,
					0.4143650433848691d, 0.36686600927632246d,
					0.360125246397006d, 0.3501403759814549d,
					0.3623281762072442d, 0.41096707531599863d,
					0.34496435140080267d, 0.3308205879872711d,
					0.3413060279473752d, 0.3327148740487306d,
					0.2905191567974871d, 0.30411476369123236d,
					0.30898838403715717d, 0.3074524156629861d,
					0.27196310602864093d, 0.2787253387416663d,
					0.28612568161345187d, 0.4202650950311939d,
					0.3751290972520449d, 0.36244827024021437d,
					0.3865701265846255d, 0.4909199793569932d,
					0.49401598743756014d, 0.43300009501629255d,
					0.3090972163867203d, 0.3521872746776201d,
					0.3495959521584882d, 0.29741293067475444d,
					0.2600136680394776d, 0.17892643742792197d,
					0.1334840450422698d, 0.10029567795505423d,
					0.0820360456688582d, 0.05787571562709896d,
					0.05984473070943953d, 0.05280085716239505d,
					0.0402940901338063d, 0.04350769408036739d,
					0.0389732885548259d, 0.03787620338948802d,
					0.038395697050261086d, 0.1151807498466193d,
					0.12631729768273542d, 0.33634526669947007d,
					0.40829911856814416d, 0.5301138168178355d,
					0.5811134885695999d, 0.5221795282979231d,
					0.6653521492563615d, 0.5676538537126996d,
					0.6000364625895773d, 0.4924963810709179d,
					0.5037880716639218d, 0.46333237181042125d,
					0.49382025757047815d, 0.489104985089504d,
					0.3955718453187309d, 0.30354941841216065d,
					0.2705147534097854d, 0.21265525351821188d,
					0.177447181536996d, 0.13832695998172526d,
					0.1107669571860372d, 0.0958798474440849d,
					0.08015478266669473d, 0.09955291190994765d,
					0.1150498362400335d, 0.11174812778427913d,
					0.12708195514767d, 0.10869594038817974d,
					0.14641697712722235d, 0.10828947717154387d,
					0.08958868137308432d, 0.08030555010886661d,
					0.06961543409998369d, 0.09489943233376776d,
					0.09629931515203981d, 0.09787399223474509d,
					0.0832397184002629d, 0.07156593817991676d,
					0.12641883824599076d, 0.11112176063257113d,
					0.14179714756458725d, 0.11746616746009748d,
					0.09297230313730181d, 0.08366178212288063d,
					0.07029922830212719d, 0.2082071488900527d,
					0.19870914800983328d, 0.2740823169904464d,
					0.4053197185942497d, 0.5366238277389349d,
					0.4302223970744381d, 0.6960443055023606d,
					0.4213727235101097d, 0.4371944069152606d,
					0.3632289454416373d, 0.6014083808421822d,
					0.5152715595308998d, 0.48910285710050194d,
					0.5352444387961435d, 0.4537855648176108d,
					0.400041087164769d, 0.420095278147748d,
					0.5785571180219318d, 0.5154882074148543d,
					0.42967959502825853d, 0.444206275030934d,
					0.46280315521563936d, 0.5831865345461528d,
					0.4172903921496832d, 0.33741378331456806d,
					0.3486030800352329d, 0.31118706759387943d,
					0.25792032494136374d, 0.2749537174184164d,
					0.2589244004275057d, 0.2514229508849479d,
					0.29601769969736225d, 0.2777403544444674d,
					0.29361243931490033d, 0.3544607777508549d,
					0.5957561597151597d, 0.333159345195738d,
					0.4410099829065233d, 0.3561697102735901d,
					0.4662286983763275d, 0.44937210611419764d,
					0.3233740984550782d, 0.3265125200613101d,
					0.39727967842369555d, 0.36782184284683717d,
					0.3703345915365353d, 0.3140757037512134d,
					0.3460421941187174d, 0.35764194754320955d,
					0.3659919646395542d, 0.28263949268588184d,
					0.34262543198570805d, 0.3130338154534361d,
					0.26668940249866707d, 0.1781621543070602d,
					0.12945588336342018d, 0.08856057115113186d,
					0.09959079476097694d, 0.07358956786797945d,
					0.04417649363039145d, 0.04150004384172188d },
			new double[] { 1.49793258702227E-4d, 5.944114943036621E-5d,
					0.158742833353793d, 0.13764425706152478d,
					0.18446585831310025d, 0.24362610785025557d,
					0.24273699039081323d, 0.32173146879279646d,
					0.2654693290533662d, 0.298833948340644d,
					0.2866153200017111d, 0.25035283295271066d,
					0.2617204336118462d, 0.24088315486557463d,
					0.26451750133838486d, 0.24384598035017283d,
					0.2867298701466412d, 0.3224389414332582d,
					0.2926764602591126d, 0.31751382027036973d,
					0.29831788462979875d, 0.2734228722358384d,
					0.23088583553139203d, 0.24484568632246118d,
					0.24414197242294627d, 0.2089689242626758d,
					0.24530549210092903d, 0.3594336099396104d,
					0.3486247265794563d, 0.3311660449932201d,
					0.3236487777770326d, 0.2871537084708213d,
					0.2487735920140308d, 0.2759990936262176d,
					0.22414749903954947d, 0.5519048617336456d,
					0.4871310712270568d, 0.3618121752816915d,
					0.3862281896222885d, 0.4343063170163078d,
					0.377826074427316d, 0.24143927252643094d,
					0.24531253063032252d, 0.2348576654622013d,
					0.1887086713241598d, 0.16284553929378234d,
					0.09819162230126866d, 0.08634133927715121d,
					0.05083675480158265d, 0.05548631744726905d,
					0.04234886489313994d, 0.0368112891131674d,
					0.05362564790729291d, 0.2195265030010268d,
					0.6199604067657786d, 0.4558553089691473d,
					0.45966662821525994d, 0.3569801684984819d,
					0.3203940254366591d, 0.2430323656063064d,
					0.21929599090519913d, 0.341873352539514d,
					0.40836154873555275d, 0.6114326285101284d,
					0.6431119990172348d, 0.5885595360677301d,
					0.7636752399068562d, 0.5979365107115644d,
					0.5965385014167445d, 0.6055409435807364d,
					0.519608831867177d, 0.4266358497833551d,
					0.39286335465980016d, 0.32086303401822713d,
					0.3147026588265499d, 0.19032490025875634d,
					0.17106831391582808d, 0.1439528960879741d,
					0.13312630800754915d, 0.10234493672121836d,
					0.10513457767030368d, 0.1041917756076428d,
					0.07001572062329592d, 0.05710320783458441d,
					0.05549407536848771d, 0.0630439530659603d,
					0.06002779400274202d, 0.053552606117574564d,
					0.05706009517866145d, 0.05147687436405427d,
					0.05814277607308234d, 0.09510506937351547d,
					0.09840107197897408d, 0.17291389619979886d,
					0.15189902018639617d, 0.1808802460833945d,
					0.16285467213420024d, 0.1561129585538604d,
					0.1263651919994607d, 0.11019883399870663d,
					0.08490963487007389d, 0.07511607831696077d,
					0.061901499578802706d, 0.06370969233393774d,
					0.08565881331406604d, 0.10168005796579378d,
					0.10913309398498486d, 0.10735835381412134d,
					0.19262293018488402d, 0.25372901375198953d,
					0.2558610733031629d, 0.4539351706074624d,
					0.45157189126499075d, 0.47622794054018797d,
					0.35892928616307596d, 0.4632334897008727d,
					0.4312893146722008d, 0.3686969176516851d,
					0.41892229919568924d, 0.3223655873651318d,
					0.29473788265485695d, 0.2646832122579637d,
					0.24687248616539226d, 0.20123503616134725d,
					0.1972438662502352d, 0.20435804563423468d,
					0.3075725940108813d, 0.3198986016381746d,
					0.37259100133800277d, 0.376524443384996d,
					0.4648755157565708d, 0.42937853317494334d,
					0.5017484277732466d, 0.4528113679717772d,
					0.4676010555899485d, 0.5538893912889505d,
					0.5328040910025605d, 0.4233759514109238d,
					0.36493109985079814d, 0.39688988281270254d,
					0.29498265769975524d, 0.31351563001179455d,
					0.2955670474084015d, 0.39641246411055814d,
					0.4146415553437614d, 0.34558269193944624d,
					0.34510718856625805d, 0.40368037141182417d,
					0.4163115562095927d, 0.4198153699428777d,
					0.44090136818608305d, 0.3840757044792088d,
					0.3256959636147276d, 0.37716588225074743d,
					0.3421419266117768d, 0.32562116759349075d,
					0.2682991398813505d, 0.19048770774299123d,
					0.15394678478989868d, 0.1270158831341978d,
					0.08492811571662422d, 0.06263644585219737d,
					0.05075892536926217d, 0.03205189768589786d,
					0.02629001861909284d },
			new double[] { 0.02720388408980058d, 0.04999847696314864d,
					0.05971205661375617d, 0.1194972305993932d,
					0.1294926079993115d, 0.17111157819106984d,
					0.16801554886162712d, 0.19938994437996255d,
					0.14341384367030374d, 0.14299538957248223d,
					0.09146651271675325d, 0.07001762985163704d,
					0.08064585729422666d, 0.09213563677916896d,
					0.06959879473451747d, 0.11418823308233461d,
					0.13886128767601547d, 0.1763096053438196d,
					0.15028182957731398d, 0.17401613695133045d,
					0.13816617045645066d, 0.1732830123271202d,
					0.16212659158701004d, 0.1285638730824246d,
					0.12435592914781884d, 0.11348757580101947d,
					0.1241731290868363d, 0.10988065366831722d,
					0.17063044687120477d, 0.12509819150208784d,
					0.1291327253505936d, 0.12409372589076453d,
					0.33043643584949134d, 0.450474588812481d,
					0.4089713155612705d, 0.43726604667829855d,
					0.49320460877407907d, 0.4650417325867438d,
					0.42181917582188616d, 0.374323782045608d,
					0.30063464925963d, 0.3002631399818283d,
					0.40816419719400054d, 0.7470180325150232d,
					0.5774331611254686d, 0.6731911850651195d,
					0.7381012459510539d, 0.721255911457091d,
					0.7156057028564519d, 0.589364477394362d,
					0.794754726513702d, 0.745526107072913d,
					0.7149192862404733d, 0.6240090684092634d,
					0.510912931308181d, 0.4535976789529676d,
					0.36945798407027225d, 0.3141538748642192d,
					0.25755289360097167d, 0.1924437565650313d,
					0.16533254967046773d, 0.12992199090478262d,
					0.10556919884462658d, 0.08892462195826376d,
					0.07054074442309381d, 0.05853617164492862d,
					0.05072084753396709d, 0.039465615026550285d,
					0.04641610228714334d, 0.04734141523552666d,
					0.07003571205520519d, 0.047902246290366705d,
					0.04490943279049112d, 0.03780673606196891d,
					0.040268445120210494d, 0.040911983697556234d,
					0.06453390395087594d, 0.11202904224371235d,
					0.14593175615663265d, 0.1431519466692235d,
					0.11180778507448669d, 0.13866580703894268d,
					0.139288269297374d, 0.17101640244359698d,
					0.2125599779929895d, 0.1666405440831075d,
					0.198846979500399d, 0.5269329435622373d,
					0.6244089976297582d, 0.6255997894910835d,
					0.587896890148194d, 0.5411297653534256d,
					0.5548131201164125d, 0.40326176451230483d,
					0.40464470837884164d, 0.3220355651645121d,
					0.28271573653890364d, 0.2324111516982486d,
					0.2018049188979729d, 0.1812237098405956d,
					0.1487633537474051d, 0.1372591068180165d,
					0.12248152696778368d, 0.112495222067995d,
					0.09219623074386d, 0.12788816483844997d,
					0.2087274021122372d, 0.1387801378808511d,
					0.14868528138383347d, 0.13826863120895072d,
					0.18807409079967136d, 0.20952071561345656d,
					0.27868533572864457d, 0.3313186947734055d,
					0.4789385514578435d, 0.5558262793681552d,
					0.6540765636024052d, 0.6349501483038976d,
					0.7281246732528822d, 0.5784565502687278d,
					0.6067007315832846d, 0.5991761962588316d,
					0.5124284441930463d, 0.4754641882351824d,
					0.4242061135543745d, 0.46198974469072057d,
					0.5059476702600588d, 0.5074020825481693d,
					0.41675554201090004d, 0.4103366958805133d,
					0.40477070418885663d, 0.37755920372313806d,
					0.5196643951229506d, 0.5413662232181534d,
					0.576123442334544d, 0.5950603952712141d,
					0.4883720532922499d, 0.4395998055166475d,
					0.43874971204717667d, 0.3486139639938005d,
					0.3168993831398498d, 0.3467445298880237d,
					0.2910668090102436d, 0.34939345939709515d,
					0.3021639858199701d, 0.2952731708417609d,
					0.2980310692988758d, 0.4243824108642336d,
					0.3774035255843524d, 0.33951558316876496d,
					0.34197307907689506d, 0.2713982717851064d,
					0.24066187837514957d, 0.1581925741317531d,
					0.11904282852963743d, 0.09015186175211667d,
					0.06310609323867376d, 0.04237172402557681d,
					0.0338925336515483d, 0.023977708715307314d,
					0.01830390488752584d, 0.013807043746592099d,
					0.010018572518611529d, 0.007443296794461467d,
					0.00573171019434486d },
			new double[] { 0.0d, 3.1168782142618654E-5d, 3.155397335470125E-4d,
					0.018277395289926123d, 0.01872631030266181d,
					0.018000872213246387d, 0.02723760164343387d,
					0.033414812927365534d, 0.03304765559068496d,
					0.03827239414288482d, 0.035707298823302244d,
					0.04147447551825752d, 0.027142890792965432d,
					0.02577604995638443d, 0.026030858183315065d,
					0.034308066688588955d, 0.032302656220727165d,
					0.04728018424230097d, 0.05884499892783468d,
					0.09400861910987778d, 0.15580200738592198d,
					0.2095182012725096d, 0.29298710746756135d,
					0.4345298029755289d, 0.4127279647304007d,
					0.4738553480328488d, 0.35899158626213173d,
					0.3602579059707315d, 0.3928597191560215d,
					0.4862538823615817d, 0.4649525571673343d,
					0.6485158629945058d, 0.6520324369202807d,
					0.5710443863855227d, 0.6536262808174671d,
					0.7648797703037141d, 0.6484897654333268d,
					0.6042710955576163d, 0.808213702031249d,
					0.5188369551071071d, 0.4706234653594825d,
					0.4080163408547277d, 0.41511908398227026d,
					0.37412522340774723d, 0.5037464691363442d,
					0.6504616570045472d, 0.5531552578138215d,
					0.5514229446509606d, 0.6866451763399386d,
					0.6096080999650484d, 0.5903921850560159d,
					0.5755624836061022d, 0.6405455344824721d,
					0.5988190946623831d, 0.9214117695966829d,
					0.6372703789191551d, 0.7268559673957511d,
					0.6508264885317564d, 0.719289647542727d,
					0.6404894871826476d, 0.6034985802316085d,
					0.43051380040835613d, 0.3592490202422064d,
					0.3377708156958551d, 0.2605285455559095d,
					0.1949136361704207d, 0.17065295579894765d,
					0.15079630189757787d, 0.11930345269772057d,
					0.11595632021212764d, 0.11640726253760211d,
					0.10376367125211419d, 0.12438848905526226d,
					0.12000143667844332d, 0.14379465309384154d,
					0.14101353972806477d, 0.13752665382084378d,
					0.14400441502159775d, 0.10030646087610393d,
					0.09801980564548687d, 0.10930427731087423d,
					0.08552724376837088d, 0.09585245483023992d,
					0.08246594219311615d, 0.07813484952430165d,
					0.08970410373181487d, 0.08966013757792014d,
					0.10406897694521447d, 0.1080885178153251d,
					0.10809468472698985d, 0.12044083105869409d,
					0.13999880495242617d, 0.20040451999168318d,
					0.21511359892128998d, 0.24235827144248984d,
					0.3309397883235001d, 0.37965542825809323d,
					0.30911627273865366d, 0.3773059998592458d,
					0.3937149632134086d, 0.3559456867375464d,
					0.32733424911935355d, 0.35865232585164464d,
					0.30136518673875173d, 0.2765304925591762d,
					0.24468709023031898d, 0.27349523774693246d,
					0.19058277729704717d, 0.15577883747284776d,
					0.13214836739227975d, 0.16131882239538825d,
					0.13278001486083682d, 0.16235532368690656d,
					0.167649528077027d, 0.21591411257456333d,
					0.29958220237643834d, 0.36866898261881437d,
					0.5493862100878016d, 0.7402208602451813d,
					0.5470998003157157d, 0.6066734347953886d,
					0.5558734822876198d, 0.6197138780987265d,
					0.605753338606399d, 0.47055730922583977d,
					0.5387415860279019d, 0.40500309305938503d,
					0.5493601437278988d, 0.5151735591538237d,
					0.5372519384780966d, 0.6826498317071751d,
					0.8097199314503482d, 0.6494771851908369d,
					0.5438597065594426d, 0.5891572134771057d,
					0.5086264078602459d, 0.535842379823313d,
					0.5206648674797418d, 0.47649580061407387d,
					0.5293107317255962d, 0.5294405290992141d,
					0.5777016660808626d, 0.5831033509825178d,
					0.4727771828312241d, 0.5832757061718055d,
					0.5361194144043059d, 0.5457569135779535d,
					0.6332277441786529d, 0.8910760213263781d,
					0.6000720749081486d, 0.5926303115359062d,
					0.5664800975136463d, 0.5006275695285475d,
					0.5035148624594268d, 0.4564835226327694d,
					0.45195086118888d, 0.44559632248584863d,
					0.3217193115043145d, 0.22889425434471183d,
					0.16573795839995506d, 0.13014234585235143d,
					0.09636137167730903d, 0.07652625449847816d,
					0.05226944909605463d, 0.03861105474703693d },
			new double[] { 3.071221454166651E-5d, 3.0096981534509277E-5d,
					8.82445498626088E-5d, 0.06030031195263877d,
					0.07413037460807628d, 0.07911213201283177d,
					0.07430848705151398d, 0.04987146153871348d,
					0.06381213780220896d, 0.08250841642938214d,
					0.08782201078940885d, 0.10077850374422001d,
					0.23784262066378625d, 0.15382358076973093d,
					0.1254998948015864d, 0.1137468547254562d,
					0.09142738088650454d, 0.07714764536626428d,
					0.07012841899516002d, 0.06252043463038283d,
					0.08674671298131763d, 0.07514828039618732d,
					0.1301863126070029d, 0.16734476366969928d,
					0.26864636999703817d, 0.34274072949431433d,
					0.3929078548108053d, 0.3881105991452098d,
					0.41218198581974635d, 0.46357097245173434d,
					0.5740901106581081d, 0.45746945768183744d,
					0.45866134136930253d, 0.5288866577572299d,
					0.6191649116766333d, 0.567894676568035d,
					0.563612886816589d, 0.6182451552125335d,
					0.6651846080686694d, 0.4647978388008721d,
					0.6107983124915329d, 0.7552002566109884d,
					0.5916970225619939d, 0.6029797572408453d,
					0.4017970146459378d, 0.5743976786839077d,
					0.5536990283339327d, 0.5628974103659687d,
					0.5958269831412991d, 0.5475050634725703d,
					0.5558210239793998d, 0.5540785579172187d,
					0.5294607916460522d, 0.6006515387225623d,
					0.6407140001781101d, 0.8379028327041609d,
					0.8186515626100831d, 0.7874863319166905d,
					0.7897051804512306d, 0.891119235901197d,
					0.797901583124208d, 0.7013728044783392d,
					0.5556427274673633d, 0.640556048192691d,
					0.4938926480885647d, 0.43696790048561807d,
					0.330225103757636d, 0.267063710555566d,
					0.20050713663510136d, 0.20518646553713077d,
					0.24281019477827734d, 0.27230247426667226d,
					0.2621066040390737d, 0.29685637218893335d,
					0.24604616309753397d, 0.2618976926357005d,
					0.28475101928943763d, 0.2658796229740512d,
					0.259060774175584d, 0.22755725690323747d,
					0.28745044996918373d, 0.30293629022507074d,
					0.2771658861137479d, 0.26274912240690257d,
					0.24252949809136592d, 0.25347314788628855d,
					0.24333780272030567d, 0.24043865650608037d,
					0.23381760813206554d, 0.24380119660459815d,
					0.2619406104031024d, 0.24608224019551164d,
					0.2548543810315818d, 0.2385366690060559d,
					0.3065887170675729d, 0.2807144244790225d,
					0.2774041798945188d, 0.31429692817534277d,
					0.30450876066825283d, 0.294636661701558d,
					0.35858919255359695d, 0.3004521596819939d,
					0.3075781272617544d, 0.2851811820789549d,
					0.320298137677962d, 0.3477890154562906d,
					0.25900457663946325d, 0.2640565479011461d,
					0.24083239758786965d, 0.2198927844432474d,
					0.1840593111794508d, 0.13775328097830347d,
					0.12032137032262037d, 0.15998176545331452d,
					0.2158850884778971d, 0.3442779259741861d,
					0.4963902343237508d, 0.5966472880629765d,
					0.6134084383104126d, 0.7153370197451117d,
					0.7116046336239885d, 0.5510423732145758d,
					0.5533898288132617d, 0.6120217128475551d,
					0.5449514844984517d, 0.6251531454641803d,
					0.4667902492051911d, 0.6377929263601472d,
					0.5405708676167403d, 0.5348493346263692d,
					0.7204962638827076d, 0.6210333530541227d,
					0.48270875017988096d, 0.5571218184333973d,
					0.5520579959010439d, 0.47382175405435895d,
					0.48040320476520504d, 0.5505780979657396d,
					0.6547830490979607d, 0.6082674369836967d,
					0.6358365841584042d, 0.6264953146160979d,
					0.6679132622265866d, 0.6190637314988847d,
					0.603686917882692d, 0.5448929994523372d,
					0.5259979575967254d, 0.5781128677187506d,
					0.6124144185386737d, 0.503542701999537d,
					0.5552354939694565d, 0.5746358384763093d,
					0.5839887512811429d, 0.4980684185093654d,
					0.5558690375856477d, 0.45776525704643445d,
					0.4611206982348736d, 0.3956688736625967d,
					0.2596447946175682d, 0.209625538713218d,
					0.14564802247136413d, 0.10398272805667819d,
					0.07573321935052832d, 0.05997009342535106d,
					0.04349661442775333d },
			new double[] { 2.439359666822911E-4d, 1.5099663569607876E-4d,
					0.03837506520790325d, 0.06516643611212597d,
					0.09352093903816744d, 0.1841353900012844d,
					0.3423149723553863d, 0.49441964509301645d,
					0.4415996544168009d, 0.37348575185604926d,
					0.5251564773972626d, 0.39000104431189087d,
					0.3337277102786134d, 0.32827990696072273d,
					0.46532328410071305d, 0.5589373079159999d,
					0.44123987820073834d, 0.5403367562954513d,
					0.63612280810183d, 0.5840076423109446d,
					0.5322950559339628d, 0.5859912381293217d,
					0.542257780352387d, 0.5238180963309462d,
					0.530369504175383d, 0.4771663715522797d,
					0.4978298067696835d, 0.44683785047985686d,
					0.5913887434612614d, 0.4171094508599552d,
					0.4276818786291813d, 0.4177048360015487d,
					0.412791834579446d, 0.40787948834431886d,
					0.4545910034226802d, 0.5060172434825866d,
					0.5310705767318226d, 0.5311387076661548d,
					0.7347705339989239d, 0.7007018075863221d,
					0.543073136539479d, 0.5608500650909277d,
					0.5120419380263378d, 0.49167812837579966d,
					0.759420535424531d, 0.5927567464593068d,
					0.5229487034486299d, 0.4883196084142006d,
					0.6446102192833456d, 0.620091989233564d,
					0.5886308245418244d, 0.5932435849597952d,
					0.6962841942843148d, 0.6172335758816743d,
					0.6029852873685196d, 0.8812919480780147d,
					0.7243238385538345d, 0.7510479419185987d,
					0.9341492709444548d, 0.7166815393594134d,
					0.6688174402741497d, 0.6062291397239168d,
					0.6662234637991729d, 0.5345533069858344d,
					0.48106218389084626d, 0.3720632513406319d,
					0.37531607291301083d, 0.2583587168593932d,
					0.22887504832729258d, 0.20589921608864234d,
					0.16538967303660887d, 0.13121404315429738d,
					0.13183619995808832d, 0.12010536476972969d,
					0.12728655455391658d, 0.1397368381097079d,
					0.15174160758224045d, 0.15639386628059423d,
					0.18150698522772513d, 0.3155513297198815d,
					0.270216308224431d, 0.29679199418613994d,
					0.3094071901436114d, 0.2993564688055007d,
					0.26475125335135635d, 0.23212129863643388d,
					0.24296242514253838d, 0.18047680253104997d,
					0.15717357501310916d, 0.14503123396304687d,
					0.13675685593826298d, 0.13556474620692846d,
					0.1538620323083463d, 0.13033854285425028d,
					0.21001528429576588d, 0.15727057577693404d,
					0.21160072649201186d, 0.2735964572337162d,
					0.21226515802885035d, 0.1585982952483778d,
					0.16063161582579352d, 0.20169494606678218d,
					0.18223495289322808d, 0.192127730506189d,
					0.2683557388814349d, 0.23568977777496838d,
					0.2319829311054073d, 0.27153526285593704d,
					0.256647003311349d, 0.2489241362274077d,
					0.2522130279036488d, 0.2743057108535895d,
					0.2466250498613622d, 0.25543980926778237d,
					0.24520827838351397d, 0.2623124856328439d,
					0.4128598594873864d, 0.48481492354714717d,
					0.5391829648166868d, 0.5698726718426256d,
					0.6210119583899658d, 0.767555690051709d,
					0.6958736124438943d, 0.5100954786294319d,
					0.5630765994986786d, 0.5929664288792107d,
					0.5550937840354496d, 0.537047897853345d,
					0.563903878814953d, 0.4787852028316014d,
					0.5990713077892841d, 0.5710681575625574d,
					0.577271987432664d, 0.5342958697666065d,
					0.5855239239761337d, 0.6250859768491204d,
					0.5131621078501353d, 0.513972953936248d,
					0.5027266804032321d, 0.5509428788192828d,
					0.5033102752635257d, 0.6204363771325963d,
					0.5046126408512025d, 0.5016658728313649d,
					0.6123923395627764d, 0.5106057937918593d,
					0.47852727830265573d, 0.5106710619352497d,
					0.561402182401439d, 0.6258337602611186d,
					0.472181353569248d, 0.4586038586382194d,
					0.47086410000937023d, 0.46431595869723635d,
					0.4398425583511654d, 0.4056880261971658d,
					0.3285966586666821d, 0.37254253400630155d,
					0.20796213488010312d, 0.1406569036172187d,
					0.11183213696985869d, 0.07698242247519159d,
					0.0599981412390033d, 0.04245644366699112d,
					0.03217931953300267d },
			new double[] { 1.1988885476840902E-4d, 0.0d, 0.012205901573620573d,
					0.014306421115070233d, 0.05059281948136328d,
					0.12257415790714091d, 0.1540724227426586d,
					0.2774076070615652d, 0.3708315397960754d,
					0.4075444620277935d, 0.38676747637200715d,
					0.4408407833811333d, 0.33686880395808966d,
					0.49077734436661313d, 0.4510342450830415d,
					0.43415315169984975d, 0.4482272749579689d,
					0.5354557714712311d, 0.49941169577841327d,
					0.4377200623769121d, 0.4006484864550535d,
					0.39608993339647447d, 0.523169768631302d,
					0.5864326937462898d, 0.6052273339325438d,
					0.542603680097772d, 0.4297765336771978d,
					0.6385654724112717d, 0.5040661676877716d,
					0.4836748448915687d, 0.6606480209834866d,
					0.6268705758116517d, 0.5553781156793788d,
					0.5275814164127403d, 0.612751070733732d,
					0.768587204179051d, 0.5711364776973742d,
					0.806517650263019d, 0.6398551314970216d,
					0.6669840090657274d, 0.7022835169379611d,
					0.6908524017373836d, 0.6422384665346766d,
					0.5553012373897793d, 0.5855974113635259d,
					0.6181158163799897d, 0.682935505256364d,
					0.7418693366050062d, 0.5751806432799534d,
					0.6236227393479574d, 0.600560401660533d,
					0.49684142327275027d, 0.5722168791840645d,
					0.8868383637003345d, 0.9734401182363618d,
					0.6982151943758098d, 0.765801722996865d,
					0.7908576378250005d, 0.7625841384004138d,
					0.7717734281411903d, 0.7063700648819442d,
					0.7263573465369574d, 0.628055066716792d,
					0.5847803933127504d, 0.6119996397951455d,
					0.5982518936523866d, 0.6761495505443067d,
					0.4980991223111406d, 0.42011938118363196d,
					0.4441966319485598d, 0.3483846192924997d,
					0.3114144957716726d, 0.2643174819585323d,
					0.2145976853914185d, 0.1586481911230102d,
					0.12893690671591895d, 0.11099903327283275d,
					0.10303555302785126d, 0.09616585483148815d,
					0.14466816324526027d, 0.2676466995526773d,
					0.33339399780237927d, 0.3047262797989543d,
					0.24620821187230754d, 0.21809139049043405d,
					0.25131027936079314d, 0.23485290098848838d,
					0.2315596506057226d, 0.2234565290544142d,
					0.18150134085247274d, 0.21677089221156776d,
					0.25471028293571846d, 0.2203927824050998d,
					0.23679942932293419d, 0.20179574952846996d,
					0.18276532224349196d, 0.18935743448750925d,
					0.19936193483614922d, 0.20134947735249792d,
					0.145367249558915d, 0.22679992355953177d,
					0.16370480904008908d, 0.1742068120735866d,
					0.2255222975017102d, 0.22866177954014688d,
					0.34229886186767217d, 0.32263911570715337d,
					0.2656153842898014d, 0.28838420389443026d,
					0.30694938651191467d, 0.3072361191217477d,
					0.28382040758698646d, 0.2279480234360092d,
					0.25515717041050356d, 0.266811749545964d,
					0.3459545196034853d, 0.3200435015543171d,
					0.7471086555898163d, 0.6234850732036266d,
					0.52696953693835d, 0.5137338583202322d,
					0.5250237570433294d, 0.5442093304222877d,
					0.514583770251669d, 0.5643434612608486d,
					0.539209386563951d, 0.5204981481472591d,
					0.5123998821833372d, 0.6722648668884513d,
					0.5383450715524787d, 0.4878353238157368d,
					0.5021366025926777d, 0.5343207538839312d,
					0.6126204947792488d, 0.6361137145525837d,
					0.5396949639177481d, 0.4978113177485674d,
					0.49049960905182927d, 0.4522832157481933d,
					0.5331185159736974d, 0.4434478861642939d,
					0.5914723629592313d, 0.527142391106916d,
					0.4900347762055008d, 0.6089413896334689d,
					0.5428693241709733d, 0.5296923406909155d,
					0.45212001601656027d, 0.4823991662735337d,
					0.4326660474465288d, 0.4426843601683309d,
					0.4105239792977077d, 0.610962051940508d,
					0.43781305389217456d, 0.4791237108582781d,
					0.5873971881833542d, 0.5343128507599525d,
					0.3985884652658639d, 0.30556623185938553d,
					0.20111090632322967d, 0.1633250600329762d,
					0.12905404486695363d, 0.09230499664271127d,
					0.05681761076034691d, 0.05187639715107424d },
			new double[] { 1.552964574408739E-4d, 0.004942219451773387d,
					0.020646678651768093d, 0.03192593670580717d,
					0.04018295538022278d, 0.02675999719321444d,
					0.037073522106552154d, 0.0778581191332842d,
					0.2016521211901714d, 0.32276412568800655d,
					0.24946611233151925d, 0.2806401946597072d,
					0.4290647086655186d, 0.5251340160061903d,
					0.4688176244009079d, 0.544188006969786d,
					0.48549231408230453d, 0.5340664111851323d,
					0.5306942947709488d, 0.6129626047035546d,
					0.5440406683577056d, 0.5586838626954908d,
					0.5288869567923206d, 0.5357326040791378d,
					0.4702676770366795d, 0.5091694516929545d,
					0.4823398261751436d, 0.5050086899705875d,
					0.43718254465699347d, 0.5128850495037012d,
					0.5957633333834557d, 0.49398332876487194d,
					0.5687884559468455d, 0.5445938120075409d,
					0.5732942773940713d, 0.4979714142715981d,
					0.4984996524546679d, 0.6108513220605148d,
					0.5596057842918244d, 0.6135228083630498d,
					0.643243709089263d, 0.6609464887029789d, 0.61179563045953d,
					0.6068965652766247d, 0.5690214233631341d,
					0.5999276260812197d, 0.6938996514856143d,
					0.7043312896029625d, 0.6975412591298072d,
					0.9166293921000707d, 0.697201463206563d,
					0.6771622883160762d, 0.7746354784116634d,
					0.7708578191751365d, 0.8816748475337262d,
					0.8083224048590545d, 0.6644056408829303d,
					0.833356790757853d, 0.6487571411778722d,
					0.6741369635517724d, 0.7325445167383791d,
					0.8782957401918942d, 0.6453924598388879d,
					0.8835194346832682d, 0.8358067781732545d,
					0.8547007277336139d, 0.6904083215794322d,
					0.770472847690207d, 0.6761113058337085d,
					0.6608238656971692d, 0.5040388259822236d,
					0.4383194506806356d, 0.4256167855406018d,
					0.3473293493565667d, 0.3182188864720953d,
					0.2877929726068877d, 0.27844362000851103d,
					0.21757587492347644d, 0.2625785521294367d,
					0.23327277533983107d, 0.265607493048785d,
					0.2681205977455604d, 0.231878249327964d,
					0.25854216406551883d, 0.19547923519768293d,
					0.2041521193763799d, 0.21333931171110637d,
					0.19252522865093594d, 0.13567410125598206d,
					0.1382098225272205d, 0.13772463486932932d,
					0.1850685598997509d, 0.15462288081290723d,
					0.12534176194460422d, 0.14203651168667558d,
					0.17471277372349145d, 0.20249308532198088d,
					0.18246181172170983d, 0.17163386438211975d,
					0.1521394662770763d, 0.17347211246503794d,
					0.15098767193538162d, 0.18728661532186497d,
					0.17095145681892174d, 0.22028885778423707d,
					0.2256553120374006d, 0.2588523693442244d,
					0.20556011335011043d, 0.22158113635546609d,
					0.2578324486014326d, 0.31144201270673527d,
					0.3273596501981447d, 0.36436382373816295d,
					0.29205104221431016d, 0.337246516318218d,
					0.4488736186275967d, 0.6225193090802003d,
					0.5140599886647065d, 0.5311347366733457d,
					0.5117385155803755d, 0.5505360425671102d,
					0.5783731292679866d, 0.5927423499656813d,
					0.6472825137264526d, 0.5749235667256504d,
					0.648241232688662d, 0.8550647793379533d,
					0.6297539231331061d, 0.591849031485413d,
					0.630678747730099d, 0.7343719535871052d,
					0.5662052751324728d, 0.537512886195312d,
					0.5346421085630154d, 0.6382545830664685d,
					0.6414487667884216d, 0.6062991727816507d,
					0.5154481856375559d, 0.5550187186311243d,
					0.41842551941470085d, 0.5067583655043203d,
					0.4120440217367033d, 0.41777080578505427d,
					0.47545765447261423d, 0.5090932259692909d,
					0.4845850855803429d, 0.6144680566441404d,
					0.41089963761627285d, 0.46840448770251175d,
					0.38914503299851666d, 0.5677133966879773d,
					0.41476025496258884d, 0.4328796063641443d,
					0.46044361244963156d, 0.39653582945713933d,
					0.33724427317300026d, 0.2561815685011321d,
					0.2024356708315276d, 0.1472395361171091d,
					0.11496607449630514d, 0.0867139494861656d,
					0.06789041367037521d, 0.049413469084628535d,
					0.034863763339653096d, 0.024587540519644523d },
			new double[] { 6.269795993381677E-5d, 3.076832438083196E-5d,
					9.021775606265941E-5d, 0.0043188040599296635d,
					0.0119765058657054d, 0.017751340276864598d,
					0.02141274273842263d, 0.02920708362772156d,
					0.0488904287429866d, 0.08123781040888388d,
					0.08914381592424958d, 0.07372129900501938d,
					0.11649851850164229d, 0.45088605467049453d,
					0.5350145144905755d, 0.5053201958872864d,
					0.6334099751691943d, 0.4408970099792923d,
					0.4266393979514029d, 0.40713300229814897d,
					0.3596044542077482d, 0.5118232327906579d,
					0.44337203316033247d, 0.49012812037053294d,
					0.44673955788782826d, 0.6134844611565868d,
					0.6235809356904273d, 0.6231511125993323d,
					0.5586986503501243d, 0.5900377598757578d,
					0.7269712641881868d, 0.5343128666247252d,
					0.5575490662296378d, 0.5837615822137436d,
					0.5018385391130031d, 0.57194792085568d,
					0.4614863906273438d, 0.5469898969226407d,
					0.630610370170767d, 0.5496793895971412d,
					0.5279288641818527d, 0.49392193180066135d,
					0.4894227943626629d, 0.6339475527079677d,
					0.5267102846978429d, 0.7298465132232682d,
					0.5677150264968579d, 0.5605234636129938d,
					0.5955036512548664d, 0.5472839953190951d,
					0.5705982426074999d, 0.5907530625869399d,
					0.6128698536601326d, 0.7285787991537447d,
					0.640478072223477d, 0.852561201568259d, 1.015381163471108d,
					0.7870928344950598d, 0.7612095963043032d,
					0.7391715546006795d, 0.8541684612782277d,
					0.7409644784452667d, 0.9345297988525151d,
					0.6585659506851193d, 0.8153339624962982d,
					0.7315041495373688d, 0.7007240372390312d,
					0.7097042055465242d, 0.6719674047719034d,
					0.7091350912407841d, 0.804072607432791d,
					0.6706921123209649d, 0.7005736502580806d,
					0.7113946116943934d, 0.6414308105135986d,
					0.5599851384361726d, 0.601198076884163d,
					0.49051818576704576d, 0.46077167953279174d,
					0.44905007165192035d, 0.35964107758318775d,
					0.3004311563167926d, 0.272216534272572d,
					0.24666105674477182d, 0.24191385724352937d,
					0.2104264900044283d, 0.17242134884456392d,
					0.15910706259910734d, 0.18827574359138724d,
					0.1907261631223113d, 0.24920585534133552d,
					0.22229122923465539d, 0.25067240318662776d,
					0.3091457419096942d, 0.22076424959403249d,
					0.2268743186735157d, 0.2235070250267316d,
					0.284701340988584d, 0.1901976557958846d,
					0.21369659531291782d, 0.19779186186327247d,
					0.17308252157350668d, 0.16403440927110477d,
					0.11667645131613218d, 0.11634474774443658d,
					0.12225883627556376d, 0.123350013408079d,
					0.1565173216331217d, 0.22269077163148152d,
					0.20217598633979242d, 0.29939635740769455d,
					0.2985932233709442d, 0.3007110617542626d,
					0.39399875904355414d, 0.2827776108104459d,
					0.2752604008838207d, 0.32262201211802677d,
					0.4793488346940892d, 0.5242448257923992d,
					0.6935616553941042d, 0.5610843751642669d,
					0.4740727181098862d, 0.5449187295526241d,
					0.529049374579164d, 0.5822491646087349d, 0.51043815557559d,
					0.4769687580178847d, 0.5009673999826963d,
					0.537009360555608d, 0.5690993411264011d,
					0.6212077228872874d, 0.7227677198549761d,
					0.5227806349040496d, 0.5945405226364395d,
					0.551939787753477d, 0.6887376064656966d,
					0.5865281051337344d, 0.5738124412549843d,
					0.662927691789297d, 0.5074761360696702d,
					0.7098365491907946d, 0.5288139482771673d,
					0.5053038784697815d, 0.436514550279703d,
					0.46561913601414034d, 0.4741394430043179d,
					0.5206275671505948d, 0.5231251383162945d,
					0.5683969062371809d, 0.5495172165891941d,
					0.4861253661644368d, 0.5146058926090125d,
					0.7611652483610437d, 0.4853600065305452d,
					0.6596799164815556d, 0.5605263870764358d,
					0.4972229918274079d, 0.41833021944841464d,
					0.35038711677979617d, 0.29018040852008076d,
					0.22798052361097285d, 0.1830420799483281d,
					0.13973438943920727d, 0.10576956657688921d,
					0.0723956550103311d },
			new double[] { 1.6134818008453034E-4d, 1.178360011218985E-4d,
					6.600663009102798E-4d, 0.01760979425448111d,
					0.021094200517258483d, 0.028632997170153888d,
					0.07349369042507016d, 0.10736461052666169d,
					0.12514903720289544d, 0.10648040902782056d,
					0.08598323523071129d, 0.07785640976064578d,
					0.09259160953635459d, 0.15545376111935014d,
					0.19388974541994647d, 0.31192024421213166d,
					0.46050037189804066d, 0.6488039925902652d,
					0.49546230432397226d, 0.7382479579752569d,
					0.6026093070960542d, 0.7539491428259726d,
					0.6219386215537348d, 0.5354611586681137d,
					0.5754667562838098d, 0.5853326774622667d,
					0.49281952767503084d, 0.5880243008254971d,
					0.46879697321226976d, 0.6963156998889456d,
					0.5164039065482172d, 0.5026733590605234d,
					0.5421527634027438d, 0.5175315851889603d,
					0.5391385275695254d, 0.5747612930422561d,
					0.5376207441572746d, 0.5314093360109386d,
					0.5924128075185803d, 0.6238519334328126d,
					0.5956876970194082d, 0.6824773594097236d,
					0.5427789724719911d, 0.7451500202456794d,
					0.6673367244587992d, 0.6169377220178344d,
					0.6736468793381764d, 0.5875929040902862d,
					0.5826436337712798d, 0.6354523925608168d,
					0.8926280393112437d, 0.6450552471841831d,
					0.6691349283538698d, 0.7025635529975395d,
					0.6976025979291319d, 0.773520969266094d,
					0.8279766401920003d, 0.8112759717927474d,
					0.895250829657899d, 0.7861196976702166d,
					0.7118868094767606d, 0.7985208944601495d,
					0.6741709887349868d, 0.6676256938762413d,
					0.7740471040816927d, 0.9438351872812316d,
					0.6940136414849976d, 0.6479268005322812d,
					0.6127284532241491d, 1.2072173655085865d,
					0.6742778435937565d, 0.7614417957416119d,
					0.8625715512408091d, 0.8086609254154902d,
					0.7929898760243832d, 0.7579364599566996d,
					0.7640939222794436d, 0.6026088664141316d,
					0.5259541350808526d, 0.4635829965713037d,
					0.5075221550973671d, 0.47256039903671987d,
					0.42442199189525787d, 0.4482423130828921d,
					0.3967424992178678d, 0.4039457364992981d,
					0.3626210258836251d, 0.3078213311702322d,
					0.29004796446942877d, 0.30049611966731643d,
					0.24335736486968285d, 0.23869782169047515d,
					0.20893750915033077d, 0.24696615224463866d,
					0.26130194253330224d, 0.21412337338422952d,
					0.2848497570431935d, 0.22136465373914493d,
					0.20500277487360613d, 0.1808106054236834d,
					0.20252055928732637d, 0.16088824448224454d,
					0.1878916928504919d, 0.20253708598806905d,
					0.21528730438704538d, 0.21889376733275107d,
					0.20322169387213532d, 0.22034665835343492d,
					0.3378455714197426d, 0.33202176877060025d,
					0.31063003544877166d, 0.38245830002064585d,
					0.35350335733206123d, 0.4187934388486618d,
					0.3848000468224826d, 0.39892703039155936d,
					0.40198669933558007d, 0.5093653138218764d,
					0.8719658495519496d, 0.6483826731499375d,
					0.6642899916718497d, 0.6632418645645073d,
					0.5304684451944093d, 0.48867913039600275d,
					0.49341646362319547d, 0.5415291058382061d,
					0.6025937051250947d, 0.5658940855540961d,
					0.5688375798087629d, 0.6625495014399453d,
					0.5908278281565645d, 0.6253529793888647d,
					0.6270911903832601d, 0.6530961583240156d,
					0.6157683653961585d, 0.5859762444621298d,
					0.52403999738524d, 0.44536105516193425d,
					0.41381721869094024d, 0.46528026378832316d,
					0.47935703736360613d, 0.5573215154360568d,
					0.5211761627178633d, 0.5871915568528586d,
					0.5636188672771512d, 0.535836831544189d,
					0.4119806945579585d, 0.4054245205137178d,
					0.4764717156528722d, 0.42064328449883703d,
					0.4157286248981795d, 0.3721974050679605d,
					0.4192291765844095d, 0.4953508128624089d,
					0.41931925362797245d, 0.4873872338759288d,
					0.44724718958184256d, 0.3918795916573855d,
					0.3060752796075344d, 0.2644904080460774d,
					0.19543870589677384d, 0.1435344520500774d,
					0.1156183968976501d, 0.08118609651729344d,
					0.06345490937478157d },
			new double[] { 3.148404876268714E-5d, 2.866504455215851E-5d,
					0.00695612326177841d, 0.005741676535732667d,
					0.011814722226858062d, 0.015289890923009227d,
					0.02480082435947271d, 0.029420255465377753d,
					0.03453157070599284d, 0.046730843881698375d,
					0.05146548529286401d, 0.061284701114250724d,
					0.08258664723855079d, 0.09955855947676284d,
					0.10490190510614862d, 0.1503123064580706d,
					0.21492133278551828d, 0.25559682106929676d,
					0.44684992003659074d, 0.5016418435502702d,
					0.47176835458060556d, 0.5628768655848245d,
					0.7093085073303882d, 0.7097232330228495d,
					0.6585507188820239d, 0.6102295411450566d,
					0.5636619099642444d, 0.5569003396546516d,
					0.5795210342961469d, 0.5259058550017786d,
					0.4584701215319659d, 0.5472094275173126d,
					0.5629400270997343d, 0.5867646589770321d,
					0.5019783112239623d, 0.5060322650546738d,
					0.5598597205269553d, 0.6554515957928585d,
					0.6325775874866608d, 0.5581657261303906d,
					0.7165957848516683d, 0.6060206801820721d,
					0.7452690665658479d, 0.48183298801383706d,
					0.557286286008563d, 0.5791073664267886d,
					0.6111918610986149d, 0.8545134399670703d,
					0.6593966990122629d, 0.5183683929563434d,
					0.6378924796901067d, 0.6135869939384426d,
					0.6077083554816964d, 0.7495329775342947d,
					0.6623684419839161d, 0.7680714553157775d,
					0.8479850887012882d, 0.6875680091627476d,
					0.7404228621174991d, 0.6398323702213721d,
					0.6549317435789022d, 0.6643113849774901d,
					0.6790891589107636d, 0.7643083050712439d,
					0.616426041097427d, 0.6780855951227343d,
					0.6481240033945369d, 0.7932225079844261d,
					0.657605672697667d, 0.7028111874913979d,
					0.6202398417252337d, 0.7058821480103591d,
					0.6551922899348415d, 0.6664330174322554d,
					0.6858623199363683d, 0.6691202235427375d,
					0.7694473877843575d, 0.8154061500307207d,
					0.8073621641026113d, 0.8925455543985696d,
					0.6572791944102921d, 0.6052196404902374d,
					0.5072340962062519d, 0.5904416103306235d,
					0.4500751068267372d, 0.4438501948200337d,
					0.5246439969957319d, 0.3918130172567336d,
					0.38552641914174d, 0.39991608410092105d,
					0.383204639849132d, 0.3325266168008541d,
					0.33789849093846136d, 0.38395622079913055d,
					0.5694911046089736d, 0.5252346632690166d,
					0.4311017449697667d, 0.5866924345961977d,
					0.4605063155123025d, 0.47821185691769474d,
					0.5787578391292696d, 0.3952252336665628d,
					0.37769519728608875d, 0.4240028103270149d,
					0.3964388884435734d, 0.590184523423704d,
					0.5597512152695179d, 0.43294428162656884d,
					0.3908579160495936d, 0.41312434226300015d,
					0.4318440453802813d, 0.35672287001442915d,
					0.36069300070330546d, 0.3719882237647243d,
					0.4132849604919836d, 0.4904126776495482d,
					0.6744226160735914d, 0.875474913859549d,
					0.7163431848961024d, 0.5584564967603156d,
					0.6485310502761802d, 0.6198182195281617d,
					0.5464073243776738d, 0.5625927430039934d,
					0.5182274785157265d, 0.5622119358722651d,
					0.5261386504113329d, 0.5813092626657853d,
					0.581022250237426d, 0.5730510610176253d,
					0.7978005574786542d, 0.5381236324787896d,
					0.5637557934139009d, 0.5718119181810987d,
					0.5596956973811721d, 0.5827972566844414d,
					0.599411942488245d, 0.5051549359801288d,
					0.41799392367020793d, 0.571169595335274d,
					0.5423199850187025d, 0.4582280054262079d,
					0.4734233812811107d, 0.4970605329890991d,
					0.5098027448784498d, 0.5098792665877613d,
					0.5032129466229037d, 0.769989292189133d,
					0.6862005249971327d, 0.5093395241022931d,
					0.47806910870128444d, 0.5025678166879072d,
					0.582797934684547d, 0.6724458564397464d,
					0.5741559472708332d, 0.5020493032016883d,
					0.44366979885607283d, 0.3347202248879044d,
					0.26850932876100664d, 0.21466223102549353d,
					0.18041641836459119d, 0.12277429554272581d,
					0.10130749322718231d, 0.07197759771373093d,
					0.057476366970362854d },
			new double[] { 0.0d, 8.761067689551139E-5d, 0.025206997517087524d,
					0.09442983053762787d, 0.07103008267235118d,
					0.05917666610945207d, 0.049477207048965376d,
					0.09326834607699652d, 0.1988251985721973d,
					0.2523663642171142d, 0.26529394698761827d,
					0.270975232822454d, 0.259749150373703d,
					0.2477032987116839d, 0.3268851406216908d,
					0.2781623510724627d, 0.2622385872527874d,
					0.24014126628497334d, 0.27275265883479877d,
					0.3342465880382163d, 0.4710958659817032d,
					0.7227797037959343d, 0.6420875587581549d,
					0.7563242258735985d, 0.5911160142827571d,
					0.5606596774648476d, 0.7418101923440219d,
					0.680156855902199d, 0.6529131635540035d,
					0.6106772792788279d, 0.5840951416796124d,
					0.4902425259033891d, 0.5371712288929539d,
					0.5045256735380059d, 0.49053171100770765d,
					0.5255478808420245d, 0.6095451242084445d,
					0.6212835548840947d, 0.6180863277742686d,
					0.5763990411539289d, 0.6672561654677208d,
					0.5323211313940307d, 0.6356763475548018d,
					0.6583067586307078d, 0.614469995408365d,
					0.6182607181100421d, 0.6017101118649721d,
					0.7417408816826219d, 0.5941122993192954d,
					0.6389199348838343d, 0.6456579488496248d,
					0.7148967262071485d, 0.6735711818095245d,
					0.6359579887399813d, 0.7204113541273072d,
					0.6854803836466626d, 0.7237448400476053d,
					0.7097058245988893d, 0.666823275072254d,
					0.7032839339036203d, 0.653875197025824d,
					0.7079004242362558d, 0.7150083305580445d,
					0.7483849321690595d, 0.7214361622726633d,
					0.6558424193871891d, 0.7662596404017052d,
					0.739017624393713d, 0.7515310828734446d,
					0.6405463128753763d, 0.6526739558045362d,
					0.692834355480544d, 0.6965760487734365d,
					0.8413213224006186d, 0.6441295834885228d,
					0.696134794257015d, 0.8487947212196805d,
					0.9012153966251905d, 0.8842627898602774d,
					0.7924991166915245d, 0.6878200628807019d,
					0.7096683072257974d, 0.6986688736374995d,
					0.6984970862060422d, 0.6860370209467032d,
					0.6685644581753128d, 0.6518117193731641d,
					0.7064382894444947d, 0.5463460530904181d,
					0.5223317839390924d, 0.5133950994009933d,
					0.45395695565582034d, 0.43283091819193376d,
					0.38213843935475095d, 0.429924845962267d,
					0.41457378763331326d, 0.435013765813395d,
					0.3776394048976298d, 0.4351106436218675d,
					0.46658527914044234d, 0.5052987465573477d,
					0.48086945448375396d, 0.4500741920304197d,
					0.5503704351070771d, 0.4515053104452709d,
					0.49161556828557074d, 0.4273003755967185d,
					0.49381200591979674d, 0.4733062169712966d,
					0.4865197952418098d, 0.47545065141873843d,
					0.47831009538412717d, 0.4492874604246783d,
					0.5650672749745808d, 0.411704725561464d,
					0.5668117398867857d, 0.5465478570947867d,
					0.6756368209674131d, 0.9233025069252976d,
					0.7373801967412649d, 0.5696078971127567d,
					0.5777344148070381d, 0.6555881230207844d,
					0.6084323319426876d, 0.5076926114609077d,
					0.5520664049313181d, 0.524556405545068d,
					0.5528466583446848d, 0.5278617326972117d,
					0.7501276228538146d, 0.5964810500998778d,
					0.525135748908016d, 0.5883319732660203d,
					0.6731658458128794d, 0.5152775047739095d,
					0.5018266085803933d, 0.5524218193667945d,
					0.45480079261936446d, 0.5653791978723914d,
					0.5229621569576219d, 0.5168259789867095d,
					0.5208549830554319d, 0.4864822573856434d,
					0.48344427485206304d, 0.5165736519226272d,
					0.5812571618837904d, 0.6739647739096054d,
					0.5152352462242071d, 0.5365631678618319d,
					0.5313561900527213d, 0.6365752072271941d,
					0.5392839764514271d, 0.44569489023168535d,
					0.5346625762926526d, 0.47254515894205557d,
					0.670011043047124d, 0.4627292917376359d,
					0.3621924296701932d, 0.2905254057090016d,
					0.22863120096267428d, 0.1746814403383934d,
					0.1336515984552239d, 0.09956448488975203d,
					0.07448543814261964d, 0.05743858266951641d },
			new double[] { 2.977992978468155E-5d, 0.0d, 0.1649498180515216d,
					0.20191260096383273d, 0.18138317151219477d,
					0.12868295083760742d, 0.11238900507394975d,
					0.1097475489762399d, 0.12582477942595388d,
					0.07986649420510203d, 0.10503628567519052d,
					0.17815030252780004d, 0.2295415051534289d,
					0.3593323151989484d, 0.2995404010223506d,
					0.2299644852295939d, 0.2568413587712865d,
					0.28783343964830665d, 0.2332402474796234d,
					0.24088389400767918d, 0.22062410878562405d,
					0.2588596527839071d, 0.34808713100067407d,
					0.5079452091244089d, 0.5815486642619901d,
					0.6988766357723891d, 0.5816092806921447d,
					0.7751326180302599d, 0.594689364767764d,
					0.6414960365069207d, 0.49702369650529965d,
					0.5790375113304674d, 0.46735198194389227d,
					0.5253213305277044d, 0.6852990516439397d,
					0.5027747613528893d, 0.5378944580751491d,
					0.5014230032509243d, 0.45220963304729606d,
					0.5434021140418065d, 0.46162490827961133d,
					0.6649635431035287d, 0.5947973549129937d,
					0.46507019231295077d, 0.5117367789305316d,
					0.4997860579080964d, 0.5830695145771707d,
					0.7186036195995947d, 0.5779893620600046d,
					0.6724983398071387d, 0.5665547623866785d,
					0.5312297733191425d, 0.5711316253546876d,
					0.8061507815125232d, 0.5608935693671531d,
					0.6931244274300531d, 0.6715877666648988d,
					0.7386933243344425d, 0.6791632621270998d,
					0.5951061176627799d, 0.7001343582824793d,
					0.7001664884765362d, 0.7659025277745954d,
					0.7386535256302934d, 0.6918223899311066d,
					0.6603970311414863d, 0.5796264796658973d,
					0.7918297413717728d, 0.6440774524190302d,
					0.5694177028340969d, 0.6703593868754973d,
					0.7104553947782475d, 0.6118384295417935d,
					0.5717375441565666d, 0.6863475025130727d,
					0.6195266927761462d, 0.837924805001577d,
					0.759206020914093d, 0.9298874548090925d,
					0.8734453403137314d, 0.7746502790733295d,
					0.880112446262437d, 0.8184361229786802d,
					0.7599550403616665d, 0.8073994238360612d,
					0.7250574326602606d, 0.7858053535827476d,
					0.6656914101095461d, 0.6162201682160604d,
					0.7101143210816283d, 0.6089163531164726d,
					0.5782338798038982d, 0.5595767338315637d,
					0.5664221186816086d, 0.8469299907697061d,
					0.544690237799805d, 0.45289355758803657d,
					0.48000390990287767d, 0.3983974306993899d,
					0.39344910015874596d, 0.3588971022170846d,
					0.469462414274775d, 0.33576361896526474d,
					0.37416745538959767d, 0.3683480402069981d,
					0.3123213488599362d, 0.4895285940914876d,
					0.4135710806269265d, 0.3679320288815745d,
					0.3620991548188449d, 0.45801022797162494d,
					0.4138733769430194d, 0.36756215062661013d,
					0.38869734079126417d, 0.4133960864244946d,
					0.4180308496175889d, 0.4644774333023714d,
					0.5504248132815517d, 0.6690425881384919d,
					0.6352170092107123d, 0.696458941431659d,
					0.6424109886129222d, 0.627677207904799d,
					0.6395526880597863d, 0.7511031015745119d,
					0.5394015145488722d, 0.5776116253534762d,
					0.7196087618684773d, 0.6704408838944032d,
					0.7062356330618097d, 0.6048401321645578d,
					0.6858447901727817d, 0.5575334092712307d,
					0.48930058581494795d, 0.5020339528319476d,
					0.4789928634253022d, 0.47720891717615194d,
					0.6080272239492354d, 0.5772034548635873d,
					0.8402636296994028d, 0.7877048666917053d,
					0.6172596474371767d, 0.519039411223713d,
					0.5130614889166886d, 0.5331312775934863d,
					0.5594584345087046d, 0.6286845781702722d,
					0.5867339336814926d, 0.6489075337829966d,
					0.6043025915458737d, 0.5599374826829653d,
					0.5761550937697132d, 0.6730203645690592d,
					0.5083847973933547d, 0.6245917823453526d,
					0.5422163871405227d, 0.42781229860567316d,
					0.34957144244065785d, 0.2762677758819102d,
					0.17894483912024547d, 0.15258434390207562d,
					0.11308059220384362d, 0.0923803079916676d,
					0.07160078710790739d, 0.0485823981938238d },
			new double[] { 1.5079478353568422E-4d, 9.210937609851675E-5d,
					0.12841864746246878d, 0.25415300865878815d,
					0.2545676139344635d, 0.2790773154976796d,
					0.34239172624422987d, 0.2671821141390069d,
					0.2428408283829731d, 0.24707420912923303d,
					0.2392711716935694d, 0.2480798320318008d,
					0.23747654670967383d, 0.17784876503406735d,
					0.17064793523183686d, 0.1423341274188581d,
					0.18986375454120447d, 0.16743851090503323d,
					0.22510443140937902d, 0.16396915411130233d,
					0.19164950305982467d, 0.21112976317565427d,
					0.23325637146848818d, 0.2602077361036603d,
					0.30221450235056213d, 0.6924196725774743d,
					0.8559438597893488d, 0.9090014942657684d,
					0.6195241327861575d, 0.6609178518780442d,
					0.6013886767829845d, 0.6614016468846092d,
					0.5097448953947948d, 0.5203103673019825d,
					0.5222709365420296d, 0.5630404537937679d,
					0.5725459729269127d, 0.4984198027358793d,
					0.5612744255555107d, 0.6192495857973018d,
					0.5747881990604027d, 0.5288549083054847d,
					0.6850755136504947d, 0.5269463536744469d,
					0.6396697320901422d, 0.5385264432998019d,
					0.5420965965052178d, 0.5889636785503897d,
					0.593077194275447d, 0.5413427938413595d,
					0.6562866500972055d, 0.5082515868244755d,
					0.5804584093465704d, 0.6132305917989191d,
					0.5758875265883356d, 0.6789331470296585d, 0.6539324292134d,
					0.5231898965114583d, 0.6532214058728526d,
					0.565768918886983d, 0.7219097749805707d,
					0.7791039398502448d, 0.5689620772430296d,
					0.6256830588487508d, 0.6688800210199398d,
					0.7514863734945252d, 0.8161668340381054d,
					0.7064158289989594d, 0.6563368497803952d,
					0.6344020999490596d, 0.8092336592194466d,
					0.7317694119820666d, 0.6976759504103229d,
					0.6373438653109658d, 0.6889316801051154d,
					0.656482194779992d, 0.7623914720959738d,
					0.7650192834437674d, 0.6629756147476857d,
					0.7018540893939497d, 0.6170419972638918d,
					0.6330292505259563d, 0.6800982047848005d,
					0.6053458339280534d, 0.6145846186084749d,
					0.5920828046445689d, 0.6086879817991958d,
					0.6049261282439478d, 0.5796688012716288d,
					0.5583367635057044d, 0.5591877902074817d,
					0.5080888952922352d, 0.4564296296218731d,
					0.4222679489263748d, 0.381880406218262d,
					0.3142017080798312d, 0.3088791284238494d,
					0.26278763890272955d, 0.21441588003697828d,
					0.17576451323914843d, 0.1898000204103847d,
					0.1483003353698936d, 0.14808746911087448d,
					0.1941708735200487d, 0.2330424514177995d,
					0.27147836790191304d, 0.32876672272546503d,
					0.40077287734047046d, 0.29677148971665984d,
					0.30284476099816904d, 0.29429481013068204d,
					0.334382621923286d, 0.29109537248757533d,
					0.4078269633584971d, 0.2897571427463277d,
					0.3214176782450945d, 0.359851462440914d,
					0.4304595894278525d, 0.38228800352581727d,
					0.41070089764452294d, 0.37707244017697783d,
					0.366378611453457d, 0.38468716488814847d,
					0.46206627073250295d, 0.42988460251853794d,
					0.604739688840964d, 0.7144266382667468d,
					0.7319616784080145d, 0.7212095234927073d,
					0.6570225714795344d, 0.6018774284581037d,
					0.6003619460072973d, 0.5400564161779087d,
					0.4968773914750604d, 0.7150395965631042d,
					0.5610171424747528d, 0.5222903800615126d,
					0.5601917096914385d, 0.5514242716523766d,
					0.5678784987512083d, 0.5768440618660355d,
					0.6752295881067496d, 0.6901851838720517d,
					0.5098780016098068d, 0.5353351574532416d,
					0.5271375218631379d, 0.5782870672984574d,
					0.7754355167486988d, 0.5834373337787581d,
					0.4861757275571725d, 0.6263595561176747d,
					0.5105050683879097d, 0.7312173101683281d,
					0.5313578509594197d, 0.6144980168038533d,
					0.6397196849059559d, 0.42829290200380976d,
					0.3480943397000364d, 0.24862461516003212d,
					0.2197732835777584d, 0.16869670295068465d,
					0.12527099238910222d, 0.09530420062250951d,
					0.07022728850369878d, 0.05497735825538174d },
			new double[] { 6.0629990143409434E-5d, 6.105997647160312E-5d,
					0.12894988269107258d, 0.20298756149600522d,
					0.22894479959647906d, 0.32004469573281275d,
					0.28614421100865456d, 0.3276292082889173d,
					0.27605726234438044d, 0.28046412809343546d,
					0.2893396877316741d, 0.3198262456390335d,
					0.25623335349551424d, 0.2372092214307525d,
					0.22064353043311913d, 0.3944764842273886d,
					0.34762581083721383d, 0.3470776067999389d,
					0.2785644802010604d, 0.27225928822523293d,
					0.3355627291426047d, 0.3807539462807455d,
					0.3049233242587732d, 0.3214684628133942d,
					0.30779915296915555d, 0.2431231472278283d,
					0.22734627911828378d, 0.4819407736492059d,
					0.34544489812848533d, 0.4631957359565918d,
					0.6055925233819976d, 0.5347906024852711d,
					0.7804806042520689d, 0.609985395705612d,
					0.5663076571504772d, 0.6647912165007921d,
					0.661007863929777d, 0.609031530764517d,
					0.6080988764386054d, 0.5664427161098302d,
					0.621952741276413d, 0.45882616190372655d,
					0.4951434649072694d, 0.5373150779743588d,
					0.656703468937292d, 0.7588549432254995d,
					0.6422198203092695d, 0.653840546785915d,
					0.6182416666862226d, 0.5762641408096734d,
					0.591578359857453d, 0.6375076658575286d,
					0.8486960096854606d, 0.5912223549144069d,
					0.6200748245489782d, 0.6259592040268959d,
					0.6709994277772531d, 0.730692383759933d,
					0.6532101162977247d, 0.6332859198832131d,
					0.7050919604136597d, 0.6380343477616744d,
					0.7159890533749628d, 0.7292483140873518d,
					0.6353276288342211d, 0.6483743554517009d,
					0.6313395738524984d, 0.7135316400165401d,
					0.7925881329261959d, 0.7047427106554552d,
					0.8721984067510886d, 0.5988831484221374d,
					0.6406849802853873d, 0.7038689939458436d,
					0.8110630703050644d, 0.8990364146795489d,
					0.7298495707011045d, 0.6162927786818799d,
					0.8646781887523285d, 0.694980392619297d,
					0.7117315630975386d, 0.667578599582775d,
					0.5398501637847714d, 0.6862794241502955d,
					0.598484167209244d, 0.660524836631706d,
					0.7018691198869299d, 0.5858576537019984d,
					0.7306512788509967d, 0.7392913723065259d,
					0.514199374873407d, 0.5592697061062559d,
					0.5381369905607637d, 0.5677147922500466d,
					0.6329137201804057d, 0.5616585545433487d,
					0.48121777546208583d, 0.5343237928971385d,
					0.5240623650576246d, 0.47295637362741333d,
					0.4604756406578089d, 0.48283688836106303d,
					0.45539143193444576d, 0.5112783964205823d,
					0.400188150927909d, 0.40289368809875237d,
					0.36338673531849286d, 0.3309249273682517d,
					0.3758734586190773d, 0.2828918868135648d,
					0.3490213393574718d, 0.4214049473012445d,
					0.383806109201293d, 0.41199361877832064d,
					0.391830308623628d, 0.3863323011400493d,
					0.35535735975829863d, 0.35885587459253676d,
					0.3370088026023467d, 0.4579009404007995d,
					0.41659236783904074d, 0.4125497962921656d,
					0.4275696812228958d, 0.4559940300530321d,
					0.45626320288442124d, 0.3973241093546761d,
					0.42495237064878477d, 0.5617102895808179d,
					1.2483573165473973d, 0.8196882947304092d,
					0.7327577870187388d, 0.7503421463239696d,
					0.6155415458407331d, 0.5570114886310074d,
					0.6275756041415959d, 0.6097534194219799d,
					0.525715128664711d, 0.589741623411643d,
					0.5081543488410312d, 0.5395322481597157d,
					0.5684268918301709d, 0.5981723284946497d,
					0.47843656255693134d, 0.5443523646343496d,
					0.5156626094440627d, 0.5631911621453612d,
					0.5597859077191149d, 0.8144905844768543d,
					0.6120334442155342d, 0.6030949812769292d,
					0.5599553478385918d, 0.5293795657558826d,
					0.5560695185137356d, 0.5461666134473491d,
					0.508521730414895d, 0.5198341247138348d,
					0.42068001290050855d, 0.3172757121460168d,
					0.2538441579949667d, 0.17881555942071867d,
					0.13500602494832648d, 0.10702631375861622d,
					0.0860333288928138d, 0.05525873516208765d,
					0.04970671343968437d },
			new double[] { 6.085925537395926E-5d, 2.9489944545807093E-5d,
					1.1583873197670849E-4d, 0.26114884019946627d,
					0.23494151411774222d, 0.28009221494978254d,
					0.32860206114331786d, 0.34026027453283575d,
					0.3781850536751242d, 0.3624218189756274d,
					0.3292335094297322d, 0.33014518130867193d,
					0.28295093172267294d, 0.25819849426210056d,
					0.28147861334507585d, 0.2520624660564247d,
					0.259985040011877d, 0.3492690417413152d,
					0.3661638319217026d, 0.495073767716265d,
					0.388524938276634d, 0.33994619786390273d,
					0.35807243702726804d, 0.3977460037113291d,
					0.31475372357560055d, 0.3942635341892813d,
					0.35610230890928884d, 0.34336201250146076d,
					0.32329708306836236d, 0.4527215381855426d,
					0.3912316695692272d, 0.47002632297247393d,
					0.5346478410093896d, 0.5071270879934187d,
					0.6571911032333372d, 0.6832547173829172d,
					0.5645602861374274d, 0.5552220524079982d,
					0.7114355531488616d, 0.5473962690647977d,
					0.5454961191480158d, 0.5776109564054991d,
					0.706032684271386d, 0.61426996297516d, 0.6669355398459091d,
					0.5255447959748749d, 0.6400924315244807d,
					0.5749856460895084d, 0.5689500669267639d,
					0.626113425459229d, 0.5857539666718584d,
					0.7621092375941211d, 0.788809967464887d,
					0.6453469936281864d, 0.6401998015476937d,
					0.6259439972667371d, 0.6754360445903602d,
					0.6144227800239593d, 0.587523822271068d,
					0.6113660179679598d, 0.665702410782934d,
					0.668931952008281d, 0.7135583651779167d,
					0.5884406967701923d, 0.565481317947288d,
					0.7080021521681663d, 0.8026547934633289d,
					0.6812100469163667d, 0.748377290022488d,
					0.7511240194495753d, 0.8007557039745149d,
					0.7937256444571527d, 0.7103594293443747d,
					0.7137610417103608d, 0.8403612760030945d,
					0.7131251017458414d, 0.7442743466438578d,
					0.7597496899044741d, 0.788412592037409d,
					0.5958887621911043d, 0.7003256358969903d,
					0.6839380544670287d, 0.6687093109439145d,
					0.5726347770472437d, 0.699356469809895d,
					0.6713470307526279d, 0.5764501361655178d,
					0.6777699254186044d, 0.6390069626099252d,
					0.6057438413619847d, 0.733049444917879d,
					0.8105431046691899d, 0.7935300569149835d,
					0.9552370561012009d, 0.7215408414933605d,
					0.6309451589703583d, 0.647509604566655d,
					0.7864928326414827d, 0.6723280124196751d,
					0.643416291724834d, 0.6424469252782878d,
					0.6790229790693355d, 0.5865509247742675d,
					0.5338760312045684d, 0.4943083359352376d,
					0.506438873695214d, 0.4402214188866649d,
					0.3793378438077465d, 0.4082437472486499d,
					0.3353633332916739d, 0.32740102327073406d,
					0.36121547086324307d, 0.35740996512351103d,
					0.36433766741400775d, 0.39964799615455787d,
					0.5891722166667281d, 0.45596207211119316d,
					0.6195852360910641d, 0.5058104167675886d,
					0.5418929534604975d, 0.5794322670796865d,
					0.6686490521107646d, 0.6076670171489702d,
					0.5667273774566666d, 0.6291019710048782d,
					0.4674261740859454d, 0.4749694711532465d,
					0.5328036533389615d, 0.47474346151292796d,
					0.5323225296648145d, 0.6301932889825095d,
					0.9238359965404923d, 0.7121589109631521d,
					0.6787881881903988d, 0.8293988270051335d,
					0.7969251457818881d, 0.7614438678754265d,
					0.7018647930744754d, 0.6640186103192836d,
					0.6298454341069084d, 0.5720107633122921d,
					0.6115933584523853d, 0.5669196550171112d,
					0.5396061431416747d, 0.6541157267783855d,
					0.940431010462533d, 0.6693073435969449d,
					0.6056139181276103d, 0.7446555157391268d,
					0.6107100055250471d, 0.6511655080708597d,
					0.5806887034896829d, 0.5331655353043364d,
					0.7737358022272207d, 0.7368460420500169d,
					0.5125789998108472d, 0.562242182784709d,
					0.47704959081491566d, 0.3567080826247866d,
					0.3011688154126048d, 0.22093043732699574d,
					0.1659094424285549d, 0.11755969903467091d,
					0.09103047533919228d, 0.07161580438958882d },
			new double[] { 0.0d, 0.0d, 0.25729780829431753d,
					0.3336073098108765d, 0.3096524840581726d,
					0.2954767631320553d, 0.2682164305062519d,
					0.31566098165924905d, 0.23708141270551086d,
					0.28214292110593d, 0.33442254991727266d,
					0.3721690126536548d, 0.3133886348186848d,
					0.35277773386254524d, 0.36598888551685577d,
					0.40656477945569713d, 0.43405198855930277d,
					0.6148161761332728d, 0.4793517219433855d,
					0.45000588173380046d, 0.4593457230194329d,
					0.42984083538516527d, 0.4455684898543622d,
					0.46036957889783736d, 0.4590296837926969d,
					0.43093341231777016d, 0.3764733167866006d,
					0.5156093233726274d, 0.46062811753098826d,
					0.39029897580205375d, 0.46249692407575216d,
					0.5830785872006125d, 0.650461038928969d,
					0.7199473794211217d, 1.0432531665014317d,
					0.6376952229074727d, 0.8183860886621868d,
					0.6887711573785319d, 0.6595906073951208d,
					0.6793898899350307d, 0.6054968387396852d,
					0.6716475276035061d, 0.6157318112644937d,
					0.5969835372832359d, 0.5188351468538243d,
					0.6356959544521726d, 0.5293561704568237d,
					0.6336202397762437d, 0.6416964963871528d,
					0.5041214629184718d, 0.5585154974125994d,
					0.526696309244179d, 0.5819066424218772d,
					0.6858113005003513d, 0.663825976944528d,
					0.6101329180977628d, 0.5811198436019765d,
					0.6551285736637732d, 0.6812735126090099d,
					0.573010604665009d, 0.8165129796375759d,
					0.6678834715182811d, 0.7026153066164543d,
					0.7162871593553793d, 0.6966466484343801d,
					0.707895429526664d, 0.6620017288442994d,
					0.598221874161606d, 0.6648492187494152d,
					0.7325872021104802d, 0.8066407080097533d,
					0.8442525094920034d, 0.7485196540719729d,
					0.8365428198257848d, 0.6844712189526656d,
					0.8204931384743624d, 0.702983443081306d,
					0.5917656707587287d, 0.8000759604114998d,
					0.8217125088792862d, 0.696413940599882d,
					0.748335793558122d, 0.6159264185973494d,
					0.5758083148718068d, 0.5808510773045696d,
					0.6555512785034942d, 0.6070065435910743d,
					0.6926593970550873d, 0.8361867223014564d,
					0.7654147192684693d, 0.6277493360905979d,
					0.610718199277967d, 0.5677483358611866d,
					0.625574410492908d, 0.5246904903418929d,
					0.7089551249735867d, 0.7446345746276137d,
					0.614018573881399d, 0.6572367718670624d,
					0.6823580220033131d, 0.6437114705065884d,
					0.5681033542407019d, 0.6541171162366954d,
					0.5828769645996738d, 0.5983970952140405d,
					0.6297331329309961d, 0.6594341578726899d,
					0.5304413558018328d, 0.5761818389844632d,
					0.5551976309589196d, 0.5369458205272912d,
					0.6342399795156549d, 0.5860910143345811d,
					0.42478633280506123d, 0.5210032994024106d,
					0.47533226951994695d, 0.5212812932732082d,
					0.5410907908621794d, 0.6163936760884455d,
					0.5642724702392357d, 0.5950840124934185d,
					0.658361433079808d, 0.5453263184090155d,
					0.6729741289553998d, 0.5853317359759077d,
					0.5622336499800739d, 0.6011009167642017d,
					0.6566038852514472d, 0.6298803345089787d,
					0.604609847895721d, 0.6528936029090864d,
					0.7888001344223081d, 0.7955775513519676d,
					0.7375321232951203d, 0.9227437561485632d,
					0.7142322921538428d, 0.6318249320482291d,
					0.7311428469181812d, 0.6688766002917188d,
					0.5157504139008569d, 0.5906937814873756d,
					0.7519151005979201d, 0.6805955246305598d,
					0.807067251538859d, 0.6693584543790683d,
					0.7585264355510355d, 0.5802336475124573d,
					0.7097880056404099d, 0.5926474090307955d,
					0.6291024970909778d, 0.6272077088941926d,
					0.684625508644687d, 0.5951453208670792d,
					0.5269724121517851d, 0.5638610187420489d,
					0.47605438889121127d, 0.43420392008834935d,
					0.32432855161965624d, 0.2479255628404473d,
					0.19332095484102774d, 0.14741097750437349d,
					0.10780189160056583d, 0.0794074980965811d,
					0.061915946674221456d, 0.048468884359528036d },
			new double[] { 3.7538329958852274E-4d, 1.1338289961227266E-4d,
					0.07029448456895841d, 0.18156833833876926d,
					0.21693273958627485d, 0.22970553639348815d,
					0.2562780240671488d, 0.26964642355423707d,
					0.30898174248051113d, 0.3099204793845743d,
					0.3219536611538521d, 0.28812995900853744d,
					0.3540156318961212d, 0.3809022658993938d,
					0.3588527559128039d, 0.39548291712294775d,
					0.36969087004539214d, 0.27577599173241624d,
					0.30348721400595663d, 0.3664970759362302d,
					0.31521425470435566d, 0.38407288164564896d,
					0.27887362562107904d, 0.3056195057348341d,
					0.18903189614887428d, 0.1973356786820266d,
					0.20945949303454736d, 0.2668761746563073d,
					0.3374879497156411d, 0.47286523805883834d,
					0.3457083539627636d, 0.39923882299410346d,
					0.4130809052105704d, 0.4297111252005854d,
					0.38826408265339507d, 0.5402425232228686d,
					0.9217434653133282d, 0.7613753526716218d,
					0.6812389123066661d, 0.740573816282017d,
					0.6601788027268728d, 0.7135491229907582d,
					0.7048233833093824d, 0.6180211217005146d,
					0.6827041748287263d, 0.6742279406394381d,
					0.508699730837841d, 0.5727212687778614d,
					0.5809900968498084d, 0.5253990439818959d,
					0.621306403173351d, 0.5617918486875662d,
					0.5756972584707986d, 0.6171584707900708d,
					0.6572429112462976d, 0.6407764376202406d,
					0.6155727382225961d, 0.5948507592258794d,
					0.6462192636784504d, 0.6174576624871102d,
					0.8233187552720482d, 0.7379190435339441d,
					0.8987568729899202d, 0.8608276437154749d,
					0.8128427386432212d, 0.6780820718008078d,
					0.7686763105598085d, 0.9749250059195798d,
					0.6331814837606968d, 0.6271658115953623d,
					0.7205214809237299d, 0.6600134317832055d,
					0.6668715619867482d, 0.6600225308766658d, 0.6947805618169d,
					0.7212790571403247d, 0.6595353737877683d,
					0.7536592633744034d, 0.8624416259665766d,
					0.7084100504733591d, 0.6785938975632871d,
					0.7520494133479088d, 0.9024006989354697d,
					0.77241379537434d, 0.7223716147925889d,
					0.7009229273667685d, 0.8520091715731145d,
					0.8924925771973922d, 0.7272181130166068d,
					0.6667608745064956d, 0.7326653279904848d,
					0.7515126683476251d, 0.6960078277577889d,
					0.6536806242658298d, 0.6147499808725643d,
					0.6048150629057003d, 0.6642953187412436d,
					0.53324159564997d, 0.6418039479353363d,
					0.6975967249719014d, 0.6910776201081626d,
					0.7340238009614216d, 0.7239332306097959d,
					0.657961046394153d, 0.6389406811377671d,
					0.7616849235789563d, 0.6793932883160284d,
					0.6038655297214649d, 0.5699447730911454d,
					0.726969520252269d, 0.47464674863502226d,
					0.5228865451927948d, 0.569920820789786d,
					0.5203094182639023d, 0.4815937196916147d,
					0.36461932628734695d, 0.4039234488257566d,
					0.5546266316089722d, 0.5152276445090695d,
					0.5043548707832742d, 0.7700903692791052d,
					0.7602878515195193d, 0.6831097205010159d,
					0.711388047560198d, 0.6380921636782023d,
					0.6338973741627085d, 0.6014614192505052d,
					0.6051541283241189d, 0.49799384970387855d,
					0.547762612342642d, 0.5019036369644279d,
					0.5144980071066138d, 0.4781112375275523d,
					0.4752535624409772d, 0.5306554913196047d,
					0.5378897267073353d, 0.7278324540578299d,
					0.6305391323982357d, 0.8461620570600549d,
					0.7069241352555722d, 0.5760213067000017d,
					0.681716056514264d, 0.7204489969087355d,
					0.6108923466169196d, 0.6079657065593904d,
					0.5653442412356247d, 0.6142700318107256d, 0.5647763508139d,
					0.5929124857072268d, 0.5560784841822051d,
					0.6499524156586928d, 0.6172814608487804d,
					0.5676415103669835d, 0.6034838198297796d,
					0.49816627421026d, 0.46072141091657137d,
					0.45758648053313533d, 0.36386250089170913d,
					0.2976793559774851d, 0.2331798736998656d,
					0.16188920967126863d, 0.13864904188870997d,
					0.10397095952268803d, 0.07045283831356784d,
					0.05480097159271744d },
			new double[] { 0.0d, 3.0201154121184342E-5d, 0.29628861087628494d,
					0.32634081800813936d, 0.2342433411215133d,
					0.309151879562309d, 0.29462826782950413d,
					0.33103909842664925d, 0.35318362590067987d,
					0.2954187425162688d, 0.3157677884921059d,
					0.33688191245636256d, 0.29889250213408625d,
					0.27626294775615723d, 0.332795898522799d,
					0.25967469584853253d, 0.29284301852543854d,
					0.29173079022178555d, 0.3528167655624266d,
					0.3307787249045416d, 0.43009554636255826d,
					0.35040743121451845d, 0.38972616980751934d,
					0.406012402669206d, 0.4477324638803623d,
					0.5655648359170045d, 0.4926667748732674d,
					0.4899687245043488d, 0.4902939233318681d,
					0.535844620111762d, 0.7009818637456388d,
					0.5267801651553211d, 0.494573493561225d,
					0.4616558792869612d, 0.49403256892662595d,
					0.472531935485379d, 0.5446119041090214d,
					0.6861558209800093d, 0.8395143353381518d,
					0.59363877819612d, 0.7626150302565247d,
					0.6259435843536012d, 0.9188007695709103d,
					0.7654658381433253d, 0.6121410825574457d,
					0.6813175956303505d, 0.6057541629810309d,
					0.6579602660122383d, 0.5727955500579645d,
					0.7715189854838395d, 0.6224692079989903d,
					0.5561350242023374d, 0.5446321438431905d,
					0.5318284928876922d, 0.5611486081960992d,
					0.6614417837636859d, 0.7667528197372172d,
					0.6414934510842105d, 0.548583086519497d,
					0.6280708113737267d, 0.6770382625879245d,
					0.6762875111346799d, 0.7958293556380087d,
					0.8522028855219201d, 0.6561455695639623d,
					0.5741172755482397d, 0.6663156566319882d,
					0.7737343605079724d, 0.6313342541641224d,
					0.7882890957244301d, 0.7837569511724792d,
					0.7423731547551279d, 0.7346330494440029d,
					0.6661328160127965d, 0.7858645650679341d,
					0.6998925855580649d, 0.7183207554381569d,
					0.7783400326157327d, 0.8228282591795885d,
					0.6881060408467625d, 0.7154622610262511d,
					1.078759024624786d, 0.9005620785368894d,
					0.7956931148921947d, 0.7235893692445802d,
					0.7867314625548225d, 0.7675525276848827d,
					0.6121765621527587d, 0.6597376545156841d,
					0.7245660239229758d, 0.6083179019417407d,
					0.7122150696948139d, 0.6366459856117214d,
					0.6561197149100824d, 0.7590208807439507d,
					0.7509083445106668d, 0.6784164875700559d,
					0.8607620289169027d, 0.6977205881914081d,
					0.7574857023285864d, 0.6712790617477655d,
					0.7316112321117804d, 0.7609956263532273d,
					0.732849574364532d, 0.8499621226118904d,
					1.0684238301533002d, 0.8394670666972348d,
					0.7786491436521433d, 0.7152714744465105d,
					0.8013316248027821d, 0.6389171185421624d,
					0.6705095802870562d, 0.5960825249808661d,
					0.5868391123522756d, 0.5598557682252862d,
					0.5599544526508945d, 0.5702400380744952d,
					0.5914014896947971d, 0.45907036195481793d,
					0.5285958114588971d, 0.6089948009903758d,
					0.5189800434072465d, 0.63065098473264d,
					0.4827921993735441d, 0.5074544130816514d,
					0.4649251356211946d, 0.4514185331398495d,
					0.36920574943951334d, 0.4087452749883137d,
					0.48215430159518d, 0.421982532084278d,
					0.46200602271339275d, 0.47181828134371206d,
					0.41377510784727317d, 0.37519065253025385d,
					0.3550862925063027d, 0.35118925598218914d,
					0.45094914200127934d, 0.8615992807013959d,
					0.6872426137930173d, 0.6342427315382997d,
					0.7142001805629566d, 0.6415700258555201d,
					0.6707810629983213d, 0.5966535675582668d,
					0.7599349396358281d, 0.5705507509900763d,
					0.5650464650646337d, 0.766321624871081d,
					0.6722505738971407d, 0.6904861044530781d,
					0.685542817808015d, 0.6848143320390092d,
					0.702732438147444d, 0.6622385865504683d,
					0.7887579651389591d, 0.6291500607733705d,
					0.5131420895307965d, 0.37737188289270795d,
					0.2944728621282432d, 0.22610652266207776d,
					0.1699977391355345d, 0.1334629389630394d,
					0.09508797122731316d, 0.08537472561229707d },
			new double[] { 8.969260762144824E-5d, 1.2211219220489998E-4d,
					0.033539861729035995d, 0.13910599506958068d,
					0.2017198295226292d, 0.22370404878809444d,
					0.3842140292953661d, 0.2612018960077123d,
					0.27798036534875603d, 0.3307769340405473d,
					0.37063295441837113d, 0.25547028147016465d,
					0.29675835928471217d, 0.31260630759216196d,
					0.2899142034390438d, 0.3551684066584732d,
					0.26879779095795225d, 0.3321067100813833d,
					0.3715156489290324d, 0.36754179996226766d,
					0.39184512767600377d, 0.36195692118780437d,
					0.434687193006883d, 0.44294440458708706d,
					0.3946405776802843d, 0.3707803370167086d,
					0.469545746721479d, 0.394105810476716d,
					0.42599859594536194d, 0.38722609726652746d,
					0.5358028474097134d, 0.4977904075242919d,
					0.4882986625917712d, 0.5917352317201761d,
					0.4826829726612803d, 0.5161695441934596d,
					0.47672890139539226d, 0.5328297668963992d,
					0.5443607156041165d, 0.5470216196333095d,
					0.5366234772742369d, 0.47397887895317886d,
					0.5713782976375817d, 0.5890867070636493d,
					0.7740352668288039d, 0.6712113982756858d,
					0.8380797809903656d, 0.6675016435056388d,
					0.5933319954459275d, 0.6216457108861291d,
					0.5916228635543735d, 0.542881518982822d,
					0.6743841832135642d, 0.6711725744433431d,
					0.6006671808547015d, 0.6788932407164686d,
					0.5925068687964643d, 0.7052885531941356d,
					0.66326781526079d, 0.6696406716728162d,
					0.6176973136119437d, 0.660864200163254d,
					0.6667810341102962d, 0.7328822665767843d,
					0.7520084672231084d, 0.6312619816650449d,
					0.5535475739863002d, 0.6694593352742496d,
					0.8431141215865917d, 0.6191542985673273d,
					0.7601086463921142d, 0.6959131966213589d,
					0.6471473328625977d, 0.733224435106936d,
					0.6915976032616231d, 0.8860252973334829d,
					0.827903802645571d, 0.8020813589585569d,
					0.6826583287015894d, 0.6730690453466175d,
					0.7512842482710119d, 0.7957873113839349d,
					0.6569304194892847d, 0.5850410500961957d,
					0.9522668256202773d, 0.7197019017793073d,
					0.8459295382420545d, 0.8864936547383608d,
					0.7009155425370454d, 0.6977642052998032d,
					0.6702571109351029d, 0.7633723957052486d,
					0.7263779847477541d, 0.8163949699563873d,
					0.7848268066516323d, 0.6805616120533629d,
					0.6650991670707842d, 0.7193462600898479d,
					0.6912665937544165d, 0.8327853526494338d,
					0.6923678193799003d, 0.6633632169750089d,
					0.6330595809733166d, 0.7327295368487384d,
					0.7970238477461034d, 0.786975093094633d,
					1.009284637864185d, 0.8944762130022504d,
					0.9038825587439367d, 0.8155597625417098d,
					0.9152130974695466d, 0.9030969949060756d,
					0.8083350729742889d, 0.8645134988010253d,
					0.738390790565143d, 0.6737805144834076d,
					0.5908543504677688d, 0.6549570265374552d,
					0.7234174244094882d, 0.5811519168534959d,
					0.6973766338194684d, 0.6351731069956453d,
					0.6579321522790579d, 0.5586404705128076d,
					0.6660436187661701d, 0.6828456266513035d,
					0.6472460186949058d, 0.5574136082660041d,
					0.5904841544385573d, 0.5832456308261359d,
					0.55181924470838d, 0.6786855459876402d,
					0.6277547922356663d, 0.6277605190279478d,
					0.546292982046403d, 0.5436319471904008d,
					0.49748428784843785d, 0.48847293315832446d,
					0.4073946993493015d, 0.4884253857542596d,
					0.48899535319331927d, 0.7342448259342449d,
					0.8109113287766718d, 0.5255777149166583d,
					0.6085627187559824d, 0.5854782862500963d,
					0.6026763626647674d, 0.704963485207578d,
					0.6280754672327088d, 0.5227535144487413d,
					0.6063674040934873d, 0.576946330338264d,
					0.5404987836537448d, 0.571445083913353d,
					0.7971365196395971d, 0.6316117957598346d,
					0.5848273349032395d, 0.4586080768485147d,
					0.4076484023773487d, 0.279262130951296d,
					0.2161264195922079d, 0.16934223988874547d,
					0.12407534812083011d, 0.09735560859480033d,
					0.06532062455645676d },
			new double[] { 8.853508117217124E-5d, 0.0d, 0.16131658059856818d,
					0.17412589525818986d, 0.2802948755185098d,
					0.34674017917788325d, 0.32138364834948996d,
					0.3184554007312139d, 0.41167786542503015d,
					0.3397389145977427d, 0.3230228822010987d,
					0.27061825660605826d, 0.32430595181809957d,
					0.289698160664315d, 0.31476419614372014d,
					0.2783766476604437d, 0.48546260435288274d,
					0.3356740609577318d, 0.38051937699940547d,
					0.5033683965672069d, 0.41146309215634275d,
					0.3674131775851232d, 0.31879550681992835d,
					0.45189422533727214d, 0.3575237007403682d,
					0.36181056592272004d, 0.4244170650527772d,
					0.6112693685821309d, 0.45538062414536307d,
					0.499078849683797d, 0.4899780972888304d,
					0.44066260091764065d, 0.4677946729466636d,
					0.47994508615518383d, 0.41584484032749974d,
					0.41995344024716996d, 0.43114703124417486d,
					0.4282935883161785d, 0.41567543150433706d,
					0.4212112550240626d, 0.4525134170009817d,
					0.40814637593792963d, 0.4998920186612404d,
					0.8641608502934369d, 0.6441338095457098d,
					0.6393208980601096d, 0.6497852197967843d,
					0.6236141776994825d, 0.9863458902220901d,
					0.8825677665525066d, 0.619669949596115d,
					0.8094649571101786d, 0.9226345441608963d,
					0.5634336190512574d, 0.6312228880431129d,
					0.6417452337041321d, 0.60425635466341d, 0.611310399674878d,
					0.7422327034867923d, 0.9561851784514408d,
					0.7660046789177872d, 0.7368487296979576d,
					0.743406900708761d, 0.768958288950941d,
					0.7692097974393577d, 0.815110212982429d,
					0.9544982840980216d, 0.7248919111365831d,
					0.8717503024026201d, 0.6629851580221866d,
					0.7169321961130626d, 0.8095453412593377d,
					0.7580347811085195d, 0.7848574589007584d,
					0.6656777247407699d, 0.6535259520060177d,
					0.6486473021010097d, 0.6491136603455551d,
					0.6569923312055593d, 0.7127253331271105d,
					0.7116668048031538d, 0.7162344981935934d,
					0.7354803048981334d, 0.8124761781739819d,
					0.8687943554371073d, 0.8576851003640896d,
					0.9070648537042598d, 0.8887653352305955d,
					0.7252404493903374d, 0.8515151699896308d,
					0.797363727493824d, 0.7329675929157928d,
					0.8988582421575709d, 0.776895282903441d,
					0.7642113453390049d, 0.7289587845961599d,
					0.7801736039321207d, 1.0710718779176758d,
					0.8122968268866677d, 1.1108962968595637d,
					0.9043221729403078d, 0.7877244888676653d,
					0.8172874002212602d, 0.7099532239844102d,
					0.9191097750819813d, 0.9069859965210482d,
					0.8848407787033887d, 0.8037662858544559d,
					0.6718688861707932d, 0.7251795972942737d,
					0.6643657581078309d, 0.8204288833967511d,
					0.7785547372309466d, 0.844374132525245d,
					0.7720197133318885d, 0.6803741659744666d,
					0.6699131938740489d, 0.5773838179161035d,
					0.8830978570938989d, 0.5587502366056316d,
					0.6179672686079413d, 0.7205224683521455d,
					0.6038686030695943d, 0.7479141853311078d,
					0.6784824746798271d, 0.6417546952928773d,
					0.6252990034330137d, 0.5907842230698915d,
					0.6298683627949256d, 0.6504423133146523d,
					0.6843263833143312d, 0.8057638943020389d,
					0.6317618707563799d, 0.7008642400367966d,
					0.6231722347051505d, 0.7117482998289102d,
					0.6722243659792183d, 0.6900827303649493d,
					0.6370724814330183d, 0.6147406181853968d,
					0.7735077770714094d, 0.8430457483238266d,
					0.7922417739814736d, 1.0879194594410344d,
					0.8323957392853045d, 0.880420823868834d,
					0.6912258390620607d, 0.7956396937544646d,
					0.6595717024840718d, 0.6786576806495146d,
					0.6486841295876447d, 0.6614639908697841d,
					0.8054189785765179d, 0.6266743423682662d,
					0.532351671444609d, 0.602231410714184d,
					0.4438876007111144d, 0.36297486721062117d,
					0.29442736274135145d, 0.23652012925481342d,
					0.19782403226051873d, 0.13317862745126818d,
					0.10059262272117743d, 0.07197865419612012d,
					0.06848591491257858d },
			new double[] { 5.7134577796921486E-5d, 8.406320952955442E-5d,
					1.7246347673528434E-4d, 0.19457165775389892d,
					0.20169757146830827d, 0.28319726011017043d,
					0.33583120875317485d, 0.33608678898829597d,
					0.42851406095729166d, 0.363005511405365d,
					0.37817287296786894d, 0.3430675064783905d,
					0.33371986403207743d, 0.2757995924108309d,
					0.28885865612172507d, 0.3196320279943628d,
					0.49521530246586387d, 0.4924098355824454d,
					0.439660935906961d, 0.38535501823412965d,
					0.45181400670966815d, 0.3529926911432763d,
					0.5075905002794154d, 0.4166480448370859d,
					0.48431809600787606d, 0.4243281831058137d,
					0.47786587239893275d, 0.4509504100478344d,
					0.40133540275012464d, 0.4470987802162478d,
					0.3975242393855912d, 0.5029661358294785d,
					0.5141516523964682d, 0.39764256714089224d,
					0.44439197290049476d, 0.43661013195257875d,
					0.38473227555576395d, 0.4575155063424327d,
					0.6111369794192278d, 0.5382821406398688d,
					0.9536112131389757d, 0.9195914658939609d,
					0.711852584557103d, 0.7209868555612812d,
					0.6105131060474407d, 0.686715592227392d,
					0.6572608115777697d, 0.7438192922606004d,
					0.654469449236375d, 0.748968425000839d, 1.024118383884689d,
					0.7865524267011322d, 0.7244782597324444d,
					0.7922632100504096d, 0.8232882611207083d,
					0.7381784988001672d, 0.7283751525545877d,
					0.6958753558931478d, 0.7127494644889856d,
					0.8438765158602242d, 0.8211464299980555d,
					0.7703537236535243d, 0.7790573632920321d,
					0.7142921115635017d, 0.8883738347892223d,
					0.9158224406823662d, 0.6267211075599052d,
					0.8446336229260649d, 0.7966756534201397d,
					0.6842066938079441d, 0.5171353989255993d,
					0.702896782423582d, 0.7272455437063191d,
					0.8670861040174275d, 0.6911530461190325d,
					0.6639128126420322d, 0.6610820502302012d,
					0.7456127792779127d, 0.6283397121537807d,
					0.654127788457349d, 0.7397019015491838d,
					0.7085788410447611d, 0.8656600769852524d,
					0.6801561253132923d, 0.694708470049104d,
					0.6750224633692625d, 0.7679848592109331d,
					0.8582849820024715d, 0.7871623876971844d,
					0.8573087234346635d, 0.7137071843321623d,
					0.6385464120533507d, 0.7580106245650609d,
					0.7424667888915472d, 0.7754355098011763d,
					0.7391554016712508d, 1.081307239024109d,
					0.7844099840154353d, 0.8449475255311193d,
					1.0297904547439405d, 0.7355041696183358d,
					0.8087858022748305d, 0.8944320548710318d,
					0.8995318794076846d, 0.7441367280321032d,
					0.8321798508721124d, 0.9557578701371954d,
					0.8763547649359135d, 0.8045033393961879d,
					0.9303628991081244d, 0.539406852802536d,
					1.1370823260813245d, 0.7683442086278794d,
					0.9280749226563174d, 0.8871031230829735d,
					0.791027805082111d, 0.7983529178806018d,
					0.8745422679826912d, 0.8162263745825212d,
					0.8101747965258743d, 0.7051163211474992d,
					0.7420488355361851d, 0.7493261363406319d,
					0.7603723655053686d, 0.700500886751182d,
					0.6646188610595659d, 0.6628096392097419d,
					0.6786136864666285d, 0.6306513338069776d,
					0.7575186889539386d, 0.6779660033410861d,
					0.6513351963363416d, 0.7998276952221272d,
					0.6211439631828477d, 0.7358022022058542d,
					0.7417431357138254d, 0.7146316541672378d,
					0.8593027944975369d, 0.8069119012939848d,
					0.7193865142231886d, 0.8497635837024636d,
					0.7546387248387327d, 0.7770571558642874d,
					0.8436148274348563d, 0.7817611795667573d,
					0.8262238441601208d, 0.7550372898343666d,
					0.6975420533521586d, 1.271773395156856d,
					1.0067914443873254d, 1.010663839814302d,
					0.9597503856812606d, 0.7495669501391373d,
					0.8018062698551631d, 0.8155123244850434d,
					0.804133036487434d, 0.770432998608158d,
					0.6046039868149612d, 0.4664617852998513d,
					0.3797014525640289d, 0.2558231985675009d,
					0.20994725232519418d, 0.145544761443483d,
					0.12146375896498239d, 0.09275799326123844d },
			new double[] { 8.729563315536886E-5d, 5.9889915755238366E-5d,
					0.03192293578752964d, 0.03116251079972475d,
					0.11383405377805592d, 0.1811563187396842d,
					0.3221552430791154d, 0.32803711344313186d,
					0.4453860314111699d, 0.38218077097696534d,
					0.4180374046638287d, 0.45431769610447637d,
					0.35280707031568725d, 0.3347751220215306d,
					0.34878185665705347d, 0.4002958019938477d,
					0.3777538819673139d, 0.4463583048897764d,
					0.4506073665383002d, 0.5037107126662971d,
					0.472362388147662d, 0.5504013696197083d,
					0.4769634571313322d, 0.6553356680151365d,
					0.5323339509311715d, 0.4223516361080943d,
					0.7162270367786641d, 0.49671231222944096d,
					0.43894800817638485d, 0.4252996650087614d,
					0.39810077871562377d, 0.38599174217297955d,
					0.4259771523575316d, 0.40994303832191853d,
					0.5097770715748652d, 0.5172367579993651d,
					0.5558355699069234d, 0.642911462221358d,
					0.7002456892576572d, 0.8149175449435202d,
					0.7416548971526684d, 0.7597775765298523d,
					0.6948237166116792d, 0.7377742047056354d,
					0.659268466245796d, 0.7175848892852006d,
					0.6355282340260832d, 0.721524711228581d,
					0.7361540656200436d, 0.7731966566890753d,
					0.6536936995782467d, 0.8652424196150599d,
					0.944444757509084d, 0.9080734309560821d,
					0.9800296131613321d, 0.9807952057515195d,
					0.7343033985425304d, 0.7440149138576567d,
					0.9443225793677151d, 0.7380503456951193d,
					0.6778463674451923d, 0.6956680177215154d,
					0.8194596520381487d, 0.6957160029616377d,
					0.5816711901632585d, 0.6057798013023453d,
					0.6633219008866521d, 0.7097661262247175d,
					0.5696454008900952d, 0.7035713269468306d,
					0.6432669129534757d, 0.6392514754495133d,
					0.660223642401956d, 0.7222944166625104d,
					0.6714550151964871d, 0.7637367447219089d,
					0.8469761135496955d, 0.6944909974990245d,
					0.7861358925695118d, 0.757005509219125d,
					1.0361291266252877d, 0.694889615350558d,
					0.8071139611497798d, 0.7983508176166884d,
					0.8217617387230216d, 0.7771009958735207d,
					0.82927060472605d, 0.7902926211302763d,
					0.9219271077346932d, 0.7167093387279999d,
					0.904297549591574d, 0.7122854414314245d,
					0.6759787595561897d, 0.8188072551817422d,
					0.8413483794221198d, 0.8327392835241186d,
					0.8901356917072808d, 0.8249850859623264d,
					0.8173576665181429d, 0.6929754898078864d,
					0.7647666493137139d, 0.7969801744173393d,
					0.8604024351660475d, 0.8926601194100797d,
					0.9492898511722402d, 0.8946993836730552d,
					1.0497318543120409d, 0.9112984817667622d,
					0.9827996586218767d, 1.2625520353441946d,
					1.0101791184123923d, 0.842849679468587d,
					1.0676954769387397d, 0.9298404475692487d,
					0.7560324483378618d, 1.048424929021938d,
					1.100897602426381d, 0.8646924552145384d,
					0.7228739986557923d, 0.6278718834210757d,
					0.8267454098903563d, 0.8897497532714234d,
					0.8173440030333479d, 0.7434465408026346d,
					0.7264370036935861d, 0.7735588585034707d,
					0.7970501636329884d, 0.7307187687358424d,
					0.709838391957678d, 0.7243372885426981d,
					0.7461136162957663d, 0.830855093269319d,
					0.9345444030832912d, 0.8415332307050921d,
					0.922116802893641d, 0.7684222128573122d,
					0.9251902083899629d, 0.6973151157685951d,
					0.9262183644390716d, 0.7929555345507934d,
					0.6588494869220052d, 0.7195697019291354d,
					0.8200117055349351d, 0.7250891548675502d,
					0.7285310125749936d, 0.7801660738335648d,
					0.9254928762694662d, 0.6947093844776067d,
					0.7015925640511622d, 0.6850075792455458d,
					0.752358944330656d, 0.8688638908706542d,
					0.9394839697189894d, 0.9001446592558626d,
					0.8083745755046943d, 1.044556377651518d,
					0.6909293655016059d, 0.5970221315945093d,
					0.4518673853019134d, 0.2847230563433035d,
					0.2333394587673878d, 0.1684062178558826d,
					0.13002574680468598d, 0.1033530593455771d,
					0.05970928127549451d },
			new double[] { 4.292659639786733E-4d, 3.269614066197543E-4d,
					0.1312959733568344d, 0.15210583453045165d,
					0.3918879647511596d, 0.31031529518567247d,
					0.296227398075103d, 0.31760542195677327d,
					0.29650440743516077d, 0.33470080177973394d,
					0.36632304017812306d, 0.38752528392372754d,
					0.3801764981502064d, 0.4917092805995139d,
					0.5401753214740297d, 0.4222715138877876d,
					0.433642849000806d, 0.4846068955989113d,
					0.4917265119467693d, 0.49906764596848013d,
					0.5595770437034061d, 0.4264680869965432d,
					0.4855227473089658d, 0.5085472160965017d,
					0.5462783742179853d, 0.35737258224408563d,
					0.359038739948453d, 0.3877829812974743d,
					0.34189934159903795d, 0.40408592357871437d,
					0.3881145947792061d, 0.47846593057967896d,
					0.41495722665647716d, 0.4673021003712214d,
					0.4754986313715275d, 0.5577920366489161d,
					0.6930406275057498d, 0.6348601109855041d,
					0.6536298227064385d, 0.8106589398537077d,
					0.7525464522676855d, 0.7108901613987915d,
					0.7616369089962131d, 0.7517486480471448d,
					0.8380115264270571d, 0.7506822651776712d,
					0.690915292042303d, 0.700396485947909d, 0.680992801012178d,
					0.7178716573612002d, 0.6165667454623874d,
					0.6244408192723061d, 1.0400116901107104d,
					0.6920568431414873d, 0.8303739435651422d,
					0.835979094209025d, 0.912051659807858d,
					1.0780804688207226d, 1.0071816819004142d,
					0.9259881621061382d, 1.0294729132856466d,
					1.0192927435519208d, 1.1282939028254715d,
					0.9182754098766673d, 0.8718096376274028d,
					0.8326326378589035d, 0.822518714824854d,
					0.7822151849929787d, 0.865805493266172d,
					0.9175477100469177d, 0.7158424823738087d,
					0.7537724505550628d, 0.8091472262927064d,
					0.8206164609906585d, 0.9985254157741954d,
					0.786532975857275d, 0.9017221274622459d,
					0.7904195524258157d, 0.7901508309480225d,
					0.7201371121422903d, 0.7841229740791417d,
					0.7491496076204731d, 0.7599594795140255d,
					0.8697984805922437d, 0.7260843163453982d,
					0.8646153053381693d, 0.9447478144904488d,
					0.686006076557033d, 0.7581230813283006d,
					0.8117582848709239d, 0.8259946069576183d,
					0.7698170892428386d, 0.8076289779958251d,
					0.8316273462644012d, 0.8906238707043111d,
					0.8204209594991531d, 0.8640854057185707d,
					0.9140066360241849d, 1.0449773949582508d,
					1.0753543031903816d, 0.7203010433311445d,
					0.8317372894137954d, 1.0608958049454935d,
					0.9163057594043731d, 0.8569114585784346d,
					0.9689876814217127d, 0.8236812344518609d,
					0.829918377229423d, 0.8694164383577723d,
					1.030593034495615d, 0.9461448949463185d,
					0.951277024286752d, 1.1867633884277162d,
					1.0971045861393558d, 1.064017915238936d,
					1.1487654353900856d, 0.7701690275284145d,
					0.8738612061047525d, 0.8006161648703455d,
					0.8685195651814969d, 1.1363919743654038d,
					0.8326181815696063d, 0.9256077582801264d,
					0.8028053862800281d, 0.9414776778261424d,
					0.7732533122023206d, 0.7004266231902285d,
					0.7890577547668081d, 0.8513392417897315d,
					0.7749615802248626d, 0.8081212099652662d,
					0.744305001694577d, 0.7514099946169709d,
					0.8034427100698717d, 0.7086572001895766d,
					0.597140796510654d, 0.5734229509454396d,
					0.7232791574158319d, 0.832617144685918d,
					0.8100980538520437d, 0.8960919646325899d,
					0.7587067962527239d, 0.7839947016345963d,
					0.6053224004420984d, 0.724038037719148d,
					0.8085609732859426d, 0.7695225231753067d,
					0.844176499388617d, 0.8080054377721028d,
					0.9077335790013984d, 0.6843901465900893d,
					0.7097675375092616d, 0.8065905953153034d,
					0.8027265629508356d, 0.7694467812996099d,
					1.1190215999668351d, 0.7527865405636889d,
					0.5938064141166981d, 0.4184903383166282d,
					0.32162594311136894d, 0.22308473676034915d,
					0.18550089765065694d, 0.13278304704153215d,
					0.09122631856059044d, 0.06605094466315883d },
			new double[] { 3.0069579548164755E-5d, 1.1900125210976845E-4d,
					0.030285352017006988d, 0.14658939034894922d,
					0.2747259083867465d, 0.4038953216315871d,
					0.3522478184780098d, 0.44883770429359887d,
					0.44214410386956365d, 0.38546205850433535d,
					0.46428646305847066d, 0.40484693926941123d,
					0.4842008281299709d, 0.39381516310150655d,
					0.3958434185974338d, 0.5057336599630942d,
					0.4814721174406969d, 0.5091330535590484d,
					0.5182987753975796d, 0.4067114578154948d,
					0.4134374229573549d, 0.4181152715407433d,
					0.5568149180312164d, 0.5153069852551458d,
					0.45784456860664285d, 0.5263198284097859d,
					0.5267287159813422d, 0.5015573262596781d,
					0.46353325802271456d, 0.6314821466017925d,
					0.4900232494380626d, 0.553825463136902d,
					0.46627508885087615d, 0.44492567434464586d,
					0.6417774645332265d, 1.0174775059671397d,
					0.5895272024851603d, 0.7695903053454858d,
					0.6821552095541802d, 1.0520830469151257d,
					0.7074229863394069d, 0.8470904660080906d,
					0.766247279356208d, 0.911918544762064d,
					0.8380063830505066d, 1.0090260187649915d,
					0.9007910391410415d, 1.0127812269069034d,
					0.8380239339103266d, 0.7465219217288911d,
					0.8581530078110037d, 0.8224428655630741d,
					0.9420551337171046d, 1.0432840068576317d,
					1.172600193760246d, 1.0239222213734027d,
					0.9472133508948197d, 0.950641889473345d,
					0.8635092153465947d, 0.9290941770234393d,
					1.0362778419800136d, 0.8791484528024828d,
					1.1113866565876767d, 0.879598720955407d,
					0.9277179825489301d, 1.0400625393752059d,
					1.347041132937031d, 1.1713732968973953d,
					1.0607454508906256d, 1.1318491031958093d,
					1.1028267206828852d, 0.9645846971084018d,
					1.1632810282704744d, 0.9028504799904985d,
					0.9387517613493076d, 1.0408602402567277d,
					0.9091976466011489d, 0.7330458517646905d,
					0.8523407643745563d, 0.7963609812143447d,
					0.9123384120955128d, 0.7892026644878589d,
					0.924293539013336d, 0.7693271673042101d,
					0.9276577042528275d, 0.942774005407845d,
					0.8823544828317997d, 0.9698136574929292d,
					0.9524818157763265d, 0.9671020285877683d,
					0.91021429233628d, 0.8009114173919355d,
					0.9347263822587054d, 0.9828627710348102d,
					1.0146367452676834d, 1.0660874358890453d,
					0.829996225749436d, 0.8332913237732117d,
					0.9029004042945786d, 0.8261321460630556d,
					0.9087264657037657d, 1.082213216785503d,
					0.9167516362209461d, 1.064932833076161d,
					0.8330319190082973d, 0.8741770738678237d,
					0.8523077488466013d, 0.8056916143924698d,
					0.9478699944696032d, 0.7625394229892093d,
					0.9335720951501766d, 0.8436418911620239d,
					0.9341819724923477d, 0.9547182646604495d,
					0.8361575829656835d, 0.8589992089983611d,
					1.2805774133870182d, 0.9597399868060614d,
					0.9355149064269805d, 0.8744838067170005d,
					1.0963858880848334d, 0.8188364897781861d,
					1.6003883052316228d, 1.044135854235486d,
					0.8266502393582644d, 0.8789703438731543d,
					0.9561474576224036d, 0.9869301120360408d,
					1.204312198370954d, 1.0329018054184715d,
					1.0699853157214048d, 1.0267171253325762d,
					0.8654899595138826d, 0.9429278949376051d,
					0.8811651772535755d, 1.095174755540043d,
					0.8414827367831283d, 0.8800761241608023d,
					0.9609153082937838d, 0.8804243436953403d,
					0.8674601076568962d, 0.7923994179350374d,
					1.057752490062422d, 0.9094898668083314d,
					0.7632864259425708d, 0.824641378079237d,
					0.8348736351299793d, 0.9745262558557986d,
					0.8211541348596051d, 0.8116448392992333d,
					0.839011990297982d, 0.8278373949654504d,
					0.8364737212711842d, 0.8812587240391824d,
					0.923591961673635d, 0.7090322774768804d,
					0.6866962630934336d, 0.5571259416815253d,
					0.3779569178529945d, 0.24856227641437711d,
					0.21116889686113952d, 0.14965280828862376d,
					0.10329714817341452d, 0.07720259368716698d,
					0.05890971919233601d },
			new double[] { 5.743917085524186E-5d, 2.4023835138361314E-4d,
					2.032931220633068E-4d, 0.16284313820106103d,
					0.28734889371137684d, 0.3499851727131281d,
					0.3950463352651114d, 0.35554308487111197d,
					0.349951617487388d, 0.5149432491251186d,
					0.38802697824770904d, 0.3575149062969182d,
					0.39039971183554867d, 0.45539426534901584d,
					0.4288286395784479d, 0.458502989282452d,
					0.44541060552970685d, 0.41032254232056664d,
					0.4501955861653454d, 0.5655716492462713d,
					0.49955220531215455d, 0.446153031890865d,
					0.49269555469667775d, 0.5208083785226294d,
					0.5771542964703463d, 0.5776072663711104d,
					0.5938970674096714d, 0.6732791056506089d,
					0.7589736558659909d, 0.6697668447125803d,
					0.8800033174004236d, 0.710330887917462d,
					0.645478387779649d, 0.816243762082606d,
					0.7868787515315945d, 0.6506162572240797d,
					0.6611841799625394d, 0.7550099072681313d,
					0.7197665149737948d, 0.8673519660229028d,
					0.8549994203560183d, 0.9084976336306123d,
					0.8422080257721208d, 0.9982912722206706d,
					1.0203167425391113d, 0.8326961156642712d,
					0.9026600696586774d, 1.0798360018058597d,
					1.0132640099188976d, 0.9301883840541123d,
					0.9112183028514613d, 0.9228027661931216d,
					1.1329834735764672d, 1.0608241729613404d,
					1.2066334463623392d, 1.0360621471478813d,
					1.040459327852882d, 1.042921695688357d,
					0.9146799984715352d, 0.9204564698324542d,
					1.1718836410306532d, 1.0140302695950496d,
					0.9579924054519301d, 1.0097081459533435d,
					1.25998835664983d, 1.0559636387568445d,
					1.1913316884275285d, 0.9604706609209176d,
					1.1191048032736184d, 1.0105713378784307d,
					1.2313088359470314d, 1.1188568782501023d,
					1.409157100067965d, 1.1491427848465579d,
					1.1073816825251377d, 1.0186958704781781d,
					0.956645494708639d, 0.9386583127048131d,
					1.1841800061784429d, 0.9069190234017142d,
					0.9560253893435805d, 0.809886535181726d,
					0.8471566172725505d, 1.070670889502011d,
					1.0922900380358642d, 1.0099919677736788d,
					0.9306139706235251d, 0.7569505043923311d,
					0.8105260912129388d, 1.0223380469484868d,
					0.9385111898000759d, 0.9331442794199589d,
					0.8117305695345257d, 0.8190796702816523d,
					0.7856377095818937d, 0.718280051434608d,
					0.7952809771346764d, 0.8255566699829663d,
					0.9201150934887636d, 0.77647710066176d,
					0.7596953068836053d, 0.7169467077531049d,
					0.7739208498963557d, 1.0879358913205988d,
					0.8216056743801716d, 0.8181359401715245d,
					0.8016152009951144d, 0.8541701184253063d,
					0.871499459785959d, 0.9469415103374295d,
					0.8466278237010063d, 1.3360582472796725d,
					1.2478510323559682d, 0.956699421359636d,
					0.9038321363129199d, 0.9051734547330357d,
					0.8216577741953676d, 0.8938647345784267d,
					0.8783901291064979d, 0.8735887853233454d,
					0.9586066297326112d, 1.2744530412226556d,
					0.8680376580556489d, 0.9788937268545902d,
					0.8116190256579928d, 0.9008834933828007d,
					0.9631624566354873d, 0.923529353075178d,
					0.9929638587986106d, 1.1761799994180624d,
					0.7612975659478541d, 1.0232572153770916d,
					0.9588049770193474d, 0.9496608922634977d,
					0.9077494862293074d, 0.7652939521266633d,
					0.9423412934749387d, 0.9107675512427114d,
					0.9693709320943545d, 0.8796466769087239d,
					1.0206407309288865d, 1.0301004155224922d,
					0.9119841921626994d, 0.9637190916081599d,
					1.0140480775757252d, 1.1444875863289279d,
					1.087362008859848d, 1.056845382061029d,
					1.1808890883532035d, 1.1492485407607318d,
					1.1026447073612888d, 1.088271072887807d,
					1.0580658603339443d, 1.0265017378982628d,
					0.8600905966146694d, 0.9882422962987573d,
					0.9270296264945694d, 0.6537266640923066d,
					0.546737410507543d, 0.4020108366676356d,
					0.3221277832862622d, 0.20214776191024078d,
					0.16137475315073377d, 0.11625866335591342d,
					0.09836552858037557d },
			new double[] { 0.0d, 5.937048037290964E-5d, 6.914611951865391E-4d,
					0.36104149615791575d, 0.29477118291816584d,
					0.31508531697197795d, 0.34343686391668876d,
					0.5691888592619573d, 0.3860686558819695d,
					0.5771267518310425d, 0.3842781839263573d,
					0.47487702295522516d, 0.5335580924674689d,
					0.5370133678006631d, 0.45570156571902104d,
					0.4613228610870806d, 0.5301847883789821d,
					0.4631057209780063d, 0.4409089908326094d,
					0.5994907764373262d, 0.48809074816823667d,
					0.46410841696274757d, 0.5014315043082445d,
					0.43064857245274274d, 0.4948086025177422d,
					0.5562573650572392d, 0.5737685937146451d,
					0.6532404260944003d, 0.7208606870493076d,
					0.7495874415106621d, 0.7131957685009959d,
					0.9377076256468503d, 0.7416474204470125d,
					0.7732720027599002d, 0.8239115268877543d,
					0.9218456443530751d, 0.7463082266764475d,
					0.8469771510656615d, 1.0432895308255912d,
					1.0841716581026049d, 0.8794329930632534d,
					0.8203370856185415d, 0.7511433419971205d,
					0.7650735840702568d, 0.8823032641748051d,
					0.7683470390196036d, 1.0202432370990493d,
					0.7971869846208333d, 0.9313191893704986d,
					0.9528379181912797d, 0.9405203988847712d,
					0.7512095350174567d, 0.8947567372544776d,
					0.8966966396134505d, 0.9045036926437738d,
					0.9829259229745122d, 1.0482661421174762d,
					0.8331307148033298d, 0.7969416238227766d,
					0.9531743043991023d, 0.8372938759215116d,
					0.8735282866856802d, 1.017373102589454d,
					0.9317803789059549d, 0.9361040992715076d,
					1.1738906929993054d, 0.9158292518771464d,
					0.9881137335058724d, 0.9758535844035473d,
					0.997112839154496d, 0.9599695059878123d,
					1.0791974700633116d, 1.3336047137062539d,
					1.8221413030213378d, 1.3229349677503015d,
					1.3216987570858507d, 1.0270379634182463d,
					1.2626360706958435d, 0.9017661380842307d,
					0.9769742622719825d, 0.9746321757178996d,
					0.8796597113595037d, 0.7890966427888954d,
					1.0018814167040124d, 0.7790846878572266d,
					0.8578540028183061d, 0.8452687781110132d,
					1.1814387211528048d, 1.0137749269836545d,
					0.9124314994515139d, 0.8342474473535365d,
					0.9716201293359291d, 0.9232801265499855d,
					0.839135821680987d, 0.8388442672878595d,
					0.8968958829019271d, 0.8564869417122378d,
					1.0305299921305924d, 0.9874087616953681d,
					1.061885124939649d, 0.9203510467622628d,
					0.7956390838301654d, 0.9442952099966045d,
					0.9583684302896969d, 0.9767585050520121d,
					0.7430593395355465d, 0.9211758750233875d,
					0.833799220465339d, 0.8448581856342371d,
					1.0324227893896185d, 0.7757635438720557d,
					0.9630773393094456d, 0.8862019812143456d,
					1.0923113184791746d, 0.8462485460526351d,
					0.9707806953230578d, 1.0167100640363853d,
					0.9488620459923698d, 1.027368851138872d,
					0.8684031164911641d, 0.9600339609149909d,
					0.868372802901778d, 0.9733168886361385d,
					1.0929015034234644d, 1.1901699741642902d,
					1.373464346087893d, 0.9278286670894799d,
					1.0430844343410761d, 0.9110675119511512d,
					1.104823054754052d, 1.0362977190289917d,
					1.0210675780524006d, 1.1732389728515833d,
					0.9825397519959467d, 1.0859715549480327d,
					0.9376664005464866d, 0.8865057703722146d,
					0.99269469740138d, 1.0755034963874315d, 1.04763798320847d,
					1.053671038707781d, 0.9888613272223351d,
					1.0162726655736674d, 1.056473246292778d,
					1.1144893732763859d, 1.0861213886744185d,
					1.1097493978864548d, 1.159301886721946d,
					1.3673434807910505d, 1.115407695070453d,
					1.2777653935663222d, 1.0906622405761723d,
					1.0569439945089163d, 1.2149954222863626d,
					0.8342869062275112d, 1.0409008548198284d,
					0.9951296635897178d, 0.7501161379989585d,
					0.585110290059965d, 0.3903344360074833d,
					0.2677227400615033d, 0.20307978075523633d,
					0.21851686558753286d, 0.1240062706128891d,
					0.09037266257333165d },
			new double[] { 1.1729695812934753E-4d, 8.170269112704589E-5d,
					5.5689009633873365E-5d, 0.14731925075974778d,
					0.2565926014428685d, 0.26596683009376765d,
					0.36198435643590476d, 0.3835887882417902d,
					0.44999683163689763d, 0.4408325650597519d,
					0.4404532360320087d, 0.44813946522014336d,
					0.4583711994748169d, 0.49735375569970586d,
					0.44201153436824814d, 0.4366945020933357d,
					0.4973930500910444d, 0.43597869633370884d,
					0.5162987190929283d, 0.6073470291032753d,
					0.5709146058701242d, 0.6365839450770006d,
					0.7734591881014878d, 0.8462843635770303d,
					0.7048838370875347d, 0.6586609201023184d,
					0.7088801484589399d, 0.7281882108735256d,
					0.8048150044056835d, 0.7222123488461177d,
					0.8046906591159508d, 0.7074813387336476d,
					0.7866133125201309d, 0.6162175458563002d,
					0.8196672753039401d, 0.7851394693960403d,
					1.0274962099198113d, 0.8261537134193464d,
					0.8512769344656582d, 0.8328167308968017d,
					0.7666731314249448d, 0.8951495684700931d,
					0.7917932696446621d, 0.967314468144289d,
					0.8784861499924792d, 0.9148684223951672d,
					0.8225573789919699d, 0.9032345397936232d,
					1.0429042710873835d, 0.9036344315072737d,
					0.7964517819403272d, 0.949627356866667d,
					0.8909364805367747d, 0.623058826106149d,
					0.9738175592816113d, 1.15272467480975d,
					1.1289339387787134d, 1.158306668682951d,
					0.9094307660373676d, 1.040806808857412d,
					1.0045298753618845d, 1.0599244945331507d,
					1.1126287703151465d, 1.0587395607440246d,
					1.6217451993734648d, 1.3610580502889014d,
					1.2273871783431247d, 1.1088410554176025d,
					1.4616892094599756d, 1.1697143621726862d,
					1.0233203615149433d, 0.9919524420081257d,
					1.0239046192932917d, 0.9889551607551854d,
					1.0828660387889537d, 1.0965165836288646d,
					1.192399636512019d, 1.315163412500302d,
					1.6168866734521696d, 1.312833952980874d,
					1.3726748284324892d, 1.0002356752139792d,
					1.2913372492555744d, 1.2992210409117475d,
					1.2334789359559564d, 1.355288497738066d,
					1.082712901531363d, 1.0868207157857317d,
					1.0835190776328067d, 1.1307556013712428d,
					0.87776031262899d, 0.9448685448983816d,
					0.9668740950527387d, 1.0683171666435405d,
					0.9024955150084127d, 0.9254006495496409d,
					0.817371249423398d, 0.962647070681405d,
					0.9474281427689129d, 0.8013111342454226d,
					0.9023576293598701d, 1.0821223311810915d,
					0.8529515968457774d, 1.3249577326608704d,
					0.8922164699881631d, 0.904659896291703d,
					1.0906207772539005d, 0.8878502332901445d,
					0.9635141891229633d, 0.9960404467021702d,
					0.8101847291967483d, 0.9707677100798626d,
					0.5959270299666223d, 1.2029842326969267d,
					0.8693598917415635d, 0.9378449823279273d,
					0.8913241012418189d, 1.090184888667107d,
					0.9975431193131872d, 0.9944279531473037d,
					1.0733886426282868d, 0.9466295816616306d,
					0.9172939993483278d, 0.9148927795491113d,
					0.766143685164959d, 0.8023119185039942d,
					0.8953542421468206d, 1.3494550923284276d,
					1.0380189924737262d, 1.2708203433827965d,
					1.177862559096096d, 0.8962520590784165d,
					0.9503775242300321d, 1.0156897079454668d,
					0.994591404592995d, 1.0377418213679457d,
					0.8605989557674047d, 0.9144491591440095d,
					0.9314554936183376d, 0.8999474840737467d,
					0.9545316536766764d, 0.9780502783910666d,
					0.9863875346127448d, 1.0816157032937437d,
					1.0530988656176652d, 0.9907593298612171d,
					1.0943460064776824d, 1.0511254695245884d,
					1.3175286655038114d, 1.099813775494557d,
					1.1404235734335226d, 1.1947574521937139d,
					1.1734105441132086d, 1.0118963769074703d,
					0.9902923963446325d, 1.080831725746239d,
					1.0069476130025778d, 0.7468219757666148d,
					0.5702522630072753d, 0.4426910602363752d,
					0.3252170909555305d, 0.23358002631207453d,
					0.16689209104361397d, 0.12984863134317493d,
					0.08112385453779491d },
			new double[] { 0.0d, 0.1004783753017796d, 0.2319709101048101d,
					0.3884338608659725d, 0.33652084014405553d,
					0.368988714357478d, 0.410587947633962d,
					0.39934520214009545d, 0.44794370745897094d,
					0.3931043235313248d, 0.44144170223269674d,
					0.429815037850364d, 0.5589162448673402d,
					0.43690179057909395d, 0.5027903655094605d,
					0.5742745495232084d, 0.46718105895398016d,
					0.53406064309538d, 0.5132099058053123d, 0.612686258026288d,
					0.6975406611997091d, 0.6495889974751754d,
					0.7783135945269284d, 0.705842905938721d,
					0.8324725825945963d, 0.7897716182105344d,
					1.0553804217670604d, 1.108714490521582d,
					1.0810742924336603d, 1.0735960339568495d,
					0.9289251190333502d, 0.882308768357976d,
					0.8188261759713593d, 0.8525617519320763d,
					0.7956185503309808d, 0.7499405197348358d,
					0.8252958929241918d, 0.9379326884001273d,
					1.0583028767953622d, 0.8410401339660479d,
					0.671481859958548d, 0.8506614653126184d,
					0.9506896526783447d, 0.6394977538720248d,
					0.7012234118882068d, 0.7919431755760186d,
					0.7649324507852979d, 0.790387456384447d,
					0.7091867594007785d, 1.0082692745700272d,
					0.9717166788073323d, 0.8828931493995775d,
					0.8750860676122205d, 1.137768599313568d,
					0.9200262026599797d, 0.9270279462880048d,
					0.8379719062202172d, 1.0999003673692398d,
					1.0087707542956454d, 1.0912485559608727d,
					1.0776913192058937d, 1.0879610239566229d,
					1.1647025862441163d, 1.04021048137965d,
					1.0136667976027227d, 1.2774659322769055d,
					1.0572751117911448d, 1.182624493600263d,
					1.0830502261659343d, 1.0421020173186308d,
					1.2316595116303495d, 1.0765557742662912d,
					1.0825350808647283d, 1.2736913140195774d,
					1.1273390188315622d, 1.2208633022754753d,
					0.9914286434844304d, 1.6746544088092654d,
					1.2122854973530988d, 1.0183337141159639d,
					1.1600108641243425d, 1.1600202840141993d,
					1.125533894112889d, 1.3724744958016983d,
					1.1169844056425282d, 1.5775044477366804d,
					1.1838760689836751d, 1.6725340409442673d,
					0.9670165989165778d, 1.146733375171667d,
					1.067105027764825d, 1.004852116043951d,
					1.3878208077608665d, 0.9718594431726228d,
					0.8911465006426956d, 0.7910113797324422d,
					1.0110487159470707d, 0.8979442312674003d,
					0.9001734075651243d, 1.2070967390785639d,
					0.9408587916899444d, 0.9772294187530193d,
					0.9513931005085678d, 1.1941842893297716d,
					0.8853783773626998d, 1.046597562887328d,
					1.0255987119695433d, 1.1092653381221527d,
					0.9623036572477012d, 0.8839869587278623d,
					0.9133708464549312d, 0.9733292678919394d,
					0.930297335680685d, 0.9658596078768494d,
					0.9601549017197678d, 1.060114063222376d,
					1.0687479922390146d, 0.9650347939645775d,
					0.9807031740391626d, 1.0717812638594695d,
					1.0325107207826236d, 1.0176341953475845d,
					1.438552730191797d, 1.017792889733679d,
					1.0867038108750966d, 0.9578248470415424d,
					0.9692456617169635d, 1.0272242836221774d,
					0.9050135732681012d, 1.1404826865261344d,
					1.0412141983729548d, 0.9795514221846561d,
					1.1168716898561624d, 1.0217338006388936d,
					1.155284678899397d, 1.0388115203083117d,
					0.9874270255457249d, 1.0034713455318025d,
					0.9965467325460581d, 1.092796031347299d,
					1.0345617238181641d, 1.2875140241140968d,
					1.0377654930377207d, 1.0839556159896218d,
					1.2062010074996563d, 0.9157783053590632d,
					1.1838609812156127d, 1.0324339493405268d,
					0.9550699262804877d, 1.156969986387187d,
					1.0534227006586188d, 1.1154135550495758d,
					1.2852403127577428d, 1.07224079936898d,
					1.1014346634334553d, 0.8917439782977848d,
					0.6719627370621937d, 0.5350876514529861d,
					0.35429446195401465d, 0.2527323009333888d,
					0.20139641210401638d, 0.15777065136411875d,
					0.10465439091505173d, 0.08898904545289861d,
					0.05525198023532418d },
			new double[] { 1.1830779427160327E-4d, 5.862784728562127E-5d,
					0.005287541766655521d, 0.19792493215234402d,
					0.3349959213079282d, 0.49052675248485167d,
					0.3762402402649908d, 0.4763948745952665d,
					0.3668196898783214d, 0.5023054249075302d,
					0.43329281169942224d, 0.4744868050157615d,
					0.483508570027639d, 0.5544094874807964d,
					0.5521773869429627d, 0.5982776763253642d,
					0.5732249095531513d, 0.49829084854249006d,
					0.6373000036200736d, 0.4953843388719673d,
					0.45689863860046864d, 0.6664728964811494d,
					0.5519463532985587d, 0.635080777634319d,
					0.7184591358345144d, 0.712879324637054d,
					0.828660856214046d, 0.8481212867217452d,
					0.7110646341047292d, 0.8690126284723821d,
					0.9027657373934374d, 0.934894676828147d,
					1.4739687160790036d, 1.1627658214878467d,
					1.159645754235096d, 1.2771869429906644d,
					0.9105819580038018d, 0.8316838766485918d,
					0.8378287099832089d, 0.7862377592158629d,
					0.7524429028305777d, 0.7888338951224484d,
					0.7887318839727767d, 0.6665045144514115d,
					1.0189042685543264d, 0.7887066007041519d,
					0.7838431825372488d, 0.9622173599335017d,
					0.8173345832185268d, 0.6671050701429238d,
					0.7346805019444799d, 0.629699013355381d,
					0.823497227545121d, 0.7767171024783572d,
					0.8327368906733719d, 1.0042730933398434d,
					0.9910591777530268d, 0.9598891744392486d,
					0.8031529105171801d, 0.9014919971914668d,
					0.9557284655590434d, 1.3536680443342977d,
					0.9613646243332007d, 1.0847701656520177d,
					1.0091592763729698d, 1.0550430419068009d,
					1.133725074757541d, 1.0430610287907887d,
					1.0237823015210223d, 1.10703780209637d,
					0.8605063761290876d, 1.0367638078504677d,
					0.9997778236494852d, 1.2364838537202312d,
					1.0005468478911785d, 1.1867189666895483d,
					1.0111969117016912d, 1.3686550593457263d,
					1.3657433078666994d, 1.3830686545762598d,
					1.1962744145573974d, 1.4318852649172227d,
					1.7490388405790558d, 1.729403096497297d,
					1.3899389233124573d, 1.4396436470727882d,
					1.6762337435072616d, 1.2618408448982947d,
					1.1361753636745762d, 1.521713169050058d,
					0.9309280703241448d, 1.156604356288071d,
					1.1860514333334722d, 1.073410884226272d,
					1.0965417755147955d, 0.8335118631514841d,
					0.8555923314268035d, 0.9208526096603161d,
					0.9476090430215761d, 0.9089902202729951d,
					0.9397020770581175d, 0.9087449017192949d,
					0.9926350350771159d, 0.8601908984266176d,
					0.9082259349999637d, 1.0292287666407212d,
					1.0041817499502854d, 0.9651914615554902d,
					1.2094551241531093d, 0.9855203251848164d,
					1.0386129791793395d, 0.9683922545187658d,
					0.9863534272317431d, 0.8988055155686001d,
					0.9053839641158657d, 0.9049568169408997d,
					1.1749029958687387d, 0.9450993152673117d,
					0.935400825972483d, 1.0856754711153045d,
					0.9439285154587289d, 1.0474365880180574d,
					0.9683942691721531d, 1.0046849941529827d,
					0.9702455207975772d, 0.9749294491069738d,
					1.0412209808484325d, 0.9534163781879714d,
					0.9093006663586353d, 1.356912900199077d,
					0.7345172973621693d, 1.041520632694587d,
					1.096108267790089d, 1.067369586042538d,
					1.2086495194475815d, 1.151635089596232d,
					1.1803022542190553d, 0.9896085989712774d,
					1.0084344616547944d, 1.2196073111611074d,
					1.1851365246614194d, 1.0915201740492335d,
					1.1237023736845335d, 1.6056420134549478d,
					1.2235332949823632d, 1.0865202335654751d,
					1.012684710733624d, 0.862161746070677d,
					0.8014385555917322d, 1.0514675483011324d,
					0.9574088316386531d, 1.081163108519832d,
					0.9335165159567741d, 1.061466997004297d,
					1.0956767138760628d, 0.9256148843266829d,
					1.0684606724127168d, 0.6803353254059341d,
					0.54499188862309d, 0.38391582775484345d,
					0.28026848543173505d, 0.24579580691222452d,
					0.16997207930121544d, 0.10502667955352017d,
					0.09136117472769115d },
			new double[] { 3.0418590269660375E-5d, 0.0d, 0.3788493819629854d,
					0.24317476674136065d, 0.46792853357997377d,
					0.5030207593955405d, 0.6709526347463739d,
					0.6929898245209858d, 0.5933204559312355d,
					0.6742102997897959d, 0.5373309044619903d,
					0.5752800956838783d, 0.6261005478446126d,
					0.5509888683956324d, 0.7380260697530779d,
					0.5799425232097841d, 0.47586018688477544d,
					0.48597330480589335d, 0.5651251640799461d,
					0.5592098932649381d, 0.5978223268458817d,
					0.5935468273218527d, 0.5877859664139731d,
					0.5853891241488454d, 0.7150888172825939d,
					0.6536363397308623d, 0.7187011429428933d,
					0.7085003582587613d, 0.6434149962498442d,
					0.7209109587956601d, 0.835031109500216d,
					1.0243883998472914d, 0.9339109109307631d,
					0.8476207106645984d, 0.8609078873034248d,
					1.0893950822796608d, 1.2692288523091395d,
					1.0054168527124512d, 1.2764335029959137d,
					0.9435041570849034d, 1.0263477405095012d,
					0.8456465043692662d, 0.8413558272277986d,
					0.9973056253783247d, 0.834437426862644d,
					0.7524992890409835d, 0.8205778451156129d,
					0.8173990372374634d, 0.6408755816454342d,
					0.8008079182567576d, 0.7472613997316868d,
					0.8684837108709124d, 0.7833168657508469d,
					0.745196547759247d, 0.6842849805592494d,
					0.8365979111293863d, 0.8103215262853053d,
					0.8917309369446967d, 0.8113287126181511d,
					0.8300981976909815d, 1.3409791116409933d,
					1.0212650073693164d, 0.9860030599116788d,
					0.976385013996713d, 1.0245477506458436d,
					0.8902465832697589d, 1.0587777051798049d,
					1.2267430160393444d, 1.1270175041086623d,
					1.0490515742885356d, 0.9841698591996451d,
					0.8850393041275172d, 0.876586776716693d,
					0.8760905079935474d, 0.8825234821595587d,
					0.9170301495288291d, 1.1932053799967461d,
					1.080614223760332d, 0.99468432734888d, 0.9633865100386416d,
					1.052810771462173d, 1.048256478735758d,
					1.3368319488955256d, 1.2143605164638653d,
					1.106794386998474d, 1.1227739204152887d,
					1.942478674706621d, 1.6228587452163343d,
					1.164631359133903d, 1.0844017395868943d, 1.37460536472028d,
					1.1893556025008931d, 1.0700277806876664d,
					1.116520013040137d, 1.2088225344437906d,
					1.1664290061834495d, 1.3394044606684592d,
					1.0527895896525479d, 0.8679393186220611d,
					0.9100772423750401d, 0.9649501080698553d,
					0.981366480921792d, 0.9548707784577252d,
					1.0003516582419723d, 1.0370299857021812d,
					0.9513874979893286d, 0.9037189772936134d,
					0.9313975420976219d, 1.0410555510293251d,
					1.0070539081101986d, 1.0894336842812622d,
					0.8875640413483271d, 0.9049676051108347d,
					0.9847111866852836d, 1.0561183878813871d,
					0.7878359631489108d, 0.9605056010667267d,
					0.9445898482787719d, 1.1632604156634974d,
					0.9434211751522986d, 1.0139359308534606d,
					1.1505914415582605d, 1.0254177304119259d,
					0.9710711277546199d, 1.1075358727615843d,
					0.8848289952897792d, 0.813288643058209d,
					0.8881066086772348d, 0.7889378418665556d,
					0.8586769753338539d, 0.8508169758923363d,
					0.9955610337986619d, 0.9054995430451918d,
					0.9017368794729483d, 1.0264464644834403d,
					1.1773182331344354d, 0.8988200446799605d,
					0.8458375088758325d, 1.1030987376331904d,
					1.1653334345214794d, 0.8703108325252192d,
					0.9632470562244825d, 1.0347223274318484d,
					1.3406823032697819d, 1.1962460700919955d,
					1.3756065205571089d, 1.4263187453295592d,
					0.9445512325329684d, 1.0910264438726156d,
					1.0967559479317575d, 1.0008747872846788d,
					0.9474851698702843d, 0.9865340607171469d,
					1.189584995382864d, 0.9656087140164163d,
					0.8846390011522258d, 0.7051425076052399d,
					0.5959126175768487d, 0.41245568643286723d,
					0.3330508009276437d, 0.2708953602364732d,
					0.17544788816182488d, 0.14143160664450566d,
					0.08662533307902368d, 0.0660983806809682d },
			new double[] { 0.01888982898382261d, 0.31085752907660913d,
					0.3620328825079398d, 0.4190531003749271d,
					0.6321829904488111d, 0.6131219652108572d,
					0.6679528229368181d, 0.6310160062699458d,
					0.6492587740655649d, 0.7418569002677856d,
					0.6394389629819803d, 0.7035878822153558d,
					0.5226445567206754d, 0.6064636945318647d,
					0.5571527925825239d, 0.6240682273482965d,
					0.5546318579152728d, 0.5381995386082046d,
					0.45726520829048645d, 0.4874844379831334d,
					0.4062383560210108d, 0.40804136776049543d,
					0.5030178174524833d, 0.37848742707102284d,
					0.4630570142277685d, 0.41960892070200084d,
					0.49690502033608347d, 0.4897813403640392d,
					0.5870761071388516d, 0.5973386217414202d,
					0.6571837453014527d, 0.7591804722150867d,
					0.7456881389968754d, 0.8166062187814077d,
					0.8299176821178736d, 0.7765243046410153d,
					0.9624289969191807d, 0.8611980924322944d,
					1.0993189174437927d, 1.0836961524223432d,
					1.1140227480549947d, 1.0311820888062708d,
					0.9178938459479434d, 1.0861050869887463d,
					0.7879361924541386d, 1.0160506569751069d,
					0.8173359813647681d, 0.9399806183134815d,
					0.7295327106758198d, 0.9781589640061882d,
					0.8901082068809172d, 0.9463026877011254d,
					0.7015527200573324d, 0.6603100782302601d,
					0.7151800276511111d, 0.653478566507649d,
					0.6237323711110491d, 0.6606367215620144d,
					1.0278695286315247d, 0.6143210869095478d,
					0.6657789469797625d, 0.7890116525173541d,
					0.5808505687065776d, 0.882183539999506d,
					0.9711272658716253d, 0.7857928916947776d,
					0.7013520370871225d, 0.7913822504351657d,
					0.9278933102221059d, 0.9447327073909614d,
					0.9597961661110463d, 0.931335965292198d,
					1.0418705888359907d, 0.7581245753063899d,
					0.7901523020676403d, 0.7555698128942732d,
					0.6984634455661095d, 0.7838811507981037d,
					0.8079493639431871d, 0.9316122850889352d,
					0.8727392055081936d, 0.7844664506478464d,
					0.9194935250426848d, 0.8931646087022214d,
					0.8986542412449318d, 1.1126725111419595d,
					1.247579247460312d, 1.163373713988183d,
					1.1411985463478747d, 1.3447088211321516d,
					1.0251409383852563d, 1.0570430721536979d,
					1.4556407931541144d, 1.3107915799322167d,
					1.155453752369713d, 1.103742652831375d,
					0.8322732685451053d, 1.152289344665068d,
					1.1212225829963434d, 0.8661307243143295d,
					0.9104097171108128d, 0.5008538428094835d,
					0.887730167738971d, 0.8649565233078275d,
					0.8079739063212961d, 1.000781088595624d,
					0.9675785833598759d, 0.7780085979843625d,
					1.0345622381110378d, 0.7179065980056458d,
					1.0936374855128876d, 0.7798286685892126d,
					0.8352151329463572d, 0.6254442114532162d,
					0.9271886110383379d, 0.987727511925958d,
					0.841886437940341d, 0.7355029252301905d,
					0.8496443192094472d, 0.9114116622064097d,
					1.0273687979048018d, 1.2775376506247824d,
					1.1625946747451674d, 1.0896385240097746d,
					0.8510693935619186d, 0.790037716740189d,
					0.8383512968584845d, 0.9995090620669177d,
					0.9147423427845729d, 0.9944341955975363d,
					0.9432746850936549d, 0.8394690351636597d,
					0.8636688457955777d, 0.9435335503733558d,
					0.8855254677164891d, 0.972577306486453d,
					1.083536226750014d, 0.8928495848667704d,
					0.8600855426264943d, 0.938918832305279d,
					1.2117301891759042d, 1.2703998227731375d,
					1.0669625303450148d, 1.2919364471808519d,
					1.0232411818454883d, 1.1435701268834557d,
					1.124205084239247d, 1.0961937160626856d,
					1.1922218927386912d, 1.1280754269708773d,
					1.0460080765846032d, 1.0114499616355264d,
					1.1337476513975961d, 0.8759586994163163d,
					0.8670694201306888d, 0.7024982210288757d,
					0.5447780112509952d, 0.37928757395219914d,
					0.2968408529308834d, 0.23271160485137238d,
					0.15507992986221833d, 0.11846682756264373d,
					0.0901150354528212d, 0.06518217707112897d,
					0.04762105692700306d },
			new double[] { 1.1692169809957352E-4d, 0.0d, 0.05950371592829576d,
					0.20783828596418855d, 0.5327806202335701d,
					0.34428388462086296d, 0.3620076671722203d,
					0.4856873315114064d, 0.48815382359657383d,
					0.3986443687917385d, 0.41828792849699636d,
					0.6148521470406214d, 0.3967112978322045d,
					0.4394271380282263d, 0.3943624780154167d,
					0.5550097622493223d, 0.4605195142720767d,
					0.4219675492160991d, 0.4804129614595125d,
					0.4529079263876982d, 0.5318858092711085d,
					0.4662588720189544d, 0.5088484531958709d,
					0.36812880304003565d, 0.4804058681297466d,
					0.44368694866281044d, 0.40115018050789825d,
					0.38141916870031317d, 0.3938380336178668d,
					0.39481696158083485d, 0.4515834620524187d,
					0.512000161529237d, 0.4783356397051437d,
					0.49083154397117146d, 0.5199314504512474d,
					0.5244430746189185d, 0.6278830011166969d,
					0.6936119473513467d, 0.6023414741501372d,
					0.6418686738771424d, 0.6088615740311664d,
					0.6589468577039431d, 0.646938120687831d,
					0.6786450374722817d, 0.9506794602047501d,
					0.7724712371835452d, 0.7103764234311538d,
					0.8849596620071222d, 0.8053129998157544d,
					0.9937989527698112d, 0.778036500443895d,
					0.7053352638375365d, 0.8654577950314715d,
					0.6479636518819214d, 0.7352565141465314d,
					0.7872533761557029d, 0.5986201262603355d,
					0.764540546786557d, 0.6245303890189271d,
					0.5603764363005027d, 0.5475557096221624d,
					0.4459903782227699d, 0.6152582178869146d,
					0.5085731860488413d, 0.5710944859905986d,
					0.5667775890430072d, 0.6242941744148285d,
					0.9579242746340848d, 0.5204286607934566d,
					0.665967866447953d, 0.5845349783044719d,
					0.6011487237879908d, 0.6186591047236613d,
					0.6381794603062662d, 0.5983072248299047d,
					0.7347370244347847d, 0.7143689268990282d,
					0.8181154919831105d, 0.8642463729826273d,
					0.7396002718477164d, 1.2689095785567999d,
					0.7829998475580123d, 0.6842770624591955d,
					1.12952400768093d, 0.8867304390964195d,
					0.9238636102649137d, 0.9205458115342279d,
					0.7759248655321048d, 0.7442198691825614d,
					0.9982376655641794d, 0.7197762468530633d,
					0.8108462459564932d, 0.8341859293288147d,
					0.6502303684654822d, 0.7887177865875838d,
					1.0158769493625206d, 0.7455950146222567d,
					0.6894440405522331d, 0.6469637124851665d,
					0.8026632338168513d, 0.8719006744478652d,
					0.7670116321488311d, 0.7495831523327278d,
					0.6630077910312208d, 0.794373099408968d,
					0.7473103239349663d, 0.6833183357298818d,
					0.6620196904579383d, 0.5851928708225708d,
					0.6166598108106784d, 0.5525016223309642d,
					0.5609551939651405d, 0.6817443106328791d,
					0.6190291420839884d, 0.7161773637111748d,
					0.7524030312938775d, 0.6124052968945074d,
					0.6380095288351323d, 0.8190613038868927d,
					0.655078326161603d, 0.7073256440322242d,
					0.7158937687385212d, 0.7516481726943763d,
					0.8251196796447731d, 0.672969816083799d,
					0.7514584938637747d, 0.7468258189632397d,
					0.6854235102111598d, 0.7558097649741213d,
					0.6416247983928703d, 0.7427990078765513d,
					0.7293713546267201d, 0.7477178222162799d,
					0.6731880422765735d, 1.0284901256727028d,
					0.9992859531839258d, 1.0202561983596286d,
					0.9941520043665741d, 0.6307897885384984d,
					0.7206999722796521d, 0.7063539340106959d,
					0.6642335253102256d, 0.8041434716658608d,
					1.0723000585331623d, 0.6890490990950473d,
					0.7775404734181358d, 0.9042330706292915d,
					0.7738640060252518d, 0.7412790294896492d,
					0.8040545898682677d, 1.0225604165651168d,
					0.8780106273576762d, 1.1059607082662732d,
					1.0706623946874438d, 0.9402135367302293d,
					0.8925168167042588d, 0.798964713389738d,
					0.5950573880335905d, 0.49452577718270363d,
					0.36888365123319755d, 0.3069855489883373d,
					0.1988326126616817d, 0.15733824234011337d,
					0.12115272615945413d, 0.08907007343514524d } };

	private static final LineData[] NA23_LINES;
	
	static {
		NA23_LINES = new LineData[TEST_DATASET_COORDINATES.length];
		for (int i = 0; i < TEST_DATASET_COORDINATES.length; i++) {
			NA23_LINES[i] = new LineData(lineName(i), NA23_DATA[i],
					TEST_DATASET_COORDINATES[i]);
		}
	}

	public static final ElementData NA23 = 
		ElementData.createElementData(NA23_NAME, NA23_LINES);

	private static String lineName(int i) {
		StringBuilder sB = new StringBuilder("LINHA_");
		sB.append((i+1) < 10?"0":"");
		sB.append((i+1));
		sB.append(".xl");
		return sB.toString();
	}
}
